@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 */
 #ifndef BATCHED_KERNEL_PARAM_H
 #define BATCHED_KERNEL_PARAM_H
@@ -26,8 +26,6 @@
 #define BATRF_NB         128
 #define BATRF_RECNB       32
 #define BATF2_NB           8
-#define BASWP_WIDTH        4
-#define SWP_WIDTH          4
 
 #define BAQRF_NB         32
 
