@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 */
 
 #ifndef MAGMA_BATCHED_H
@@ -27,47 +27,53 @@ extern "C" {
 #endif
 
 
-void 
-setup_pivinfo_batched( magma_int_t **pivinfo_array, magma_int_t **ipiv_array, magma_int_t ipiv_offset, 
-    magma_int_t m, magma_int_t nb, 
+void
+setup_pivinfo_batched( magma_int_t **pivinfo_array, magma_int_t **ipiv_array, magma_int_t ipiv_offset,
+    magma_int_t m, magma_int_t nb,
     magma_int_t batchCount,  magma_queue_t queue);
 
 
-void 
-adjust_ipiv_batched( magma_int_t **ipiv_array, magma_int_t ipiv_offset, 
-    magma_int_t m, magma_int_t offset, 
+void
+adjust_ipiv_batched( magma_int_t **ipiv_array, magma_int_t ipiv_offset,
+    magma_int_t m, magma_int_t offset,
     magma_int_t batchCount, magma_queue_t queue);
 
-void 
+void
 magma_idisplace_pointers(magma_int_t **output_array,
     magma_int_t **input_array, magma_int_t lda,
-    magma_int_t row, magma_int_t column, 
+    magma_int_t row, magma_int_t column,
     magma_int_t batchCount, magma_queue_t queue);
 
-void 
+void
 stepinit_ipiv(magma_int_t **ipiv_array,
     magma_int_t pm,
     magma_int_t batchCount, magma_queue_t queue);
 
-void 
+void
 setup_pivinfo(
-    magma_int_t *pivinfo, magma_int_t *ipiv, 
-    magma_int_t m, magma_int_t nb, 
+    magma_int_t *pivinfo, magma_int_t *ipiv,
+    magma_int_t m, magma_int_t nb,
     magma_queue_t queue);
 
 void
-adjust_ipiv( magma_int_t *ipiv, 
-                 magma_int_t m, magma_int_t offset, 
+adjust_ipiv( magma_int_t *ipiv,
+                 magma_int_t m, magma_int_t offset,
                  magma_queue_t queue);
 
 void magma_iset_pointer(
     magma_int_t **output_array,
     magma_int_t *input,
     magma_int_t lda,
-    magma_int_t row, magma_int_t column, 
+    magma_int_t row, magma_int_t column,
     magma_int_t batchSize,
     magma_int_t batchCount, magma_queue_t queue);
 
+void magma_gbtrf_adjust_ju(
+    magma_int_t n, magma_int_t ku,
+    magma_int_t** dipiv_array, int* ju_array,
+    magma_int_t gbstep, magma_int_t batchCount,
+    magma_queue_t queue);
+
 #ifdef __cplusplus
 }
 #endif
