@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 */
 
 #ifndef MAGMA_TYPES_H
@@ -16,6 +16,9 @@
 #include <stdint.h>
 #include <assert.h>
 
+#ifndef __cplusplus
+#include<stdbool.h>
+#endif
 
 // for backwards compatability
 #ifdef HAVE_clAmdBlas
@@ -44,6 +47,20 @@
   #endif
 #endif
 
+// Define a deprecation macro depending on compiler and C++/C version
+#if (__cplusplus >= 201402L) || (__STDC_VERSION__ >= 202311L) || ((__GNUC__ > 9) && !defined(__INTEL_COMPILER))
+    #define MAGMA_DEPRECATE(MSG) [[deprecated(MSG)]]
+#elif __GNUC__
+    #define MAGMA_DEPRECATE(MSG) __attribute__((deprecated(MSG)))
+#elif __clang__
+  #if __has_extension(attribute_deprecated_with_message)
+    #define MAGMA_DEPRECATE(MSG) __attribute__((deprecated(MSG)))
+  #else
+    #define MAGMA_DEPRECATE(MSG)
+  #endif
+#else
+    #define MAGMA_DEPRECATE(MSG)
+#endif
 
 // =============================================================================
 // To use int64_t, link with mkl_intel_ilp64 or similar (instead of mkl_intel_lp64).
@@ -84,12 +101,12 @@ typedef double real_Double_t;
     typedef cudaEvent_t    magma_event_t;
     typedef magma_int_t    magma_device_t;
 
-    // Half precision in CUDA 
+    // Half precision in CUDA
     #if defined(__cplusplus) && CUDA_VERSION >= 7500
     #include <cuda_fp16.h>
     typedef __half           magmaHalf;
     #else
-    // use short for cuda older than 7.5 
+    // use short for cuda older than 7.5
     // corresponding routines would not work anyway since there is no half precision
     typedef short            magmaHalf;
     #endif    // CUDA_VERSION >= 7500
@@ -138,16 +155,22 @@ typedef double real_Double_t;
 #elif defined(MAGMA_HAVE_HIP)
 
     // default to HCC
-    #if !defined(__HIP_PLATFORM_HCC__) && !defined(__HIP_PLATFORM_NVCC)
-      #define __HIP_PLATFORM_HCC__
+    #if !defined(__HIP_PLATFORM_AMD__) && !defined(__HIP_PLATFORM_NVCC)
+      #define __HIP_PLATFORM_AMD__
     #endif
-    // the standard HIP header, similar to CUDA's 'cuda.h'
-    #include <hip/hip_runtime.h> 
 
-    // hipBLAS & hipSPARSE LA library headers
+    #include <hip/hip_version.h>
+    #include <hip/hip_runtime.h>
+
+    // hipblas/hipsparse headers
+    #if HIP_VERSION >= 50200000
+    #include <hipblas/hipblas.h>
+    #include <hipsparse/hipsparse.h>
+    #else
     #include <hipblas.h>
     #include <hipsparse.h>
-    
+    #endif
+
     // this macro allows you to define an unsupported function (primarily from hipBLAS)
     // which will become a NOOP, and print an error message
     #ifndef magma_unsupported
@@ -163,13 +186,13 @@ typedef double real_Double_t;
     //#define hipblasSetVectorAsync(a, b, c, d, e, f, stream) hipblasSetVector(a, b, c, d, e, f)
     //#define hipblasGetMatrixAsync(a, b, c, d, e, f, g, stream) hipblasGetMatrix(a, b, c ,d, e, f, g)
     //#define hipblasSetMatrixAsync(a, b, c, d, e, f, g, stream) hipblasSetMatrix(a, b, c, d, e, f, g)
-   
-    /* Unsupported hipBLAS functionality 
+
+    /* Unsupported hipBLAS functionality
      * Everything here is currently unsupported by hipBLAS, and as such, is a no-op,
      * and an error message is printed out to stderr
      *
      * To generate a list of these, first remove all these macro definitions, run a `make clean`
-     * to clear caches, and then start running: 
+     * to clear caches, and then start running:
      * $ make lib/libmagma.so -j64 2>&1 \
      *     | grep "use of undeclared identifier" \
      *     | awk '{gsub("'"'"'", "", $7) ; gsub(";", "", $7) ; print $7}'
@@ -181,21 +204,25 @@ typedef double real_Double_t;
      * its just a one time run to figure out which are undefined, then write a simple script
      * to turn them into the macro #define s you see below:
      */
-    
+
     #include <hip/hip_fp16.h>
 
     #ifdef __cplusplus
     extern "C" {
     #endif
-  
+
     // opaque queue struct type
-    struct magma_queue; 
+    struct magma_queue;
     typedef struct magma_queue* magma_queue_t;
     typedef hipEvent_t  magma_event_t;
     typedef magma_int_t magma_device_t;
 
+    #ifdef __cplusplus
+    typedef __half           magmaHalf;
+    #else
     // just define a half precision as a short, since they should be the same byte-size
-    typedef __half            magmaHalf; 
+    typedef short            magmaHalf;
+    #endif
 
     hipStream_t       magma_queue_get_hip_stream      ( magma_queue_t queue );
     hipblasHandle_t   magma_queue_get_hipblas_handle  ( magma_queue_t queue );
@@ -203,16 +230,14 @@ typedef double real_Double_t;
 
     /* double complex */
 
-    //typedef hipblasDoubleComplex magmaDoubleComplex;
-
     /* simple double complex definition that should be binary compatible with hipBLAS */
     typedef struct {
-        
+
         // real, imag components
         double x, y;
 
-    } magmaDoubleComplex;    
-    
+    } magmaDoubleComplex;
+
     /* functionality macros */
     #define MAGMA_Z_MAKE(r, i)   ((magmaDoubleComplex){(double)(r), (double)(i)})
     #define MAGMA_Z_REAL(a) (a).x
@@ -223,7 +248,7 @@ typedef double real_Double_t;
     #define MAGMA_Z_DIV(a, b) magmaCdiv(a, b)
     #define MAGMA_Z_ABS(a) (hypot(MAGMA_Z_REAL(a), MAGMA_Z_IMAG(a)))
     #define MAGMA_Z_ABS1(a) (fabs(MAGMA_Z_REAL(a)) + fabs(MAGMA_Z_IMAG(a)))
-    #define MAGMA_Z_CONJ(a) magmaConj(a) 
+    #define MAGMA_Z_CONJ(a) magmaConj(a)
 
     /* basic arithmetic functions */
     __host__ __device__ static inline magmaDoubleComplex magmaCadd(magmaDoubleComplex a, magmaDoubleComplex b) {
@@ -238,7 +263,7 @@ typedef double real_Double_t;
     __host__ __device__ static inline magmaDoubleComplex magmaCdiv(magmaDoubleComplex a, magmaDoubleComplex b) {
         double sqabs = b.x*b.x + b.y*b.y;
         return MAGMA_Z_MAKE(
-            (a.x * b.x + a.y * b.y) / sqabs, 
+            (a.x * b.x + a.y * b.y) / sqabs,
             (a.y * b.x - a.x * b.y) / sqabs
         );
     }
@@ -251,12 +276,9 @@ typedef double real_Double_t;
 
     /* float complex */
 
-    //typedef hipComplex magmaFloatComplex;
-    //typedef hipblasComplex magmaFloatComplex;
-    
     /* basic definition of float complex that should be binary compatible with hipBLAS */
     typedef struct {
-        
+
         // real, imag components
         float x, y;
 
@@ -272,7 +294,7 @@ typedef double real_Double_t;
     #define MAGMA_C_DIV(a, b) magmaCdivf(a, b)
     #define MAGMA_C_ABS(a) (hypotf(MAGMA_C_REAL(a), MAGMA_C_IMAG(a)))
     #define MAGMA_C_ABS1(a) (fabsf(MAGMA_C_REAL(a)) + fabs(MAGMA_C_IMAG(a)))
-    #define MAGMA_C_CONJ(a) magmaConjf(a) 
+    #define MAGMA_C_CONJ(a) magmaConjf(a)
 
     /* basic arithmetic functions */
     __host__ __device__ static inline magmaFloatComplex magmaCaddf(magmaFloatComplex a, magmaFloatComplex b) {
@@ -301,7 +323,7 @@ typedef double real_Double_t;
 
     #ifdef __cplusplus
     }
-    #endif 
+    #endif
 
 #elif defined(MAGMA_HAVE_OPENCL)
     #include <clBLAS.h>
@@ -314,7 +336,7 @@ typedef double real_Double_t;
     typedef cl_event          magma_event_t;
     typedef cl_device_id      magma_device_t;
 
-    typedef short         magmaHalf;    // placeholder until FP16 is supported 
+    typedef short         magmaHalf;    // placeholder until FP16 is supported
     typedef DoubleComplex magmaDoubleComplex;
     typedef FloatComplex  magmaFloatComplex;
 
@@ -356,7 +378,7 @@ typedef double real_Double_t;
     typedef int   magma_event_t;
     typedef int   magma_device_t;
 
-    typedef short                 magmaHalf;    // placeholder until FP16 is supported 
+    typedef short                 magmaHalf;    // placeholder until FP16 is supported
     typedef std::complex<float>   magmaFloatComplex;
     typedef std::complex<double>  magmaDoubleComplex;
 
@@ -503,8 +525,8 @@ float  magma_cabsf( magmaFloatComplex  x );
 
 // -----------------------------------------------------------------------------
 #define MAGMA_VERSION_MAJOR 2
-#define MAGMA_VERSION_MINOR 6
-#define MAGMA_VERSION_MICRO 2
+#define MAGMA_VERSION_MINOR 10
+#define MAGMA_VERSION_MICRO 0
 
 // stage is "svn", "beta#", "rc#" (release candidate), or blank ("") for final release
 #define MAGMA_VERSION_STAGE ""
@@ -684,6 +706,12 @@ typedef enum {
     MagmaHybrid        = 701,
     MagmaNative        = 702
 } magma_mode_t;
+
+typedef enum {
+    MagmaAscending     = 751,
+    MagmaDescending    = 752
+} magma_sort_t;
+
 // -----------------------------------------------------------------------------
 // sparse
 typedef enum {
@@ -831,7 +859,7 @@ typedef enum {
     Magma_PREC_HST          = 903,
     Magma_PREC_SH           = 904,
     Magma_PREC_SHT          = 905,
-    
+
     Magma_PREC_XHS_H        = 910,
     Magma_PREC_XHS_HTC      = 911,
     Magma_PREC_XHS_161616   = 912,
