@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
 */
@@ -58,6 +58,10 @@ magma_int_t magma_get_zbulge_nb_mgpu( magma_int_t n );
 magma_int_t magma_get_zbulge_vblksiz( magma_int_t n, magma_int_t nb, magma_int_t nbthreads );
 magma_int_t magma_get_zbulge_gcperf();
 
+// =============================================================================
+// Other auxiliary functions
+bool magma_zgetrf_gpu_recommend_cpu(magma_int_t m, magma_int_t n, magma_int_t nb);
+bool magma_zgetrf_native_recommend_notrans(magma_int_t m, magma_int_t n, magma_int_t nb);
 
 // =============================================================================
 // MAGMA function definitions
@@ -96,7 +100,39 @@ magma_zirange(
     magma_int_t k, magma_int_t *indxq, magma_int_t *iil, magma_int_t *iiu, magma_int_t il, magma_int_t iu);
 #endif  // MAGMA_REAL
 
-// ------------------------------------------------------------ zge routines
+// ---------------------------------------------------------------- zgb routines
+magma_int_t
+magma_zgbsv_native(
+        magma_int_t n, magma_int_t kl, magma_int_t ku, magma_int_t nrhs,
+        magmaDoubleComplex* dA, magma_int_t ldda, magma_int_t* dipiv,
+        magmaDoubleComplex* dB, magma_int_t lddb,
+        magma_int_t *info);
+
+void
+magma_zgbsv_native_work(
+        magma_int_t n, magma_int_t kl, magma_int_t ku, magma_int_t nrhs,
+        magmaDoubleComplex* dA, magma_int_t ldda, magma_int_t* dipiv,
+        magmaDoubleComplex* dB, magma_int_t lddb,
+        magma_int_t *info, void* device_work, magma_int_t* lwork,
+        magma_queue_t queue);
+
+magma_int_t
+magma_zgbtrf_native(
+    magma_int_t m, magma_int_t n,
+    magma_int_t kl, magma_int_t ku,
+    magmaDoubleComplex* dAB, magma_int_t lddab, magma_int_t* dipiv,
+    magma_int_t *info);
+
+void
+magma_zgbtrf_native_work(
+    magma_int_t m, magma_int_t n,
+    magma_int_t kl, magma_int_t ku,
+    magmaDoubleComplex* dAB, magma_int_t lddab,
+    magma_int_t* dipiv, magma_int_t *info,
+    void* device_work, magma_int_t* lwork,
+    magma_queue_t queue);
+
+// ---------------------------------------------------------------- zgb routines
 magma_int_t
 magma_zgebrd(
     magma_int_t m, magma_int_t n,
@@ -149,6 +185,14 @@ magma_zgegqr_gpu(
     magmaDoubleComplex_ptr dwork, magmaDoubleComplex *work,
     magma_int_t *info);
 
+magma_int_t
+magma_zgegqr_expert_gpu_work(
+    magma_int_t ikind, magma_int_t m, magma_int_t n,
+    magmaDoubleComplex_ptr dA,   magma_int_t ldda,
+    void *host_work,   magma_int_t *lwork_host,
+    void *device_work, magma_int_t *lwork_device,
+    magma_int_t *info, magma_queue_t queue );
+
 magma_int_t
 magma_zgehrd(
     magma_int_t n, magma_int_t ilo, magma_int_t ihi,
@@ -272,6 +316,15 @@ magma_zgeqp3_gpu(
     #endif
     magma_int_t *info);
 
+magma_int_t
+magma_zgeqp3_expert_gpu_work(
+    magma_int_t m, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t *jpvt, magmaDoubleComplex *tau,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_int_t *info, magma_queue_t queue );
+
 // CUDA MAGMA only
 magma_int_t
 magma_zgeqr2_gpu(
@@ -340,6 +393,17 @@ magma_zgeqrf_gpu(
     magmaDoubleComplex_ptr dT,
     magma_int_t *info);
 
+magma_int_t
+magma_zgeqrf_expert_gpu_work(
+    magma_int_t m, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magmaDoubleComplex *tau, magmaDoubleComplex_ptr dT,
+    magma_int_t *info,
+    magma_mode_t mode, magma_int_t nb,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_queue_t queues[2] );
+
 // CUDA MAGMA only
 magma_int_t
 magma_zgeqrf_m(
@@ -481,6 +545,21 @@ magma_zgesvd(
     #endif
     magma_int_t *info);
 
+// This definition should ideally be in magma_zbatched.h
+// It has been moved here for the need of a fortran interface,
+// which can be automatically generated for magma_z.h
+// TODO: should we move other batched-strided routines here?
+magma_int_t
+magma_zgesvj_batched_strided(
+    magma_vec_t jobu, magma_vec_t jobv,
+    magma_int_t morg, magma_int_t norg,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda, magma_int_t strideA,
+    magmaDouble_ptr        dS, magma_int_t strideS,
+    magmaDoubleComplex_ptr dU, magma_int_t lddu, magma_int_t strideU,
+    magmaDoubleComplex_ptr dV, magma_int_t lddv, magma_int_t strideV,
+    magmaInt_ptr dinfo_array,
+    magma_int_t batchCount, magma_queue_t queue );
+
 // CUDA MAGMA only
 magma_int_t
 magma_zgetf2_gpu(
@@ -504,6 +583,7 @@ magma_zgetf2_native(
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t *dipiv, magma_int_t* dipivinfo,
     magma_int_t *dinfo, magma_int_t gbstep,
+    magma_event_t events[2],
     magma_queue_t queue, magma_queue_t update_queue);
 
 // CUDA MAGMA only
@@ -515,11 +595,11 @@ magma_zgetf2_nopiv(
 
 magma_int_t
 magma_zgetrf_recpanel_native(
-    magma_int_t m, magma_int_t n,
+    magma_int_t m, magma_int_t n, magma_int_t recnb,
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t* dipiv, magma_int_t* dipivinfo,
     magma_int_t *dinfo, magma_int_t gbstep,
-    magma_queue_t queue, magma_queue_t update_queue );
+    magma_event_t events[2], magma_queue_t queue, magma_queue_t update_queue);
 
 magma_int_t
 magma_zgetrf(
@@ -535,6 +615,17 @@ magma_zgetrf_gpu(
     magma_int_t *ipiv,
     magma_int_t *info);
 
+magma_int_t
+magma_zgetrf_expert_gpu_work(
+    magma_int_t m, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t *ipiv,
+    magma_int_t *info, magma_mode_t mode,
+    magma_int_t nb, magma_int_t recnb,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_event_t events[2], magma_queue_t queues[2] );
+
 magma_int_t
 magma_zgetrf_gpu_expert(
     magma_int_t m, magma_int_t n,
@@ -608,6 +699,16 @@ magma_zgetri_gpu(
     magmaDoubleComplex_ptr dwork, magma_int_t lwork,
     magma_int_t *info);
 
+magma_int_t
+magma_zgetri_expert_gpu_work(
+    magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda, magma_int_t *ipiv,
+    magma_int_t *info,
+    magma_mode_t mode,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_queue_t queues[2] );
+
 magma_int_t
 magma_zgetrs_gpu(
     magma_trans_t trans, magma_int_t n, magma_int_t nrhs,
@@ -616,6 +717,17 @@ magma_zgetrs_gpu(
     magmaDoubleComplex_ptr dB, magma_int_t lddb,
     magma_int_t *info);
 
+magma_int_t
+magma_zgetrs_expert_gpu_work(
+    magma_trans_t trans, magma_int_t n, magma_int_t nrhs,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda, magma_int_t *ipiv,
+    magmaDoubleComplex_ptr dB, magma_int_t lddb,
+    magma_int_t *info,
+    magma_mode_t mode,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_queue_t queue );
+
 // CUDA MAGMA only
 magma_int_t
 magma_zgetrs_nopiv_gpu(
@@ -1253,17 +1365,6 @@ magma_zlaqps(
     magmaDoubleComplex *F,  magma_int_t ldf,
     magmaDoubleComplex_ptr dF, magma_int_t lddf);
 
-// CUDA MAGMA only
-magma_int_t
-magma_zlaqps_gpu(
-    magma_int_t m, magma_int_t n, magma_int_t offset,
-    magma_int_t nb, magma_int_t *kb,
-    magmaDoubleComplex_ptr dA,  magma_int_t ldda,
-    magma_int_t *jpvt, magmaDoubleComplex *tau,
-    double *vn1, double *vn2,
-    magmaDoubleComplex_ptr dauxv,
-    magmaDoubleComplex_ptr dF, magma_int_t lddf);
-
 // CUDA MAGMA only
 magma_int_t
 magma_zlaqps2_gpu(
@@ -1398,6 +1499,13 @@ magma_zpotf2_gpu(
     magma_queue_t queue,
     magma_int_t *info);
 
+magma_int_t
+magma_zpotf2_native(
+    magma_uplo_t uplo, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t step, magma_int_t *device_info,
+    magma_queue_t queue );
+
 magma_int_t
 magma_zpotrf_rectile_native(
     magma_uplo_t uplo, magma_int_t n, magma_int_t recnb,
@@ -1410,6 +1518,17 @@ magma_zpotrf(
     magmaDoubleComplex *A, magma_int_t lda,
     magma_int_t *info);
 
+magma_int_t
+magma_zpotrf_expert_gpu_work(
+    magma_uplo_t uplo, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t *info,
+    magma_mode_t mode,
+    magma_int_t nb, magma_int_t recnb,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_event_t events[2], magma_queue_t queues[2] );
+
 magma_int_t
 magma_zpotrf_expert_gpu(
     magma_uplo_t uplo, magma_int_t n,
@@ -1483,6 +1602,16 @@ magma_zpotrs_gpu(
     magmaDoubleComplex_ptr dB, magma_int_t lddb,
     magma_int_t *info);
 
+magma_int_t
+magma_zpotrs_expert_gpu_work(
+    magma_uplo_t uplo, magma_int_t n, magma_int_t nrhs,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magmaDoubleComplex_ptr dB, magma_int_t lddb,
+    magma_int_t *info,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_queue_t queue );
+
 // ------------------------------------------------------------ zsy routines
 #ifdef MAGMA_COMPLEX
 // CUDA MAGMA only
@@ -1590,6 +1719,15 @@ magma_ztrtri_gpu(
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t *info);
 
+magma_int_t
+magma_ztrtri_expert_gpu_work(
+    magma_uplo_t uplo, magma_diag_t diag, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t *info,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_queue_t queues[2] );
+
 // ------------------------------------------------------------ zun routines
 // CUDA MAGMA only
 magma_int_t
@@ -1834,6 +1972,30 @@ void magma_zq_to_panel(
     magmaDoubleComplex *A, magma_int_t lda,
     magmaDoubleComplex *work);
 
+/* auxiliary routines for posv-irgmres  */
+void
+magmablas_zextract_diag_sqrt(
+    magma_int_t m, magma_int_t n,
+    magmaDoubleComplex* dA, magma_int_t ldda,
+    double* dD, magma_int_t incd,
+    magma_queue_t queue);
+
+void
+magmablas_zscal_shift_hpd(
+    magma_uplo_t uplo, int n,
+    magmaDoubleComplex* dA, int ldda,
+    double* dD, int incd,
+    double miu, double cn, double eps,
+    magma_queue_t queue);
+
+void
+magmablas_zdimv_invert(
+    magma_int_t n,
+    magmaDoubleComplex alpha, magmaDoubleComplex* dD, magma_int_t incd,
+                              magmaDoubleComplex* dx, magma_int_t incx,
+    magmaDoubleComplex beta,  magmaDoubleComplex* dy, magma_int_t incy,
+    magma_queue_t queue);
+
 #ifdef __cplusplus
 }
 #endif
