@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Azzam Haidar
        @author Tingxing Dong
@@ -22,10 +22,37 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+
+  /*
+   *  control and tuning
+   */
+void magma_get_zgetrf_vbatched_nbparam(magma_int_t max_m, magma_int_t max_n, magma_int_t *nb, magma_int_t *recnb);
+
+
   /*
    *  LAPACK vbatched routines
    */
 
+magma_int_t
+magma_zgetf2_fused_vbatched(
+    magma_int_t max_M, magma_int_t max_N,
+    magma_int_t max_minMN, magma_int_t max_MxN,
+    magma_int_t* M, magma_int_t* N,
+    magmaDoubleComplex **dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+    magma_int_t **dipiv_array, magma_int_t ipiv_i,
+    magma_int_t *info_array, magma_int_t batchCount,
+    magma_queue_t queue);
+
+magma_int_t
+magma_zgetf2_fused_sm_vbatched(
+    magma_int_t max_M, magma_int_t max_N, magma_int_t max_minMN, magma_int_t max_MxN,
+    magma_int_t* m, magma_int_t* n,
+    magmaDoubleComplex** dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+    magma_int_t** dipiv_array, magma_int_t ipiv_i,
+    magma_int_t* info_array, magma_int_t gbstep,
+    magma_int_t nthreads, magma_int_t check_launch_only,
+    magma_int_t batchCount, magma_queue_t queue );
+
 magma_int_t
 magma_zgetrf_vbatched(
         magma_int_t* m, magma_int_t* n,
@@ -37,8 +64,18 @@ magma_int_t
 magma_zgetrf_vbatched_max_nocheck(
         magma_int_t* m, magma_int_t* n, magma_int_t* minmn,
         magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
+        magma_int_t nb, magma_int_t recnb,
         magmaDoubleComplex **dA_array, magma_int_t *ldda,
-        magma_int_t **ipiv_array, magma_int_t *info_array,
+        magma_int_t **ipiv_array, magma_int_t** pivinfo_array,
+        magma_int_t *info_array, magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetrf_vbatched_max_nocheck_work(
+        magma_int_t* m, magma_int_t* n,
+        magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
+        magmaDoubleComplex **dA_array, magma_int_t *ldda,
+        magma_int_t **dipiv_array, magma_int_t *info_array,
+        void* work, magma_int_t* lwork,
         magma_int_t batchCount, magma_queue_t queue);
 
 magma_int_t
@@ -66,7 +103,7 @@ magma_int_t magma_zscal_zgeru_vbatched(
 magma_int_t
 magma_zgetf2_vbatched(
     magma_int_t *m, magma_int_t *n, magma_int_t *minmn,
-    magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn,
+    magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
     magmaDoubleComplex **dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t *ldda,
     magma_int_t **ipiv_array, magma_int_t *info_array,
     magma_int_t gbstep, magma_int_t batchCount, magma_queue_t queue);
@@ -97,6 +134,100 @@ magma_zlaswp_right_rowserial_vbatched(
         magma_int_t k1, magma_int_t k2,
         magma_int_t batchCount, magma_queue_t queue);
 
+void
+magma_zlaswp_left_rowparallel_vbatched(
+        magma_int_t n,
+        magma_int_t* M, magma_int_t* N,
+        magmaDoubleComplex** dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+        magma_int_t k1, magma_int_t k2,
+        magma_int_t **pivinfo_array, magma_int_t pivinfo_i,
+        magma_int_t batchCount, magma_queue_t queue);
+
+void
+magma_zlaswp_right_rowparallel_vbatched(
+        magma_int_t n,
+        magma_int_t* M, magma_int_t* N,
+        magmaDoubleComplex** dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+        magma_int_t k1, magma_int_t k2,
+        magma_int_t **pivinfo_array, magma_int_t pivinfo_i,
+        magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t magma_zscal_zgeru_nopiv_vbatched(
+    magma_int_t max_M, magma_int_t max_N,
+    magma_int_t *M, magma_int_t *N,
+    magmaDoubleComplex **dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t *ldda,
+    double *dtol_array, double eps, magma_int_t *info_array, magma_int_t step, magma_int_t gbstep,
+    magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetf2_nopiv_fused_sm_vbatched(
+    magma_int_t max_M, magma_int_t max_N, magma_int_t max_minMN, magma_int_t max_MxN,
+    magma_int_t* m, magma_int_t* n,
+    magmaDoubleComplex** dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+    double* dtol_array, double eps, magma_int_t* info_array, magma_int_t gbstep,
+    magma_int_t nthreads, magma_int_t check_launch_only,
+    magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetf2_nopiv_fused_vbatched(
+    magma_int_t max_M, magma_int_t max_N,
+    magma_int_t max_minMN, magma_int_t max_MxN,
+    magma_int_t* M, magma_int_t* N,
+    magmaDoubleComplex **dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+    double* dtol_array, double eps, magma_int_t *info_array, magma_int_t batchCount,
+    magma_queue_t queue);
+
+magma_int_t
+magma_zgetf2_nopiv_vbatched(
+    magma_int_t *m, magma_int_t *n, magma_int_t* minmn,
+    magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
+    magmaDoubleComplex **dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t *ldda,
+    double *dtol_array, double eps, magma_int_t *info_array,
+    magma_int_t gbstep, magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetrf_nopiv_recpanel_vbatched(
+    magma_int_t* m, magma_int_t* n, magma_int_t* minmn,
+    magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn,
+    magma_int_t max_mxn, magma_int_t min_recpnb,
+    magmaDoubleComplex** dA_array, magma_int_t Ai, magma_int_t Aj, magma_int_t* ldda,
+    double* dtol_array, double eps,
+    magma_int_t *info_array, magma_int_t gbstep,
+    magma_int_t batchCount,  magma_queue_t queue);
+    
+magma_int_t
+magma_zgetrf_nopiv_vbatched_max_nocheck(
+        magma_int_t* m, magma_int_t* n, magma_int_t* minmn,
+        magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
+        magma_int_t nb, magma_int_t recnb,
+        magmaDoubleComplex **dA_array, magma_int_t *ldda,
+        double* dtol_array, double eps,
+        magma_int_t *info_array, magma_int_t batchCount,
+        magma_queue_t queue);
+
+magma_int_t
+magma_zgetrf_nopiv_vbatched_max_nocheck_work(
+        magma_int_t* m, magma_int_t* n,
+        magma_int_t max_m, magma_int_t max_n, magma_int_t max_minmn, magma_int_t max_mxn,
+        magmaDoubleComplex **dA_array, magma_int_t *ldda,
+        double *dtol_array, double eps, magma_int_t *info_array,
+        void* work, magma_int_t* lwork,
+        magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetrf_nopiv_vbatched(
+        magma_int_t* m, magma_int_t* n,
+        magmaDoubleComplex **dA_array, magma_int_t *ldda,
+        magma_int_t *info_array,
+        magma_int_t batchCount, magma_queue_t queue);
+
+magma_int_t
+magma_zgetrf_nopiv_expert_vbatched(
+        magma_int_t* m, magma_int_t* n,
+        magmaDoubleComplex **dA_array, magma_int_t *ldda,
+        double *dtol_array, double eps, magma_int_t *info_array,
+        magma_int_t batchCount, magma_queue_t queue);
+
 magma_int_t
 magma_zpotrf_lpout_vbatched(
     magma_uplo_t uplo, magma_int_t *n, magma_int_t max_n,
