@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
 */
@@ -78,16 +78,16 @@ magmablas_zprbt(
 
 void
 magmablas_zprbt_mv(
-    magma_int_t n,
+    magma_int_t n, magma_int_t nrhs,
     magmaDoubleComplex_ptr dv,
-    magmaDoubleComplex_ptr db,
+    magmaDoubleComplex_ptr db, magma_int_t lddb,
     magma_queue_t queue );
 
 void
 magmablas_zprbt_mtv(
-    magma_int_t n,
+    magma_int_t n, magma_int_t nrhs,
     magmaDoubleComplex_ptr du,
-    magmaDoubleComplex_ptr db,
+    magmaDoubleComplex_ptr db, magma_int_t lddb,
     magma_queue_t queue );
 
   /*
@@ -662,17 +662,6 @@ magmablas_ztrsv(
     magmaDoubleComplex_ptr       db, magma_int_t incb,
     magma_queue_t queue );
 
-// todo: move flag before queue?
-void
-magmablas_ztrsv_outofplace(
-    magma_uplo_t uplo, magma_trans_t transA, magma_diag_t diag,
-    magma_int_t n,
-    magmaDoubleComplex_const_ptr dA, magma_int_t ldda,
-    magmaDoubleComplex_ptr db,       magma_int_t incb,
-    magmaDoubleComplex_ptr dx,
-    magma_queue_t queue,
-    magma_int_t flag );
-
 void
 magmablas_zgemv(
     magma_trans_t trans, magma_int_t m, magma_int_t n,
