@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Ahmad Abdelfattah
 */
@@ -22,7 +22,7 @@
 
 /***************************************************************************//**
     Perform FP16 matrix-matrix product, \f$ C = \alpha op(A) op(B) + \beta C \f$.
-    This routine requires CUDA 7.5 or greater. 
+    This routine requires CUDA 7.5 or greater.
 
     @param[in]
     transA  Operation op(A) to perform on matrix A.
@@ -101,7 +101,7 @@ magma_hgemm(
             &alpha, dA, int(ldda),
                     dB, int(lddb),
             &beta,  dC, int(lddc) );
-        
+
         #if CUDA_VERSION >= 9000
         // roll back to default
         cublasSetMathMode(queue->cublas_handle(), CUBLAS_DEFAULT_MATH);
@@ -118,10 +118,10 @@ magma_hgemm(
 		      hipblas_trans_const( transA ),
 		      hipblas_trans_const( transB ),
 		      int(m), int(n), int(k),
-		      (void*)&alpha, (void*)dA, HIPBLAS_R_16F, int(ldda),
-		      (void*)dB, HIPBLAS_R_16F, int(lddb),
-		      (void *)&beta,  (void*)dC, HIPBLAS_R_16F, int(lddc),
-		      HIPBLAS_R_16F,
+		      (void*)&alpha, (void*)dA, HIP_R_16F, int(ldda),
+		      (void*)dB, HIP_R_16F, int(lddb),
+		      (void *)&beta,  (void*)dC, HIP_R_16F, int(lddc),
+		      HIPBLAS_COMPUTE_16F,
 		      HIPBLAS_GEMM_DEFAULT);
     }
     else {
@@ -151,17 +151,36 @@ magma_hgemmx(
 		      hipblas_trans_const( transA ),
 		      hipblas_trans_const( transB ),
 		      int(m), int(n), int(k),
-		      (void*)&alpha, (void*)dA, HIPBLAS_R_16F, int(ldda),
-                                     (void*)dB, HIPBLAS_R_16F, int(lddb),
-		      (void*)&beta,  (void*)dC, HIPBLAS_R_32F, int(lddc),
-		      HIPBLAS_R_32F,
+		      (void*)&alpha, (void*)dA, HIP_R_16F, int(ldda),
+                                     (void*)dB, HIP_R_16F, int(lddb),
+		      (void*)&beta,  (void*)dC, HIP_R_32F, int(lddc),
+		      HIPBLAS_COMPUTE_32F,
 		      HIPBLAS_GEMM_DEFAULT);
     }
     else {
         printf("ERROR: unsupported architecture for %s \n", __func__ );
     }
 #else
-    printf("ERROR: unsupported architectre version for %s \n", __func__ );
-#endif                                                         
+    #if CUDA_VERSION >= 7500
+    magma_int_t arch = magma_getdevice_arch();
+    if( arch >= 530 ) {
+        #if CUDA_VERSION >= 9000
+        // turn on tensor cores by default
+        cublasSetMathMode(queue->cublas_handle(), CUBLAS_TENSOR_OP_MATH);
+        #endif
+        cublasGemmEx( queue->cublas_handle(),
+                      cublas_trans_const( transA ), cublas_trans_const( transB ),
+                      int(m), int(n), int(k),
+                      &alpha, dA,        CUDA_R_16F, int(ldda),
+                              dB,        CUDA_R_16F, int(lddb),
+                      &beta,  dC,        CUDA_R_32F, int(lddc),
+                      CUDA_R_32F, CUBLAS_GEMM_DEFAULT_TENSOR_OP);
+        #if CUDA_VERSION >= 9000
+        // roll back to default
+        cublasSetMathMode(queue->cublas_handle(), CUBLAS_DEFAULT_MATH);
+        #endif
+    }
+    #endif
+#endif
 }
 
