@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Mark Gates
        @precisions normal z -> s d c
@@ -13,35 +13,6 @@
 
 #define COMPLEX
 
-#define PRECISION_z
-
-/* on some platforms (i.e. hipMAGMA on ROCm stack), we define custom types
- * So, to keep the C++ compiler from giving errors, we cast arguments to internal
- * BLAS routines. The hipify script should replace `cu*Complex` with appropriate HIP types
- *
- * FUTURE READERS: If hipBLAS changes numbers to `hipblas*Complex` rather than `hip*Complex`,
- *   these will need more complicated macro if/else blocks
- */
-/*#ifdef PRECISION_z
-  #ifdef MAGMA_HAVE_HIP
-    typedef hipDoubleComplex cuDoubleComplex;
-  #else
-    typedef cuDoubleComplex cuDoubleComplex;
-  #endif
-#elif defined(PRECISION_c)
-  #ifdef MAGMA_HAVE_HIP
-    typedef hipComplex cuDoubleComplex;
-  #else
-    typedef cuFloatComplex cuDoubleComplex;
-  #endif
-#elif defined(PRECISION_d)
-  typedef double cuDoubleComplex;
-#else
-  typedef float cuDoubleComplex;
-#endif
-*/
-//#ifdef MAGMA_HAVE_CUDA
-
 // =============================================================================
 // Level 1 BLAS
 
@@ -1858,7 +1829,11 @@ magma_ztrmm(
                     cublas_diag_const( diag ),
 		    int(m), int(n),
 		    (cuDoubleComplex*)&alpha, (const cuDoubleComplex*)dA, int(ldda),
-		    (cuDoubleComplex*)dB, int(lddb) );
+		    (cuDoubleComplex*)dB, int(lddb)
+    #if (hipblasVersionMajor >= 2)
+		    , (cuDoubleComplex*)dB, int(lddb)
+    #endif
+		    );
     #else
         cublasZtrmm(
                     queue->cublas_handle(),
