@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Mark Gates
 */
@@ -26,15 +26,11 @@
 #include <mkl_service.h>
 #endif
 
-#if defined(MAGMA_WITH_ACML)
-#include <acml.h>
-#endif
-
 #include <cuda_runtime.h>
 
 // defining MAGMA_LAPACK_H is a hack to NOT include magma_lapack.h
-// via magma_internal.h here, since it conflicts with acml.h and we don't
-// need lapack here, but we want acml.h for the acmlversion() function.
+// via magma_internal.h here, since it conflicts with some vendor's
+// headers (acml.h), and we don't need lapack here.
 #define MAGMA_LAPACK_H
 
 #include "magma_internal.h"
@@ -123,26 +119,18 @@ enum {
 // count of (init - finalize) calls
 static int g_init = 0;
 
-#ifndef MAGMA_NO_V1
-    magma_queue_t* g_null_queues = NULL;
-
-    #ifdef HAVE_PTHREAD_KEY
-    pthread_key_t g_magma_queue_key;
-    #else
-    magma_queue_t g_magma_queue = NULL;
-    #endif
-#endif // MAGMA_NO_V1
-
-
 // -----------------------------------------------------------------------------
 // subset of the CUDA device properties, set by magma_init()
 struct magma_device_info
 {
     size_t memory;
-    size_t shmem_block;      // maximum shared memory per thread block in bytes
-    size_t shmem_multiproc;  // maximum shared memory per multiprocessor in bytes
-    magma_int_t cuda_arch;
-    magma_int_t multiproc_count;    // number of multiprocessors
+    size_t shmem_block;       // maximum shared memory per thread block in bytes
+    size_t shmem_block_optin; // maximum shared memory per thread block in bytes with opt-in
+    size_t shmem_multiproc;   // maximum shared memory per multiprocessor in bytes
+    magma_int_t gpu_arch;
+    magma_int_t multiproc_count;        // number of multiprocessors
+    magma_int_t num_threads_block;      // max. #threads per block
+    magma_int_t num_threads_multiproc;  // max. #threads per sm
 };
 
 int g_magma_devices_cnt = 0;
@@ -207,42 +195,28 @@ magma_init()
                     info = MAGMA_ERR_UNKNOWN;
                 }
                 else {
-                    g_magma_devices[dev].memory          = prop.totalGlobalMem;
-                    g_magma_devices[dev].shmem_block     = prop.sharedMemPerBlock;
+                    g_magma_devices[dev].memory                = prop.totalGlobalMem;
+                    g_magma_devices[dev].num_threads_block     = prop.maxThreadsPerBlock;
+                    g_magma_devices[dev].num_threads_multiproc = prop.maxThreadsPerMultiProcessor;
+                    g_magma_devices[dev].multiproc_count       = prop.multiProcessorCount;
+                    g_magma_devices[dev].shmem_block           = prop.sharedMemPerBlock;
+
+                    g_magma_devices[dev].gpu_arch          = prop.major*100 + prop.minor*10;
                     #ifdef MAGMA_HAVE_CUDA
-                    g_magma_devices[dev].cuda_arch       = prop.major*100 + prop.minor*10;
-                    g_magma_devices[dev].shmem_multiproc = prop.sharedMemPerMultiprocessor;
-                    #elif defined(MAGMA_HAVE_HIP)
-                    g_magma_devices[dev].cuda_arch       = prop.gcnArch;
-                    g_magma_devices[dev].shmem_multiproc = prop.maxSharedMemoryPerMultiProcessor;
+                    g_magma_devices[dev].shmem_multiproc   = prop.sharedMemPerMultiprocessor;
+                    // dynamic shared memory in CUDA has a special opt-in since CUDA 9
+                    #if CUDA_VERSION >= 9000
+                    g_magma_devices[dev].shmem_block_optin = prop.sharedMemPerBlockOptin;
+                    #else
+                    g_magma_devices[dev].shmem_block_optin = prop.sharedMemPerBlock;
                     #endif
 
-                    g_magma_devices[dev].multiproc_count = prop.multiProcessorCount;
+                    #elif defined(MAGMA_HAVE_HIP)
+                    g_magma_devices[dev].shmem_multiproc   = prop.maxSharedMemoryPerMultiProcessor;
+                    g_magma_devices[dev].shmem_block_optin = prop.sharedMemPerBlock;
+                    #endif
                 }
             }
-
-            #ifndef MAGMA_NO_V1
-                #ifdef HAVE_PTHREAD_KEY
-                    // create thread-specific key
-                    // currently, this is needed only for MAGMA v1 compatability
-                    // see magma_init, magmablas(Set|Get)KernelStream, magmaGetQueue
-                    info = pthread_key_create( &g_magma_queue_key, NULL );
-                    if ( info != 0 ) {
-                        info = MAGMA_ERR_UNKNOWN;
-                        goto cleanup;
-                    }
-                #endif
-
-                // ----- queues with NULL streams (for backwards compatability with MAGMA 1.x)
-                // allocate array of queues with NULL stream
-                size = max( 1, g_magma_devices_cnt ) * sizeof(magma_queue_t);
-                magma_malloc_cpu( (void**) &g_null_queues, size );
-                if ( g_null_queues == NULL ) {
-                    info = MAGMA_ERR_HOST_ALLOC;
-                    goto cleanup;
-                }
-                memset( g_null_queues, 0, size );
-            #endif // MAGMA_NO_V1
         }
 cleanup:
         g_init += 1;  // increment (init - finalize) count
@@ -279,21 +253,6 @@ magma_finalize()
                     g_magma_devices = NULL;
                 }
 
-                #ifndef MAGMA_NO_V1
-                if ( g_null_queues != NULL ) {
-                    for( int dev=0; dev < g_magma_devices_cnt; ++dev ) {
-                        magma_queue_destroy( g_null_queues[dev] );
-                        g_null_queues[dev] = NULL;
-                    }
-                    magma_free_cpu( g_null_queues );
-                    g_null_queues = NULL;
-                }
-
-                #ifdef HAVE_PTHREAD_KEY
-                    pthread_key_delete( g_magma_queue_key );
-                #endif
-                #endif // MAGMA_NO_V1
-
                 #ifdef DEBUG_MEMORY
                 magma_warn_leaks( g_pointers_dev, "device" );
                 magma_warn_leaks( g_pointers_cpu, "CPU" );
@@ -362,9 +321,9 @@ magma_print_environment()
 
 #if defined(MAGMA_HAVE_CUDA)
 
-    printf("%% Compiled with CUDA support for %.1f\n", MAGMA_CUDA_ARCH_MIN/100.);
+    printf( "%% Compiled for CUDA architectures %s\n", MAGMA_CUDA_ARCH );
 
-    // CUDA, OpenCL, OpenMP, MKL, ACML versions all printed on same line
+    // CUDA, OpenCL, OpenMP, MKL versions all printed on same line
     int cuda_runtime=0, cuda_driver=0;
     cudaError_t err;
     err = cudaDriverGetVersion( &cuda_driver );
@@ -418,13 +377,6 @@ magma_print_environment()
             mkl_get_max_threads() );
 #endif
 
-#if defined(MAGMA_WITH_ACML)
-    // ACML 4 doesn't have acml_build parameter
-    int acml_major, acml_minor, acml_patch, acml_build;
-    acmlversion( &acml_major, &acml_minor, &acml_patch, &acml_build );
-    printf( "ACML %d.%d.%d.%d ", acml_major, acml_minor, acml_patch, acml_build );
-#endif
-
     printf( "\n" );
 
     // print devices
@@ -439,10 +391,19 @@ magma_print_environment()
         check_error( err );
 
         #ifdef MAGMA_HAVE_CUDA
+        // clockRate was deprecated in cudaDeviceProp in CUDA 12, removed in CUDA 13;
+        // use cudaDeviceGetAttribute to avoid deprecation warning
+        int clock_khz;
+        #if CUDART_VERSION >= 12000
+        cudaDeviceGetAttribute( &clock_khz, cudaDevAttrClockRate, dev );
+        #else
+        clock_khz = prop.clockRate;
+        #endif
+
         printf( "%% device %d: %s, %.1f MHz clock, %.1f MiB memory, capability %d.%d\n",
                 dev,
                 prop.name,
-                prop.clockRate / 1000.,
+                clock_khz / 1000.,
                 prop.totalGlobalMem / (1024.*1024.),
                 prop.major,
                 prop.minor );
@@ -459,12 +420,12 @@ magma_print_environment()
         #endif
 
         #ifdef MAGMA_HAVE_HIP
-        printf( "%% device %d: %s, %.1f MHz clock, %.1f MiB memory, gcn arch %d\n",
+        printf( "%% device %d: %s, %.1f MHz clock, %.1f MiB memory, gcn arch %s\n",
                 dev,
                 prop.name,
                 prop.clockRate / 1000.,
                 prop.totalGlobalMem / (1024.*1024.),
-                prop.gcnArch );
+                prop.gcnArchName );
         #endif
     }
 
@@ -528,7 +489,11 @@ magma_is_devptr( const void* A )
                   #endif
 
                 #elif defined(MAGMA_HAVE_HIP)
-                return (attr.memoryType == hipMemoryTypeDevice);
+		  #if HIP_VERSION_MAJOR >= 6
+		    return (attr.type == hipMemoryTypeDevice);
+		  #else
+                    return (attr.memoryType == hipMemoryTypeDevice);
+		  #endif
                 #endif
             }
             else if ( err == cudaErrorInvalidValue ) {
@@ -571,7 +536,7 @@ magma_getdevice_arch()
         fprintf( stderr, "Error in %s: MAGMA not initialized (call magma_init() first) or bad device\n", __func__ );
         return 0;
     }
-    return g_magma_devices[dev].cuda_arch;
+    return g_magma_devices[dev].gpu_arch;
 }
 
 
@@ -674,6 +639,52 @@ magma_getdevice_multiprocessor_count()
     return g_magma_devices[dev].multiproc_count;
 }
 
+/***************************************************************************//**
+    Returns the maximum number of threads per block for the current device.
+    This requires magma_init() to be called first to cache the information.
+
+    @return the maximum number of threads per block for the current device.
+
+    @ingroup magma_device
+*******************************************************************************/
+extern "C" magma_int_t
+magma_getdevice_num_threads_block()
+{
+    int dev;
+    cudaError_t err;
+    err = cudaGetDevice( &dev );
+    check_error( err );
+    MAGMA_UNUSED( err );
+    if ( g_magma_devices == NULL || dev < 0 || dev >= g_magma_devices_cnt ) {
+        fprintf( stderr, "Error in %s: MAGMA not initialized (call magma_init() first) or bad device\n", __func__ );
+        return 0;
+    }
+    return g_magma_devices[dev].num_threads_block;
+}
+
+/***************************************************************************//**
+    Returns the maximum number of threads per multiprocessor for the current device.
+    This requires magma_init() to be called first to cache the information.
+
+    @return the maximum number of threads per multiprocessor for the current device.
+
+    @ingroup magma_device
+*******************************************************************************/
+extern "C" magma_int_t
+magma_getdevice_num_threads_multiprocessor()
+{
+    int dev;
+    cudaError_t err;
+    err = cudaGetDevice( &dev );
+    check_error( err );
+    MAGMA_UNUSED( err );
+    if ( g_magma_devices == NULL || dev < 0 || dev >= g_magma_devices_cnt ) {
+        fprintf( stderr, "Error in %s: MAGMA not initialized (call magma_init() first) or bad device\n", __func__ );
+        return 0;
+    }
+    return g_magma_devices[dev].num_threads_multiproc;
+}
+
 /***************************************************************************//**
     Returns the maximum shared memory per block (in bytes) for the current device.
     This requires magma_init() to be called first to cache the information.
@@ -697,6 +708,30 @@ magma_getdevice_shmem_block()
     return g_magma_devices[dev].shmem_block;
 }
 
+/***************************************************************************//**
+    Returns the maximum shared memory per block (in bytes) with a special opt-in
+    for the current device.
+    This requires magma_init() to be called first to cache the information.
+
+    @return the maximum shared memory per block (in bytes) with a special opt-in
+    for the current device.
+
+    @ingroup magma_device
+*******************************************************************************/
+extern "C" size_t
+magma_getdevice_shmem_block_optin()
+{
+    int dev;
+    cudaError_t err;
+    err = cudaGetDevice( &dev );
+    check_error( err );
+    MAGMA_UNUSED( err );
+    if ( g_magma_devices == NULL || dev < 0 || dev >= g_magma_devices_cnt ) {
+        fprintf( stderr, "Error in %s: MAGMA not initialized (call magma_init() first) or bad device\n", __func__ );
+        return 0;
+    }
+    return g_magma_devices[dev].shmem_block_optin;
+}
 
 /***************************************************************************//**
     Returns the maximum shared memory multiprocessor (in bytes) for the current device.
