@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Mark Gates
        @precisions normal z -> s d c
@@ -13,35 +13,6 @@
 
 #define COMPLEX
 
-#define PRECISION_z
-
-/* on some platforms (i.e. hipMAGMA on ROCm stack), we define custom types
- * So, to keep the C++ compiler from giving errors, we cast arguments to internal
- * BLAS routines. The hipify script should replace `cu*Complex` with appropriate HIP types
- *
- * FUTURE READERS: If hipBLAS changes numbers to `hipblas*Complex` rather than `hip*Complex`,
- *   these will need more complicated macro if/else blocks
- */
-/*#ifdef PRECISION_z
-  #ifdef MAGMA_HAVE_HIP
-    typedef hipDoubleComplex hipblasDoubleComplex;
-  #else
-    typedef hipblasDoubleComplex hipblasDoubleComplex;
-  #endif
-#elif defined(PRECISION_c)
-  #ifdef MAGMA_HAVE_HIP
-    typedef hipComplex hipblasDoubleComplex;
-  #else
-    typedef hipblasFloatComplex hipblasDoubleComplex;
-  #endif
-#elif defined(PRECISION_d)
-  typedef double hipblasDoubleComplex;
-#else
-  typedef float hipblasDoubleComplex;
-#endif
-*/
-//#ifdef MAGMA_HAVE_CUDA
-
 // =============================================================================
 // Level 1 BLAS
 
@@ -72,7 +43,7 @@ magma_izamax(
     magma_queue_t queue )
 {
     int result; /* not magma_int_t */
-    hipblasIzamax( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), &result );
+    hipblasIzamax( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), &result );
     return result;
 }
 
@@ -104,7 +75,7 @@ magma_izamin(
     magma_queue_t queue )
 {
     int result; /* not magma_int_t */
-    hipblasIzamin( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), &result );
+    hipblasIzamin( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), &result );
     return result;
 }
 
@@ -136,7 +107,7 @@ magma_dzasum(
     magma_queue_t queue )
 {
     double result;
-    hipblasDzasum( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), &result );
+    hipblasDzasum( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), &result );
     return result;
 }
 
@@ -178,7 +149,7 @@ magma_zaxpy(
     magmaDoubleComplex_ptr       dy, magma_int_t incy,
     magma_queue_t queue )
 {
-    hipblasZaxpy( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy) );
+    hipblasZaxpy( queue->hipblas_handle(), int(n), (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy) );
 }
 
 
@@ -215,7 +186,7 @@ magma_zcopy(
     magmaDoubleComplex_ptr       dy, magma_int_t incy,
     magma_queue_t queue )
 {
-    hipblasZcopy( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy) );
+    hipblasZcopy( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy) );
 }
 
 
@@ -254,7 +225,7 @@ magmaDoubleComplex magma_zdotc(
     magma_queue_t queue )
 {
     magmaDoubleComplex result;
-    hipblasZdotc( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy), (hipblasDoubleComplex*)&result );
+    hipblasZdotc( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy), (hipDoubleComplex*)&result );
     return result;
 }
 #endif // COMPLEX
@@ -294,7 +265,7 @@ magmaDoubleComplex magma_zdotu(
     magma_queue_t queue )
 {
     magmaDoubleComplex result;
-    hipblasZdotu( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy), (hipblasDoubleComplex*)&result );
+    hipblasZdotu( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy), (hipDoubleComplex*)&result );
     return result;
 }
 
@@ -326,7 +297,7 @@ magma_dznrm2(
     magma_queue_t queue )
 {
     double result;
-    hipblasDznrm2( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), &result );
+    hipblasDznrm2( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), &result );
     return result;
 }
 
@@ -375,7 +346,7 @@ magma_zrot(
     double c, magmaDoubleComplex s,
     magma_queue_t queue )
 {
-    hipblasZrot( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy), &c, (hipblasDoubleComplex*)&s );
+    hipblasZrot( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy), &c, (hipDoubleComplex*)&s );
 }
 
 
@@ -424,7 +395,7 @@ magma_zdrot(
     double c, double s,
     magma_queue_t queue )
 {
-    hipblasZdrot( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy), &c, &s );
+    hipblasZdrot( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy), &c, &s );
 }
 #endif // COMPLEX
 
@@ -469,7 +440,7 @@ magma_zrotg(
     double             *c, magmaDoubleComplex *s,
     magma_queue_t queue )
 {
-    hipblasZrotg( queue->hipblas_handle(), (hipblasDoubleComplex*)a, (hipblasDoubleComplex*)b, c, (hipblasDoubleComplex*)s );
+    hipblasZrotg( queue->hipblas_handle(), (hipDoubleComplex*)a, (hipDoubleComplex*)b, c, (hipDoubleComplex*)s );
 }
 
 
@@ -539,7 +510,7 @@ magma_zscal(
     magmaDoubleComplex_ptr dx, magma_int_t incx,
     magma_queue_t queue )
 {
-    hipblasZscal( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx) );
+    hipblasZscal( queue->hipblas_handle(), int(n), (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx) );
 }
 
 
@@ -573,7 +544,7 @@ magma_zdscal(
     magmaDoubleComplex_ptr dx, magma_int_t incx,
     magma_queue_t queue )
 {
-    hipblasZdscal( queue->hipblas_handle(), int(n), &alpha, (hipblasDoubleComplex*)dx, int(incx) );
+    hipblasZdscal( queue->hipblas_handle(), int(n), &alpha, (hipDoubleComplex*)dx, int(incx) );
 }
 #endif // COMPLEX
 
@@ -611,7 +582,7 @@ magma_zswap(
     magmaDoubleComplex_ptr dy, magma_int_t incy,
     magma_queue_t queue )
 {
-    hipblasZswap( queue->hipblas_handle(), int(n), (hipblasDoubleComplex*)dx, int(incx), (hipblasDoubleComplex*)dy, int(incy) );
+    hipblasZswap( queue->hipblas_handle(), int(n), (hipDoubleComplex*)dx, int(incx), (hipDoubleComplex*)dy, int(incy) );
 }
 
 
@@ -683,9 +654,9 @@ magma_zgemv(
         queue->hipblas_handle(),
         hipblas_trans_const( transA ),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dx, int(incx),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dy, int(incy) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dx, int(incx),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dy, int(incy) );
 }
 
 
@@ -741,9 +712,9 @@ magma_zgerc(
     hipblasZgerc(
         queue->hipblas_handle(),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dy, int(incy),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dy, int(incy),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 #endif // COMPLEX
 
@@ -799,9 +770,9 @@ magma_zgeru(
     hipblasZgeru(
         queue->hipblas_handle(),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dy, int(incy),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dy, int(incy),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 
 
@@ -864,9 +835,9 @@ magma_zhemv(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dx, int(incx),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dy, int(incy) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dx, int(incx),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dy, int(incy) );
 }
 #endif // COMPLEX
 
@@ -918,8 +889,8 @@ magma_zher(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (const double*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (const double*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 #endif // COMPLEX
 
@@ -979,9 +950,9 @@ magma_zher2(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dy, int(incy),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dy, int(incy),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 #endif // COMPLEX
 
@@ -1044,9 +1015,9 @@ magma_zsymv(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dx, int(incx),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dy, int(incy) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dx, int(incx),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dy, int(incy) );
 }
 
 
@@ -1096,8 +1067,8 @@ magma_zsyr(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 
 
@@ -1155,9 +1126,9 @@ magma_zsyr2(
         queue->hipblas_handle(),
         hipblas_uplo_const( uplo ),
         int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dx, int(incx),
-                (hipblasDoubleComplex*)dy, int(incy),
-                (hipblasDoubleComplex*)dA, int(ldda) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dx, int(incx),
+                (hipDoubleComplex*)dy, int(incy),
+                (hipDoubleComplex*)dA, int(ldda) );
 }
 
 
@@ -1213,8 +1184,8 @@ magma_ztrmv(
         hipblas_trans_const( trans ),
         hipblas_diag_const( diag ),
         int(n),
-        (hipblasDoubleComplex*)dA, int(ldda),
-        (hipblasDoubleComplex*)dx, int(incx) );
+        (hipDoubleComplex*)dA, int(ldda),
+        (hipDoubleComplex*)dx, int(incx) );
 }
 
 
@@ -1271,8 +1242,8 @@ magma_ztrsv(
         hipblas_trans_const( trans ),
         hipblas_diag_const( diag ),
         int(n),
-        (hipblasDoubleComplex*)dA, int(ldda),
-        (hipblasDoubleComplex*)dx, int(incx) );
+        (hipDoubleComplex*)dA, int(ldda),
+        (hipDoubleComplex*)dx, int(incx) );
 }
 
 
@@ -1348,9 +1319,9 @@ magma_zgemm(
         hipblas_trans_const( transA ),
         hipblas_trans_const( transB ),
         int(m), int(n), int(k),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 
 #ifdef COMPLEX
@@ -1422,9 +1393,9 @@ magma_zhemm(
         hipblas_side_const( side ),
         hipblas_uplo_const( uplo ),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 #endif // COMPLEX
 
@@ -1491,8 +1462,8 @@ magma_zherk(
         hipblas_uplo_const( uplo ),
         hipblas_trans_const( trans ),
         int(n), int(k),
-        &alpha, (hipblasDoubleComplex*)dA, int(ldda),
-        &beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        &alpha, (hipDoubleComplex*)dA, int(ldda),
+        &beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 #endif // COMPLEX
 
@@ -1568,9 +1539,9 @@ magma_zher2k(
         hipblas_uplo_const( uplo ),
         hipblas_trans_const( trans ),
         int(n), int(k),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb),
-        &beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb),
+        &beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 #endif // COMPLEX
 
@@ -1643,9 +1614,9 @@ magma_zsymm(
         hipblas_side_const( side ),
         hipblas_uplo_const( uplo ),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 
 
@@ -1710,8 +1681,8 @@ magma_zsyrk(
         hipblas_uplo_const( uplo ),
         hipblas_trans_const( trans ),
         int(n), int(k),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 
 
@@ -1785,9 +1756,9 @@ magma_zsyr2k(
         hipblas_uplo_const( uplo ),
         hipblas_trans_const( trans ),
         int(n), int(k),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb),
-        (hipblasDoubleComplex*)&beta,  (hipblasDoubleComplex*)dC, int(lddc) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb),
+        (hipDoubleComplex*)&beta,  (hipDoubleComplex*)dC, int(lddc) );
 }
 
 
@@ -1857,8 +1828,12 @@ magma_ztrmm(
                     hipblas_trans_const( trans ),
                     hipblas_diag_const( diag ),
 		    int(m), int(n),
-		    (hipblasDoubleComplex*)&alpha, (const hipblasDoubleComplex*)dA, int(ldda),
-		    (hipblasDoubleComplex*)dB, int(lddb) );
+		    (hipDoubleComplex*)&alpha, (const hipDoubleComplex*)dA, int(ldda),
+		    (hipDoubleComplex*)dB, int(lddb)
+    #if (hipblasVersionMajor >= 2)
+		    , (hipDoubleComplex*)dB, int(lddb)
+    #endif
+		    );
     #else
         hipblasZtrmm(
                     queue->hipblas_handle(),
@@ -1939,8 +1914,8 @@ magma_ztrsm(
         hipblas_trans_const( trans ),
         hipblas_diag_const( diag ),
         int(m), int(n),
-        (hipblasDoubleComplex*)&alpha, (hipblasDoubleComplex*)dA, int(ldda),
-                (hipblasDoubleComplex*)dB, int(lddb) );
+        (hipDoubleComplex*)&alpha, (hipDoubleComplex*)dA, int(ldda),
+                (hipDoubleComplex*)dB, int(lddb) );
 }
 
 //#endif // MAGMA_HAVE_CUDA
