@@ -2,11 +2,11 @@
 #define SGEMM_FERMI_KERNELS_H
 
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Jakub Kurzak
        @author Stan Tomov
