@@ -1,16 +1,16 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Jakub Kurzak
        @author Stan Tomov
        @author Mark Gates
        @author Azzam Haidar
        @author Ahmad Abdelfattah
-       
+
 */
 
 #include "magma_internal.h"
@@ -29,18 +29,18 @@
     Purpose
     -------
     CGEMM performs one of the matrix-matrix operations
-    
+
         C = alpha*op( A )*op( B ) + beta*C,
-    
+
     where op( X ) is one of
-    
+
         op( X ) = X      or
         op( X ) = X**T   or
         op( X ) = X**H,
-    
+
     alpha and beta are scalars, and A, B and C are matrices, with
     op( A ) an m by k matrix, op( B ) a k by n matrix and C an m by n matrix.
-    
+
     Parameters
     ----------
     @param[in]
@@ -50,7 +50,7 @@
       -      = MagmaNoTrans:   op( A ) = A.
       -      = MagmaTrans:     op( A ) = A**T.
       -      = MagmaConjTrans: op( A ) = A**H.
-    
+
     @param[in]
     transB  magma_trans_t.
             On entry, transB specifies the form of op( B ) to be used in
@@ -58,28 +58,28 @@
       -      = MagmaNoTrans:   op( B ) = B.
       -      = MagmaTrans:     op( B ) = B**T.
       -      = MagmaConjTrans: op( B ) = B**H.
-    
+
     @param[in]
     m       INTEGER.
             On entry,  M  specifies  the number  of rows  of the  matrix
             op( A )  and of the  matrix C.  M  must  be at least  zero.
-    
+
     @param[in]
     n       INTEGER.
             On entry,  N  specifies the number  of columns of the matrix
             op( B ) and the number of columns of the matrix C. N must be
             at least zero.
-    
+
     @param[in]
     k       INTEGER.
             On entry,  K  specifies  the number of columns of the matrix
             op( A ) and the number of rows of the matrix op( B ). K must
             be at least  zero.
-    
+
     @param[in]
     alpha   COMPLEX
             On entry, ALPHA specifies the scalar alpha.
-    
+
     @param[in]
     dA_array      Array of pointers, dimension (batchCount).
              Each is a COMPLEX array A of DIMENSION ( ldda, ka ), where ka is
@@ -88,14 +88,22 @@
              part of the array A must contain the matrix A, otherwise
              the leading  k by m  part of the array A must contain  the
              matrix A.
-    
+
     @param[in]
     ldda    INTEGER.
             On entry, ldda specifies the first dimension of each array A as
             declared in the calling (sub) program. When  transA = MagmaNoTrans
             then ldda must be at least  max( 1, m ), otherwise  ldda must be at
             least  max( 1, k ).
-    
+
+    @param[in]
+    Ai   INTEGER
+            Row offset for all 'A' matrices.
+
+    @param[in]
+    Aj   INTEGER
+            Column offset for all 'A' matrices.
+
     @param[in]
     dB_array      Array of pointers, dimension (batchCount).
              Each is a COMPLEX array B of DIMENSION ( lddb, kb ), where kb is
@@ -104,19 +112,27 @@
              part of the array B must contain the matrix B, otherwise
              the leading  n by k  part of the array B must contain  the
              matrix B.
-    
+
+    @param[in]
+    Bi   INTEGER
+            Row offset for all 'B' matrices.
+
+    @param[in]
+    Bj   INTEGER
+            Column offset for all 'B' matrices.
+
     @param[in]
     lddb    INTEGER.
             On entry, lddb specifies the first dimension of each array B as
             declared in the calling (sub) program. When  transB = MagmaNoTrans
             then lddb must be at least  max( 1, k ), otherwise lddb must be at
             least  max( 1, n ).
-    
+
     @param[in]
     beta    COMPLEX.
             On entry,  BETA  specifies the scalar  beta.  When  BETA  is
             supplied as zero then C need not be set on input.
-    
+
     @param[in,out]
     dC_array      Array of pointers, dimension (batchCount).
              Each is a COMPLEX array C of DIMENSION ( lddc, n ).
@@ -125,37 +141,21 @@
              case C need not be set on entry.
              On exit, each array  C  is overwritten by the  m by n  matrix
              ( alpha*op( A )*op( B ) + beta*C ).
-    
+
+    @param[in]
+    Ci   INTEGER
+            Row offset for all 'C' matrices.
+
+    @param[in]
+    Cj   INTEGER
+            Column offset for all 'C' matrices.
+
     @param[in]
     lddc    INTEGER.
             On entry, lddc specifies the first dimension of each array C as
             declared in  the  calling  (sub)  program.   lddc  must  be  at
             least max( 1, m ).
-    
-    @param[in]
-    Ai   INTEGER
-            Row offset for all 'A' matrices.
-    
-    @param[in]
-    Aj   INTEGER
-            Column offset for all 'A' matrices.
-    
-    @param[in]
-    Bi   INTEGER
-            Row offset for all 'B' matrices.
-    
-    @param[in]
-    Bj   INTEGER
-            Column offset for all 'B' matrices.
-    
-    @param[in]
-    Ci   INTEGER
-            Row offset for all 'C' matrices.
-    
-    @param[in]
-    Cj   INTEGER
-            Column offset for all 'C' matrices.
-    
+
     @param[in]
     batchCount  INTEGER
                 The number of matrices to operate on.
@@ -194,28 +194,22 @@ magmablas_cgemm_batched_core(
         info = -10;
     else if ( lddc < m )
         info = -13;
-    
+
     if (info != 0) {
         magma_xerbla( __func__, -(info) );
         return;  //info;
     }
-    
-    magma_int_t arch = magma_getdevice_arch();
-    if ( arch < 200  ) {
-        printf("arch < 200 not supported \n"); // TODO call hipblas
-        return;
-    }
-    
+
     if ( m <= 0 || n <= 0 || k <= 0 )
         return;
 
-    // special case for small square matrices 
+    // special case for small square matrices
     if( m == n && n == k && m <= magma_get_cgemm_batched_smallsq_limit(m)){
         magmablas_cgemm_batched_smallsq(
-                transA, transB, 
-                m, n, k, 
-                alpha, dA_array, Ai, Aj, ldda, 
-                       dB_array, Bi, Bj, lddb, 
+                transA, transB,
+                m, n, k,
+                alpha, dA_array, Ai, Aj, ldda,
+                       dB_array, Bi, Bj, lddb,
                 beta,  dC_array, Ci, Cj, lddc, batchCount, queue );
         return;
     }
@@ -300,13 +294,37 @@ magmablas_cgemm_batched_core(
             break;
         case 3: // tn
             {
-                if (k < 16)
-                {
+                if(m == n && m < 32) {
+                    if(m <= 8) {
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 8, 8, 32, 1, 8, 8, 8, 8, 0, 0>
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else if(m <= 16) {
+                        gemm_template_batched_tn<magmaFloatComplex, 16, 4, 16, 16, 16, 1, 16, 4, 16, 4, 0, 0>
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else if (m <= 24) {
+                        #ifdef MAGMA_HAVE_HIP
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 24, 24,  8, 1, 8, 8, 8, 8, 0, 0>
+                        #else
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 24, 24, 16, 1, 8, 8, 8, 8, 0, 0>
+                        #endif
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else {
+                        #ifdef MAGMA_HAVE_HIP
+                        gemm_template_batched_tn<magmaFloatComplex,  8, 8, 32, 32,  8, 1,  8, 8,  8, 8, 0, 0>
+                        #else
+                        gemm_template_batched_tn<magmaFloatComplex, 16, 8, 32, 32, 64, 1, 16, 8, 16, 8, 0, 0>
+                        #endif
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                }
+                else if (k < 16) {
                     gemm_template_batched_tn<magmaFloatComplex, version(TN,282), 0, 0>
                     (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
                 }
-                else
-                {
+                else {
                     gemm_template_batched_tn<magmaFloatComplex, version(TN,505), 0, 0>
                     (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
                 }
@@ -314,13 +332,37 @@ magmablas_cgemm_batched_core(
             break;
         case 6: // cn
             {
-                if (k < 16)
-                {
+                if(m == n && m < 32) {
+                    if(m <= 8) {
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 8, 8, 32, 1, 8, 8, 8, 8, 1, 0>
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else if(m <= 16) {
+                        gemm_template_batched_tn<magmaFloatComplex, 16, 4, 16, 16, 16, 1, 16, 4, 16, 4, 1, 0>
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else if (m <= 24) {
+                        #ifdef MAGMA_HAVE_HIP
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 24, 24,  8, 1, 8, 8, 8, 8, 1, 0>
+                        #else
+                        gemm_template_batched_tn<magmaFloatComplex, 8, 8, 24, 24, 16, 1, 8, 8, 8, 8, 1, 0>
+                        #endif
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                    else {
+                        #ifdef MAGMA_HAVE_HIP
+                        gemm_template_batched_tn<magmaFloatComplex,  8, 8, 32, 32,  8, 1,  8, 8,  8, 8, 1, 0>
+                        #else
+                        gemm_template_batched_tn<magmaFloatComplex, 16, 8, 32, 32, 64, 1, 16, 8, 16, 8, 1, 0>
+                        #endif
+                        (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
+                    }
+                }
+                else if (k < 16) {
                     gemm_template_batched_tn<magmaFloatComplex, version(TN,282), 1, 0>
                     (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
                 }
-                else
-                {
+                else {
                     gemm_template_batched_tn<magmaFloatComplex, version(TN,505), 1, 0>
                     (m, n, k, dA_array, ldda, dB_array, lddb, dC_array, lddc, alpha, beta, Ai, Aj, Bi, Bj, Ci, Cj, batchCount, queue);
                 }
