@@ -1,10 +1,10 @@
 #include "hip/hip_runtime.h"
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Azzam Haidar
        @author Tingxing Dong
@@ -36,6 +36,8 @@ izamax_kernel_batched(
     int tx = threadIdx.x;
     const magmaDoubleComplex *x = x_array[batchid] + xj * lda + xi;
     magma_int_t *ipiv           = ipiv_array[batchid] + ipiv_i;
+    magma_int_t *info = &info_array[batchid];
+    int linfo = ( (gbstep+step) == 0) ? 0 : *info;
 
     double *shared_x = sdata;
     int *shared_idx = (int*)(shared_x + zamax);
@@ -44,9 +46,8 @@ izamax_kernel_batched(
 
     if (tx == 0) {
         *ipiv  = shared_idx[0] + step + 1; // Fortran Indexing & adjust ipiv
-        if (shared_x[0] == MAGMA_D_ZERO) {
-            info_array[batchid] = shared_idx[0] + step + gbstep + 1;
-        }
+        linfo  = ( shared_x[0] == MAGMA_D_ZERO && linfo == 0) ? (shared_idx[0]+step+gbstep+1) : linfo;
+        *info = (magma_int_t)linfo;
     }
 }
 
@@ -63,13 +64,13 @@ izamax_kernel_native(
 
     double *shared_x = sdata;
     int *shared_idx = (int*)(shared_x + zamax);
+    int linfo = ( (gbstep+step) == 0) ? 0 : *info;
 
     izamax_devfunc(length, x, incx, shared_x, shared_idx);
     if (tx == 0) {
         *ipiv  = shared_idx[0] + step + 1; // Fortran Indexing
-        if (shared_x[0] == MAGMA_D_ZERO) {
-            (*info) = shared_idx[0] + step + gbstep + 1;
-        }
+        linfo  = ( shared_x[0] == MAGMA_D_ZERO && linfo == 0) ? (shared_idx[0]+step+gbstep+1) : linfo;
+        *info = (magma_int_t)linfo;
     }
 }
 
@@ -209,7 +210,7 @@ magma_izamax_native(
         hipblasGetPointerMode(queue->hipblas_handle(), &ptr_mode);
         hipblasSetPointerMode(queue->hipblas_handle(), HIPBLAS_POINTER_MODE_DEVICE);
 
-        hipblasIzamax(queue->hipblas_handle(), length, (const hipblasDoubleComplex*)x, 1, (int*)(ipiv));
+        hipblasIzamax(queue->hipblas_handle(), length, (const hipDoubleComplex*)x, 1, (int*)(ipiv));
         hipLaunchKernelGGL(magma_zpivcast, dim3(1), dim3(1), 0, queue->hip_stream() ,  ipiv );
 
         hipblasSetPointerMode(queue->hipblas_handle(), ptr_mode);
@@ -231,7 +232,11 @@ void zswap_kernel_batched(
     magmaDoubleComplex *x = x_array[batchid] + xj * incx + xi;
     magma_int_t *ipiv = ipiv_array[batchid] + xi;
 
-    zswap_device(n, x, incx, step, ipiv);
+    magmaDoubleComplex* xpiv = x_array[batchid] + (xj+step) * incx + (xi+step);
+    double rx_abs = fabs( MAGMA_Z_REAL(xpiv[0]) ) + fabs( MAGMA_Z_IMAG(xpiv[0]) );
+    if( rx_abs != MAGMA_D_ZERO) {
+        zswap_device(n, x, incx, step, ipiv);
+    }
 }
 
 
@@ -719,10 +724,11 @@ zcomputecolumn_kernel_shared_batched( int m, int paneloffset, int step,
     __shared__ double  shared_x[zamax];
     __shared__ int     shared_idx[zamax];
     __shared__ magmaDoubleComplex alpha;
-    int tid = threadIdx.x;
+    int tid   = threadIdx.x;
+    int linfo = ((gboff + gbstep) == 0 ) ? 0 : info_array[batchid];
 
     // checkinfo to avoid computation of the singular matrix
-    if (info_array[batchid] != 0 ) return;
+    //if (info_array[batchid] != 0 ) return;
 
 
     int nchunk = magma_ceildiv( m, MAX_NTHREADS );
@@ -739,7 +745,7 @@ zcomputecolumn_kernel_shared_batched( int m, int paneloffset, int step,
         __syncthreads();
     }
 
-    // if ( tid < (m-step) ) // DO NO TPUT THE IF CONDITION HERE SINCE izamax_devfunc HAS __syncthreads INSIDE.
+    // if ( tid < (m-step) ) // DO NO PUT THE IF CONDITION HERE SINCE izamax_devfunc HAS __syncthreads INSIDE.
     // So let all htreads call this routine it will handle correctly based on the size
     // note that izamax need only 128 threads, s
     izamax_devfunc(m-step, shared_A+step, 1, shared_x, shared_idx);
@@ -747,16 +753,21 @@ zcomputecolumn_kernel_shared_batched( int m, int paneloffset, int step,
         ipiv[gboff]  = shared_idx[0] + gboff + 1; // Fortran Indexing
         alpha = shared_A[shared_idx[0]+step];
         //printf("@ step %d ipiv=%d where gboff=%d  shared_idx %d alpha %5.3f\n",step,ipiv[gboff],gboff,shared_idx[0],alpha);
-        if (shared_x[0] == MAGMA_D_ZERO) {
-            info_array[batchid] = shared_idx[0] + gboff + gbstep + 1;
-        }
+        linfo  = ( shared_x[0] == MAGMA_D_ZERO && linfo == 0) ? (shared_idx[0]+gboff+gbstep+1) : linfo;
+        info_array[batchid] = (magma_int_t)linfo;
+        //if (shared_x[0] == MAGMA_D_ZERO) {
+        //    info_array[batchid] = shared_idx[0] + gboff + gbstep + 1;
+        //}
     }
     __syncthreads();
-    if (shared_x[0] == MAGMA_D_ZERO) return;
-    __syncthreads();
 
-    // DO NO PUT THE IF CONDITION HERE SINCE izamax_devfunc HAS __syncthreads INSIDE.
-    zscal5_device( m-step, shared_A+step, alpha);
+    //if (shared_x[0] == MAGMA_D_ZERO) return;
+    //__syncthreads();
+
+    if( shared_x[0] != MAGMA_D_ZERO ) {
+        zscal5_device( m-step, shared_A+step, alpha);
+        // there is sync at the end of zscal5_device
+    }
 
     // put back the pivot that has been scaled with itself menaing =1
     if (tid == 0)  shared_A[shared_idx[0] + step] = alpha;
@@ -808,26 +819,101 @@ magma_int_t magma_zcomputecolumn_batched( magma_int_t m, magma_int_t paneloffset
 }
 
 /******************************************************************************/
-template<int WIDTH>
+template<int N>
 __global__ void
-zgetf2_fused_batched_kernel( int m,
+zgetf2_fused_kernel_batched( int m,
                            magmaDoubleComplex** dA_array, int ai, int aj, int ldda,
                            magma_int_t** dipiv_array, magma_int_t* info_array, int batchCount)
 {
-    // different indices per branch
+    const int tx = threadIdx.x;
     const int batchid = blockIdx.x * blockDim.y + threadIdx.y;
-    //const int batchid = blockIdx.z * blockDim.y + threadIdx.y;
+    if(batchid >= batchCount)return;
 
+    int rowid, gbstep = aj;
+    int linfo = (gbstep == 0) ? 0 : info_array[batchid];
+
+    // shared memory workspace
     HIP_DYNAMIC_SHARED( magmaDoubleComplex, zdata)
-
     magmaDoubleComplex* swork = (magmaDoubleComplex*)zdata;
-     if(batchid >= batchCount)return;
-     zgetf2_fused_device<WIDTH>(
-             m, dA_array[batchid] + aj * ldda + ai, ldda,
+
+    // read
+    magmaDoubleComplex* dA = dA_array[batchid] + aj * ldda + ai;
+    magmaDoubleComplex  rA[N] = {MAGMA_Z_ZERO};
+    #pragma unroll
+    for(int i = 0; i < N; i++){
+        rA[i] = dA[ i * ldda + tx ];
+    }
+
+     zgetf2_fused_device<N>(
+             m, min(m,N), rA,
              dipiv_array[batchid] + ai,
-             swork, &info_array[batchid], aj);
+             swork, linfo, gbstep, rowid);
+
+    // write
+    if(tx == 0){
+        info_array[batchid] = (magma_int_t)( linfo );
+    }
+
+    #pragma unroll
+    for(int i = 0; i < N; i++){
+        dA[ i * ldda + rowid ] = rA[i];
+    }
+
 }
 
+/******************************************************************************/
+template<int N>
+static magma_int_t
+magma_zgetf2_fused_kernel_driver_batched(
+    magma_int_t m,
+    magmaDoubleComplex **dA_array, magma_int_t ai, magma_int_t aj, magma_int_t ldda,
+    magma_int_t **dipiv_array,
+    magma_int_t *info_array, magma_int_t batchCount,
+    magma_queue_t queue )
+{
+    magma_int_t arginfo = 0;
+    magma_device_t device;
+    magma_getdevice( &device );
+
+    magma_int_t ntcol = (m >= 32)? 1 : (32/m);
+    int shmem = 0, shmem_max = 0;   // not magma_int_t (causes problems with 64bit builds)
+    shmem += N * sizeof(magmaDoubleComplex);
+    shmem += m * sizeof(double);
+    shmem += m * sizeof(int);    // not magma_int_t
+    shmem += N * sizeof(int);    // not magma_int_t
+    shmem *= ntcol;
+
+    dim3 grid(magma_ceildiv(batchCount,ntcol), 1, 1);
+    dim3 threads(m, ntcol, 1);
+
+    // get max. dynamic shared memory on the GPU
+    int nthreads_max, nthreads = m * ntcol;
+    hipDeviceGetAttribute (&nthreads_max, hipDeviceAttributeMaxThreadsPerBlock, device);
+    #if CUDA_VERSION >= 9000
+    hipDeviceGetAttribute (&shmem_max, cudaDevAttrMaxSharedMemoryPerBlockOptin, device);
+    if (shmem <= shmem_max) {
+        cudaFuncSetAttribute(zgetf2_fused_kernel_batched<N>, cudaFuncAttributeMaxDynamicSharedMemorySize, shmem);
+    }
+    #else
+    hipDeviceGetAttribute (&shmem_max, hipDeviceAttributeMaxSharedMemoryPerBlock, device);
+    #endif    // CUDA_VERSION >= 9000
+
+    magma_int_t total_threads = nthreads * ntcol;
+    if ( total_threads > nthreads_max || shmem > shmem_max ) {
+        //printf("error: kernel %s requires too many threads or too much shared memory\n", __func__);
+        arginfo = -100;
+        return arginfo;
+    }
+
+    void *kernel_args[] = {&m, &dA_array, &ai, &aj, &ldda, &dipiv_array, &info_array, &batchCount};
+    hipError_t e = hipLaunchKernel((void*)zgetf2_fused_kernel_batched<N>, grid, threads, kernel_args, shmem, queue->hip_stream());
+    if( e != hipSuccess ) {
+        //printf("error in %s : failed to launch kernel %s\n", __func__, hipGetErrorString(e));
+        arginfo = -100;
+    }
+
+    return arginfo;
+}
 
 /***************************************************************************//**
     Purpose
@@ -911,63 +997,53 @@ magma_zgetf2_fused_batched(
     magma_int_t *info_array, magma_int_t batchCount,
     magma_queue_t queue)
 {
-    if(m < 0 || m > ZGETF2_FUSED_BATCHED_MAX_ROWS) {
-        fprintf( stderr, "%s: m = %4lld not supported, must be between 0 and %4lld\n",
-                 __func__, (long long) m, (long long) ZGETF2_FUSED_BATCHED_MAX_ROWS);
-        return -1;
+    magma_int_t info = 0;
+    if(m < 0) {
+        info = -1;
     }
     else if(n < 0 || n > 32){
         fprintf( stderr, "%s: n = %4lld not supported, must be between 0 and %4lld\n",
                  __func__, (long long) m, (long long) 32);
-        return -2;
+        info = -2;
     }
-    magma_int_t ntcol = (m > 32)? 1 : (2 * (32/m));
 
-    magma_int_t shared_size = 0;
-    shared_size += n * sizeof(magmaDoubleComplex);
-    shared_size += m * sizeof(double);
-    shared_size += m * sizeof(int);    // not magma_int_t
-    shared_size += n * sizeof(int);    // not magma_int_t
-    shared_size *= ntcol;
+    if(info < 0) return info;
 
-    dim3 grid(magma_ceildiv(batchCount,ntcol), 1, 1);
-    dim3 threads(m, ntcol, 1);
-
-    switch(n)
-    {
-        case  1: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 1>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  2: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 2>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  3: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 3>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  4: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 4>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  5: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 5>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  6: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 6>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  7: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 7>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  8: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 8>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case  9: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel< 9>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 10: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<10>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 11: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<11>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 12: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<12>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 13: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<13>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 14: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<14>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 15: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<15>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 16: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<16>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 17: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<17>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 18: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<18>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 19: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<19>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 20: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<20>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 21: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<21>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 22: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<22>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 23: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<23>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 24: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<24>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 25: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<25>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 26: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<26>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 27: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<27>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 28: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<28>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 29: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<29>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 30: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<30>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 31: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<31>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        case 32: hipLaunchKernelGGL(HIP_KERNEL_NAME(zgetf2_fused_batched_kernel<32>), dim3(grid), dim3(threads), shared_size, queue->hip_stream(), m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount); break;
-        default: fprintf( stderr, "%s: n = %4lld is not supported \n", __func__, (long long) n);
+    switch(n) {
+        case  1: info = magma_zgetf2_fused_kernel_driver_batched< 1>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  2: info = magma_zgetf2_fused_kernel_driver_batched< 2>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  3: info = magma_zgetf2_fused_kernel_driver_batched< 3>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  4: info = magma_zgetf2_fused_kernel_driver_batched< 4>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  5: info = magma_zgetf2_fused_kernel_driver_batched< 5>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  6: info = magma_zgetf2_fused_kernel_driver_batched< 6>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  7: info = magma_zgetf2_fused_kernel_driver_batched< 7>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  8: info = magma_zgetf2_fused_kernel_driver_batched< 8>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case  9: info = magma_zgetf2_fused_kernel_driver_batched< 9>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 10: info = magma_zgetf2_fused_kernel_driver_batched<10>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 11: info = magma_zgetf2_fused_kernel_driver_batched<11>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 12: info = magma_zgetf2_fused_kernel_driver_batched<12>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 13: info = magma_zgetf2_fused_kernel_driver_batched<13>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 14: info = magma_zgetf2_fused_kernel_driver_batched<14>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 15: info = magma_zgetf2_fused_kernel_driver_batched<15>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 16: info = magma_zgetf2_fused_kernel_driver_batched<16>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 17: info = magma_zgetf2_fused_kernel_driver_batched<17>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 18: info = magma_zgetf2_fused_kernel_driver_batched<18>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 19: info = magma_zgetf2_fused_kernel_driver_batched<19>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 20: info = magma_zgetf2_fused_kernel_driver_batched<20>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 21: info = magma_zgetf2_fused_kernel_driver_batched<21>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 22: info = magma_zgetf2_fused_kernel_driver_batched<22>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 23: info = magma_zgetf2_fused_kernel_driver_batched<23>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 24: info = magma_zgetf2_fused_kernel_driver_batched<24>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 25: info = magma_zgetf2_fused_kernel_driver_batched<25>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 26: info = magma_zgetf2_fused_kernel_driver_batched<26>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 27: info = magma_zgetf2_fused_kernel_driver_batched<27>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 28: info = magma_zgetf2_fused_kernel_driver_batched<28>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 29: info = magma_zgetf2_fused_kernel_driver_batched<29>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 30: info = magma_zgetf2_fused_kernel_driver_batched<30>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 31: info = magma_zgetf2_fused_kernel_driver_batched<31>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        case 32: info = magma_zgetf2_fused_kernel_driver_batched<32>(m, dA_array, ai, aj, ldda, dipiv_array, info_array, batchCount, queue); break;
+        default: info = -100;
     }
-    return 0;
+
+    return info;
 }
