@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> c d s
        @author Hartwig Anzt
@@ -13,16 +13,12 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
+#if CUDA_VERSION >= 12000
+  #define CUSPARSE_CSRMV_ALG2 CUSPARSE_SPMV_CSR_ALG2
+  #define CUSPARSE_CSRMV_ALG1 CUSPARSE_SPMV_CSR_ALG1
+  #define CUSPARSE_CSRMM_ALG1 CUSPARSE_SPMM_CSR_ALG1
 #endif
 
-
 #if CUDA_VERSION >= 11000 
 // todo: destroy descriptor and see if the original code descriptors have to be changed 
 #define cusparseZcsrmv(handle, op, rows, cols, nnz, alpha, descr, dval, drow, dcol, x, beta, y) \
@@ -216,17 +212,6 @@ magma_z_spmv(
 
                 //printf("done.\n");
             }
-            else if ( A.storage_type == Magma_CSR5 ) {
-                //printf("using CSR5 kernel for SpMV: ");
-                CHECK( magma_zgecsr5mv( MagmaNoTrans, A.num_rows, A.num_cols, 
-                   A.csr5_p, alpha, A.csr5_sigma, A.csr5_bit_y_offset, 
-                   A.csr5_bit_scansum_offset, A.csr5_num_packets, 
-                   A.dtile_ptr, A.dtile_desc, A.dtile_desc_offset_ptr, A.dtile_desc_offset, 
-                   A.dcalibrator, A.csr5_tail_tile_start, 
-                   A.dval, A.drow, A.dcol, x.dval, beta, y.dval, queue ));
-
-                //printf("done.\n");
-            }
             else if ( A.storage_type == Magma_DENSE ) {
                 //printf("using DENSE kernel for SpMV: ");
                 magmablas_zgemv( MagmaNoTrans, A.num_rows, A.num_cols, alpha,
