@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Hartwig Anzt
 
@@ -12,15 +12,13 @@
 #include "magmasparse_internal.h"
 #include <cuda.h>  // for CUDA_VERSION
 
+#include "magma_trisolve.h"
+
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
+#if CUDA_VERSION >= 12000
+   #define cusparseCreateCsrsm2Info(info)
+   #define cusparseDestroyCsrsm2Info(info)
 #endif
 
 // todo: make it spacific
@@ -101,49 +99,6 @@
     }
 #endif
 
-
-#if CUDA_VERSION >= 11000 
-#define cusparseZcsrsm_solve(handle, op, rows, cols, nnz, alpha, descrA, dval, drow, dcol,      \
-                             info, b, ldb, x, ldx )                                             \
-    {                                                                                           \
-        size_t bufsize;                                                                         \
-        void *buf;                                                                              \
-        cusparseSetMatType( descrA, CUSPARSE_MATRIX_TYPE_GENERAL );                             \
-        cusparseZcsrsm2_bufferSizeExt(handle, 0, op, CUSPARSE_OPERATION_NON_TRANSPOSE,          \
-                                      rows, cols, nnz, alpha, descrA, dval, drow, dcol,         \
-                                      b, ldb, info, CUSPARSE_SOLVE_POLICY_NO_LEVEL, &bufsize);  \
-        magma_malloc(&buf, bufsize);                                                            \
-        magmablas_zlacpy( MagmaFull, rows, cols, b, ldb, x, ldx, queue );                       \
-        cusparseZcsrsm2_solve(handle, 0, op, CUSPARSE_OPERATION_NON_TRANSPOSE, rows, cols, nnz, \
-                              alpha, descrA, dval, drow, dcol, x, ldx, info,                    \
-                              CUSPARSE_SOLVE_POLICY_NO_LEVEL, buf);                             \
-        magma_free(buf);                                                                        \
-    }
-
-#elif defined(MAGMA_HAVE_HIP) 
-#define cusparseZcsrsm_solve(handle, op, rows, cols, nnz, alpha, descrA, dval, drow, dcol,      \
-                             info, b, ldb, x, ldx )                                             \
-    {                                                                                           \
-        size_t bufsize;                                                                         \
-        void *buf;                                                                              \
-        hipsparseZcsrsm2_bufferSizeExt(handle, 0, op, HIPSPARSE_OPERATION_NON_TRANSPOSE,          \
-                                      rows, cols, nnz, (const hipDoubleComplex*)alpha, descrA, (const hipDoubleComplex*)dval, drow, dcol,         \
-                                      (hipDoubleComplex*)b, ldb, info, HIPSPARSE_SOLVE_POLICY_NO_LEVEL, &bufsize);  \
-        magma_malloc(&buf, bufsize);                                                            \
-        hipsparseZcsrsm2_solve(handle, 0, op, HIPSPARSE_OPERATION_NON_TRANSPOSE, rows, cols, nnz, \
-                              (const hipDoubleComplex*)alpha, descrA, (const hipDoubleComplex*)dval, drow, dcol, (hipDoubleComplex*)b, ldb, info,                    \
-                              HIPSPARSE_SOLVE_POLICY_NO_LEVEL, buf);                             \
-        magmablas_zlacpy( MagmaFull, rows, cols, b, ldb, x, ldx, queue );                       \
-        magma_free(buf);                                                                        \
-    }
-
-#else
-#define cusparseZcsrsm_solve(handle, op, rows, cols, nnz, alpha, descrA, dval, drow, dcol,      \
-                             info, b, ldb, x, ldx )                                             \
-    CHECK_CUSPARSE( cusparseZcsrsm_solve(handle, op, rows, cols, alpha, descrA, dval,           \
-                                         drow, dcol, info, b, ldb, x, ldx ))              
-#endif 
-
 // todo: info is passed from analysis; to change info with this linfo & remove linfo from here
 #if CUDA_VERSION >= 11000
 #define cusparseZcsric0(handle, op, rows, nnz, descrA, dval, drow, dcol, info )                 \
@@ -225,8 +180,6 @@ magma_zcumilusetup(
     
     cusparseHandle_t cusparseHandle=NULL;
     cusparseMatDescr_t descrA=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    cusparseMatDescr_t descrU=NULL;
 #if CUDA_VERSION >= 7000 || defined(MAGMA_HAVE_HIP)
     csrilu02Info_t info_M=NULL;
     void *pBuffer = NULL;
@@ -259,7 +212,7 @@ magma_zcumilusetup(
     CHECK_CUSPARSE( cusparseSetMatType( descrA, CUSPARSE_MATRIX_TYPE_GENERAL ));
     CHECK_CUSPARSE( cusparseSetMatDiagType( descrA, CUSPARSE_DIAG_TYPE_NON_UNIT ));
     CHECK_CUSPARSE( cusparseSetMatIndexBase( descrA, CUSPARSE_INDEX_BASE_ZERO ));
-    cusparseCreateSolveAnalysisInfo( &(precond->cuinfo) );
+    cusparseCreateSolveAnalysisInfo( &(precond->cuinfoILU) );
 
     // use kernel to manually check for zeros n the diagonal
     CHECK( magma_zdiagcheck( precond->M, queue ) );
@@ -331,13 +284,13 @@ magma_zcumilusetup(
                              CUSPARSE_OPERATION_NON_TRANSPOSE,
                              precond->M.num_rows, precond->M.nnz, descrA,
                              precond->M.dval, precond->M.drow, precond->M.dcol,
-                             precond->cuinfo );
+                             precond->cuinfoILU );
     CHECK_CUSPARSE( cusparseZcsrilu0( cusparseHandle, CUSPARSE_OPERATION_NON_TRANSPOSE,
                       precond->M.num_rows, descrA,
                       precond->M.dval,
                       precond->M.drow,
                       precond->M.dcol,
-                      precond->cuinfo ));
+                      precond->cuinfoILU ));
 #endif
 
     CHECK( magma_zmtransfer( precond->M, &hA, Magma_DEV, Magma_CPU, queue ));
@@ -356,29 +309,8 @@ magma_zcumilusetup(
     CHECK( magma_index_malloc( &(precond->U_dgraphindegree_bak), precond->M.num_rows ));
 
     if( precond->trisolver == Magma_CUSOLVE || precond->trisolver == 0 ){
-        CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-        CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-        CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-        CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-        CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_LOWER ));
-        cusparseCreateSolveAnalysisInfo( &precond->cuinfoL );
-        cusparseZcsrsm_analysis( cusparseHandle,
-                                 CUSPARSE_OPERATION_NON_TRANSPOSE, precond->L.num_rows,
-                                 precond->L.nnz, descrL,
-                                 precond->L.dval, precond->L.drow, precond->L.dcol, 
-                                 precond->cuinfoL);
-    
-        CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-        CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-        CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-        CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-        CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_UPPER ));
-        cusparseCreateSolveAnalysisInfo( &precond->cuinfoU );
-        cusparseZcsrsm_analysis( cusparseHandle,
-                                 CUSPARSE_OPERATION_NON_TRANSPOSE, precond->U.num_rows,
-                                 precond->U.nnz, descrU,
-                                 precond->U.dval, precond->U.drow, precond->U.dcol, 
-                                 precond->cuinfoU );
+        CHECK(magma_ztrisolve_analysis(precond->L, &precond->cuinfoL, false, false, false, queue));
+        CHECK(magma_ztrisolve_analysis(precond->U, &precond->cuinfoU, true, false, false, queue));
     } else if( precond->trisolver == Magma_SYNCFREESOLVE ){
             magma_zmfree(&hL, queue );
             magma_zmfree(&hU, queue );
@@ -458,10 +390,8 @@ cleanup:
     magma_free( pBuffer );
     cusparseDestroyCsrilu02Info( info_M );
 #endif
-    cusparseDestroySolveAnalysisInfo( precond->cuinfo );
+    cusparseDestroySolveAnalysisInfo( precond->cuinfoILU );
     cusparseDestroyMatDescr( descrA );
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroyMatDescr( descrU );
     cusparseDestroy( cusparseHandle );
     magma_zmfree( &hA, queue );
     magma_zmfree( &hACSR, queue );
@@ -504,70 +434,15 @@ magma_zcumilusetup_transpose(
     magma_queue_t queue )
 {
     magma_int_t info = 0;
-    magma_z_matrix Ah1={Magma_CSR}, Ah2={Magma_CSR};
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrLT=NULL;
-    cusparseMatDescr_t descrUT=NULL;
-    
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
 
     // transpose the matrix
-    magma_zmtransfer( precond->L, &Ah1, Magma_DEV, Magma_CPU, queue );
-    magma_zmconvert( Ah1, &Ah2, A.storage_type, Magma_CSR, queue );
-    magma_zmfree(&Ah1, queue );
-    magma_zmtransposeconjugate( Ah2, &Ah1, queue );
-    magma_zmfree(&Ah2, queue );
-    Ah2.blocksize = A.blocksize;
-    Ah2.alignment = A.alignment;
-    magma_zmconvert( Ah1, &Ah2, Magma_CSR, A.storage_type, queue );
-    magma_zmfree(&Ah1, queue );
-    magma_zmtransfer( Ah2, &(precond->LT), Magma_CPU, Magma_DEV, queue );
-    magma_zmfree(&Ah2, queue );
-    
-    magma_zmtransfer( precond->U, &Ah1, Magma_DEV, Magma_CPU, queue );
-    magma_zmconvert( Ah1, &Ah2, A.storage_type, Magma_CSR, queue );
-    magma_zmfree(&Ah1, queue );
-    magma_zmtransposeconjugate( Ah2, &Ah1, queue );
-    magma_zmfree(&Ah2, queue );
-    Ah2.blocksize = A.blocksize;
-    Ah2.alignment = A.alignment;
-    magma_zmconvert( Ah1, &Ah2, Magma_CSR, A.storage_type, queue );
-    magma_zmfree(&Ah1, queue );
-    magma_zmtransfer( Ah2, &(precond->UT), Magma_CPU, Magma_DEV, queue );
-    magma_zmfree(&Ah2, queue );
+    magma_zmtransposeconjugate( precond->L, &(precond->LT), queue );
+    magma_zmtransposeconjugate( precond->U, &(precond->UT), queue );
    
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrLT ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrLT, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrLT, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrLT, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrLT, CUSPARSE_FILL_MODE_UPPER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoLT );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_NON_TRANSPOSE, precond->LT.num_rows,
-                             precond->LT.nnz, descrLT,
-                             precond->LT.dval, precond->LT.drow, precond->LT.dcol, 
-                             precond->cuinfoLT );
-    
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrUT ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrUT, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrUT, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrUT, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrUT, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoUT );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_NON_TRANSPOSE, precond->UT.num_rows,
-                             precond->UT.nnz, descrUT,
-                             precond->UT.dval, precond->UT.drow, precond->UT.dcol, 
-                             precond->cuinfoUT );
-cleanup:
-    cusparseDestroyMatDescr( descrLT );
-    cusparseDestroyMatDescr( descrUT );
-    cusparseDestroy( cusparseHandle );
-    magma_zmfree(&Ah1, queue );
-    magma_zmfree(&Ah2, queue );
+    CHECK(magma_ztrisolve_analysis(precond->LT, &precond->cuinfoLT, true, false, false, queue));
+    CHECK(magma_ztrisolve_analysis(precond->UT, &precond->cuinfoUT, false, false, false, queue));
 
+cleanup:
     return info;
 }
 
@@ -601,10 +476,6 @@ magma_zcumilugeneratesolverinfo(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    cusparseMatDescr_t descrU=NULL;
-    
     magma_z_matrix hA={Magma_CSR}, hL={Magma_CSR}, hU={Magma_CSR};
     
     if (precond->L.memory_location != Magma_DEV ){
@@ -623,35 +494,8 @@ magma_zcumilugeneratesolverinfo(
         magma_zmfree(&hU, queue );
     }
     
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-
-
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoL );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_NON_TRANSPOSE, precond->L.num_rows,
-                             precond->L.nnz, descrL,
-                             precond->L.dval, precond->L.drow, precond->L.dcol, 
-                             precond->cuinfoL );
-
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_UPPER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoU );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_NON_TRANSPOSE, precond->U.num_rows,
-                             precond->U.nnz, descrU,
-                             precond->U.dval, precond->U.drow, precond->U.dcol, 
-                             precond->cuinfoU );
-
+    CHECK(magma_ztrisolve_analysis(precond->L, &precond->cuinfoL, false, false, false, queue));
+    CHECK(magma_ztrisolve_analysis(precond->U, &precond->cuinfoU, true, false, false, queue));
     
     if( precond->trisolver != 0 && precond->trisolver != Magma_CUSOLVE ){
         //prepare for iterative solves
@@ -665,11 +509,7 @@ magma_zcumilugeneratesolverinfo(
         CHECK( magma_zvinit( &precond->work2, Magma_DEV, precond->U.num_rows, 1, MAGMA_Z_ZERO, queue ));
     }
     
-cleanup:
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroyMatDescr( descrU );
-    cusparseDestroy( cusparseHandle );
-     
+cleanup:     
     return info;
 }
 
@@ -709,36 +549,12 @@ magma_zapplycumilu_l(
     magma_queue_t queue )
 {
     magma_int_t info = 0;
-    
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    
+        
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
     // CUSPARSE context //
     if( precond->trisolver == Magma_CUSOLVE || precond->trisolver == 0 ){
-        CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-        CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-        CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-        CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-        CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-        CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-        CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_LOWER ));
-        cusparseZcsrsm_solve( cusparseHandle,
-                              CUSPARSE_OPERATION_NON_TRANSPOSE,
-                              precond->L.num_rows,
-                              b.num_rows*b.num_cols/precond->L.num_rows,
-                              precond->L.nnz,
-                              &one,
-                              descrL,
-                              precond->L.dval,
-                              precond->L.drow,
-                              precond->L.dcol,
-                              precond->cuinfoL,
-                              b.dval,
-                              precond->L.num_rows,
-                              x->dval,
-                              precond->L.num_rows );
+        CHECK(magma_ztrisolve(precond->L, precond->cuinfoL, false, false, false, b, *x, queue));
     } else if( precond->trisolver == Magma_SYNCFREESOLVE ){
         magma_zgecscsyncfreetrsm_solve( precond->L.num_rows,
             precond->L.nnz, 
@@ -748,12 +564,9 @@ magma_zapplycumilu_l(
             1, // rhs
             queue );
     }
-    
-    
+       
 
 cleanup:
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroy( cusparseHandle );
     return info;
 }
 
@@ -795,40 +608,14 @@ magma_zapplycumilu_l_transpose(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
     // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_UPPER ));
-    cusparseZcsrsm_solve( cusparseHandle,
-                          CUSPARSE_OPERATION_NON_TRANSPOSE,
-                          precond->LT.num_rows,
-                          b.num_rows*b.num_cols/precond->LT.num_rows,
-                          precond->LT.nnz,
-                          &one,
-                          descrL,
-                          precond->LT.dval,
-                          precond->LT.drow,
-                          precond->LT.dcol,
-                          precond->cuinfoLT,
-                          b.dval,
-                          precond->LT.num_rows,
-                          x->dval,
-                          precond->LT.num_rows );
+    CHECK(magma_ztrisolve(precond->LT, precond->cuinfoLT, true, false, false, b, *x, queue));
     
     
 
 cleanup:
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroy( cusparseHandle );
     return info;
 }
 
@@ -869,35 +656,11 @@ magma_zapplycumilu_r(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrU=NULL;
-    
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
     // CUSPARSE context //
     if( precond->trisolver == Magma_CUSOLVE || precond->trisolver == 0 ){
-        CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-        CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-        CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-        CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-        CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-        CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-        CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_UPPER ));
-        cusparseZcsrsm_solve( cusparseHandle,
-                              CUSPARSE_OPERATION_NON_TRANSPOSE,
-                              precond->U.num_rows,
-                              b.num_rows*b.num_cols/precond->U.num_rows,
-                              precond->U.nnz,
-                              &one,
-                              descrU,
-                              precond->U.dval,
-                              precond->U.drow,
-                              precond->U.dcol,
-                              precond->cuinfoU,
-                              b.dval,
-                              precond->U.num_rows,
-                              x->dval,
-                              precond->U.num_rows );
+        CHECK(magma_ztrisolve(precond->U, precond->cuinfoU, true, false, false, b, *x, queue));
     } else if( precond->trisolver == Magma_SYNCFREESOLVE ){
         magma_zgecscsyncfreetrsm_solve( precond->U.num_rows,
             precond->U.nnz,
@@ -911,8 +674,6 @@ magma_zapplycumilu_r(
     
 
 cleanup:
-    cusparseDestroyMatDescr( descrU );
-    cusparseDestroy( cusparseHandle );
     return info; 
 }
 
@@ -953,40 +714,11 @@ magma_zapplycumilu_r_transpose(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrU=NULL;
-    
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseZcsrsm_solve( cusparseHandle,
-                          CUSPARSE_OPERATION_NON_TRANSPOSE,
-                          precond->UT.num_rows,
-                          b.num_rows*b.num_cols/precond->UT.num_rows,
-                          precond->UT.nnz,
-                          &one,
-                          descrU,
-                          precond->UT.dval,
-                          precond->UT.drow,
-                          precond->UT.dcol,
-                          precond->cuinfoUT,
-                          b.dval,
-                          precond->UT.num_rows,
-                          x->dval,
-                          precond->UT.num_rows );
-
+    CHECK(magma_ztrisolve(precond->UT, precond->cuinfoUT, false, false, false, b, *x, queue));
     
-
 cleanup:
-    cusparseDestroyMatDescr( descrU );
-    cusparseDestroy( cusparseHandle );
     return info; 
 }
 
@@ -1052,11 +784,11 @@ magma_zcumiccsetup(
     CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
     CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
     CHECK_CUSPARSE( cusparseCreateMatDescr( &descrA ));
-    cusparseCreateSolveAnalysisInfo( &(precond->cuinfo) );
+    cusparseCreateSolveAnalysisInfo( &(precond->cuinfoILU) );
     // use kernel to manually check for zeros n the diagonal
     CHECK( magma_zdiagcheck( precond->M, queue ) );
- /*      
-#if CUDA_VERSION >= 7000
+    
+#if CUDA_VERSION >= 12000
     // this version has the bug fixed where a zero on the diagonal causes a crash
     CHECK_CUSPARSE( cusparseCreateCsric02Info(&info_M) );
     CHECK_CUSPARSE( cusparseSetMatType( descrA, CUSPARSE_MATRIX_TYPE_GENERAL ));
@@ -1087,7 +819,7 @@ magma_zcumiccsetup(
                          precond->M.dval, precond->M.drow, precond->M.dcol,
                          info_M, CUSPARSE_SOLVE_POLICY_NO_LEVEL, pBuffer) );    
 
-#else*/
+#else
     // this version contains the bug but is needed for backward compability
     CHECK_CUSPARSE( cusparseSetMatType( descrA, CUSPARSE_MATRIX_TYPE_SYMMETRIC ));
     CHECK_CUSPARSE( cusparseSetMatDiagType( descrA, CUSPARSE_DIAG_TYPE_NON_UNIT ));
@@ -1099,14 +831,14 @@ magma_zcumiccsetup(
                              CUSPARSE_OPERATION_NON_TRANSPOSE,
                              precond->M.num_rows, precond->M.nnz, descrA,
                              precond->M.dval, precond->M.drow, precond->M.dcol,
-                             precond->cuinfo );
+                             precond->cuinfoILU );
     cusparseZcsric0( cusparseHandle, CUSPARSE_OPERATION_NON_TRANSPOSE,
                      precond->M.num_rows, precond->M.nnz, descrA,
                      precond->M.dval,
                      precond->M.drow,
                      precond->M.dcol,
-                     precond->cuinfo );
-//#endif
+                     precond->cuinfoILU );
+#endif
 
     CHECK( magma_zmtransfer( precond->M, &precond->L, 
         Magma_DEV, Magma_DEV, queue ));
@@ -1163,7 +895,7 @@ cleanup:
     magma_free( pBuffer );
     cusparseDestroyCsric02Info( info_M );
 #endif
-    cusparseDestroySolveAnalysisInfo( precond->cuinfo );
+    cusparseDestroySolveAnalysisInfo( precond->cuinfoILU );
     cusparseDestroyMatDescr( descrL );
     cusparseDestroyMatDescr( descrU );
     cusparseDestroyMatDescr( descrA );
@@ -1202,36 +934,9 @@ magma_zcumicgeneratesolverinfo(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    cusparseMatDescr_t descrU=NULL;
+    CHECK(magma_ztrisolve_analysis(precond->M, &precond->cuinfoL, false, false, false, queue));
+    CHECK(magma_ztrisolve_analysis(precond->M, &precond->cuinfoU, false, false, true, queue));
     
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoL );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_NON_TRANSPOSE, precond->M.num_rows,
-                             precond->M.nnz, descrL,
-                             precond->M.dval, precond->M.drow, precond->M.dcol, 
-                             precond->cuinfoL );
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseCreateSolveAnalysisInfo( &precond->cuinfoU );
-    cusparseZcsrsm_analysis( cusparseHandle,
-                             CUSPARSE_OPERATION_TRANSPOSE, precond->M.num_rows,
-                             precond->M.nnz, descrU,
-                             precond->M.dval, precond->M.drow, precond->M.dcol, 
-                             precond->cuinfoU );
-
 
 /*
     // to enable also the block-asynchronous iteration for the triangular solves
@@ -1260,9 +965,6 @@ magma_zcumicgeneratesolverinfo(
 */
 
 cleanup:
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroyMatDescr( descrU );
-    cusparseDestroy( cusparseHandle );
     return info;
 }
 
@@ -1304,40 +1006,11 @@ magma_zapplycumicc_l(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrL=NULL;
-    
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrL ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrL, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrL, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrL, CUSPARSE_FILL_MODE_LOWER ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrL, CUSPARSE_INDEX_BASE_ZERO ));
-    cusparseZcsrsm_solve( cusparseHandle,
-                          CUSPARSE_OPERATION_NON_TRANSPOSE,
-                          precond->M.num_rows,
-                          b.num_rows*b.num_cols/precond->M.num_rows,
-                          precond->M.nnz,
-                          &one,
-                          descrL,
-                          precond->M.dval,
-                          precond->M.drow,
-                          precond->M.dcol,
-                          precond->cuinfoL,
-                          b.dval,
-                          precond->M.num_rows,
-                          x->dval,
-                          precond->M.num_rows );
-
-    
+    CHECK(magma_ztrisolve(precond->M, precond->cuinfoL, false, false, false, b, *x, queue));
 
 cleanup:
-    cusparseDestroyMatDescr( descrL );
-    cusparseDestroy( cusparseHandle );
     return info; 
 }
 
@@ -1378,146 +1051,12 @@ magma_zapplycumicc_r(
 {
     magma_int_t info = 0;
     
-    cusparseHandle_t cusparseHandle=NULL;
-    cusparseMatDescr_t descrU=NULL;
-    
     magmaDoubleComplex one = MAGMA_Z_MAKE( 1.0, 0.0);
 
-    // CUSPARSE context //
-    CHECK_CUSPARSE( cusparseCreate( &cusparseHandle ));
-    CHECK_CUSPARSE( cusparseSetStream( cusparseHandle, queue->cuda_stream() ));
-    CHECK_CUSPARSE( cusparseCreateMatDescr( &descrU ));
-    CHECK_CUSPARSE( cusparseSetMatType( descrU, CUSPARSE_MATRIX_TYPE_TRIANGULAR ));
-    CHECK_CUSPARSE( cusparseSetMatDiagType( descrU, CUSPARSE_DIAG_TYPE_NON_UNIT ));
-    CHECK_CUSPARSE( cusparseSetMatIndexBase( descrU, CUSPARSE_INDEX_BASE_ZERO ));
-    CHECK_CUSPARSE( cusparseSetMatFillMode( descrU, CUSPARSE_FILL_MODE_LOWER ));
-    cusparseZcsrsm_solve( cusparseHandle,
-                          CUSPARSE_OPERATION_TRANSPOSE,
-                          precond->M.num_rows,
-                          b.num_rows*b.num_cols/precond->M.num_rows,
-                          precond->M.nnz,
-                          &one,
-                          descrU,
-                          precond->M.dval,
-                          precond->M.drow,
-                          precond->M.dcol,
-                          precond->cuinfoU,
-                          b.dval,
-                          precond->M.num_rows,
-                          x->dval,
-                          precond->M.num_rows );
+    CHECK(magma_ztrisolve(precond->M, precond->cuinfoU, false, false, true, b, *x, queue));
     
     
 
 cleanup:
-    cusparseDestroyMatDescr( descrU );
-    cusparseDestroy( cusparseHandle );
     return info; 
 }
-
-
-
-/**
-    Purpose
-    -------
-
-    Performs the left triangular solves using the IC preconditioner via Jacobi.
-
-    Arguments
-    ---------
-
-    @param[in]
-    b           magma_z_matrix
-                RHS
-
-    @param[out]
-    x           magma_z_matrix*
-                vector to precondition
-
-    @param[in]
-    precond     magma_z_preconditioner*
-                preconditioner parameters
-                
-    @param[in]
-    queue       magma_queue_t
-                Queue to execute in.
-
-    @ingroup magmasparse_zgepr
-    ********************************************************************/
-extern "C"
-magma_int_t
-magma_zapplyiteric_l(
-    magma_z_matrix b,
-    magma_z_matrix *x,
-    magma_z_preconditioner *precond,
-    magma_queue_t queue )
-{
-    magma_int_t info = 0;
-    
-    magma_int_t dofs = precond->L.num_rows;
-    magma_z_solver_par jacobiiter_par;
-    jacobiiter_par.maxiter = precond->maxiter;
-
-    // compute c = D^{-1}b and copy c as initial guess to x
-    CHECK( magma_zjacobisetup_vector_gpu( dofs, b, precond->d,
-                                                precond->work1, x, queue ));
-    // Jacobi iterator
-    CHECK( magma_zjacobiiter_precond( precond->L, x, &jacobiiter_par, precond , queue ));
-
-cleanup:
-    return info;
-}
-
-
-/**
-    Purpose
-    -------
-
-    Performs the right triangular solves using the IC preconditioner via Jacobi.
-
-    Arguments
-    ---------
-
-    @param[in]
-    b           magma_z_matrix
-                RHS
-
-    @param[out]
-    x           magma_z_matrix*
-                vector to precondition
-
-    @param[in]
-    precond     magma_z_preconditioner*
-                preconditioner parameters
-                
-    @param[in]
-    queue       magma_queue_t
-                Queue to execute in.
-
-    @ingroup magmasparse_zgepr
-    ********************************************************************/
-extern "C"
-magma_int_t
-magma_zapplyiteric_r(
-    magma_z_matrix b,
-    magma_z_matrix *x,
-    magma_z_preconditioner *precond,
-    magma_queue_t queue )
-{
-    magma_int_t info = 0;
-
-    magma_int_t dofs = precond->U.num_rows;
-    magma_z_solver_par jacobiiter_par;
-    jacobiiter_par.maxiter = precond->maxiter;
-
-    // compute c = D^{-1}b and copy c as initial guess to x
-    CHECK( magma_zjacobisetup_vector_gpu( dofs, b, precond->d,
-                                                precond->work1, x, queue ));
-
-    // Jacobi iterator
-    CHECK( magma_zjacobiiter_precond( precond->U, x, &jacobiiter_par, precond , queue ));
-    
-cleanup:
-    return info;
-}
-
