@@ -1,15 +1,17 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
        @author Hartwig Anzt
 */
 #include "magmasparse_internal.h"
 
+#include "../blas/magma_trisolve.h"
+
 // todo: see how to destroy info
 // there are different, e.g., cusparseDestroyCsrsv2Info(info), etc.
 #if CUDA_VERSION >= 11000 || defined(MAGMA_HAVE_HIP)
@@ -21,6 +23,8 @@
     -------
 
     Free the memory of a magma_z_matrix.
+    Note, this routine performs a magma_queue_sync on the queue passed
+    to it prior to freeing any memory.
 
 
     Arguments
@@ -185,6 +189,7 @@ magma_zmfree(
     }
 
     if ( A->memory_location == Magma_DEV ) {
+	magma_queue_sync( queue );
         if (A->storage_type == Magma_ELL || A->storage_type == Magma_ELLPACKT) {
             if (A->ownership) {
                 if ( magma_free( A->dval ) != MAGMA_SUCCESS ) {
@@ -442,7 +447,8 @@ magma_zmfree(
     -------
 
     Free a preconditioner.
-
+    Note, this routine performs a magma_queue_sync on the queue passed
+    to it prior to freeing any memory.
 
     Arguments
     ---------
@@ -463,6 +469,7 @@ magma_zprecondfree(
     magma_z_preconditioner *precond_par,
     magma_queue_t queue ){
 
+    magma_queue_sync( queue );
     if ( precond_par->d.val != NULL ) {
         magma_free( precond_par->d.val );
         precond_par->d.val = NULL;
@@ -604,23 +611,14 @@ magma_zprecondfree(
         magma_free_cpu( precond_par->UT.blockinfo );
         precond_par->UT.blockinfo = NULL;
     }
-    if ( precond_par->solver == Magma_ILU ||
-        precond_par->solver == Magma_PARILU ||
-        precond_par->solver == Magma_ICC||
-        precond_par->solver == Magma_PARIC ) {
-        if( precond_par->cuinfoL != NULL )
-            cusparseDestroySolveAnalysisInfo( precond_par->cuinfoL ); 
-        if( precond_par->cuinfoU != NULL )
-            cusparseDestroySolveAnalysisInfo( precond_par->cuinfoU ); 
-        // todo: error: invalid conversion from 'long int' to 'cusparseSolvePolicy_t' 
-        //precond_par->cuinfoL = NULL;
-        //precond_par->cuinfoU = NULL;
-        if( precond_par->cuinfoLT != NULL )
-            cusparseDestroySolveAnalysisInfo( precond_par->cuinfoLT ); 
-        if( precond_par->cuinfoUT != NULL )
-            cusparseDestroySolveAnalysisInfo( precond_par->cuinfoUT ); 
-        //precond_par->cuinfoLT = NULL;
-        //precond_par->cuinfoUT = NULL;
+    if ((precond_par->solver == Magma_ILU ||
+         precond_par->solver == Magma_ICC) &&
+        (precond_par->trisolver == Magma_CUSOLVE ||
+         precond_par->trisolver == 0)) {
+        magma_trisolve_free( &precond_par->cuinfoL );
+        magma_trisolve_free( &precond_par->cuinfoU );
+        magma_trisolve_free( &precond_par->cuinfoLT );
+        magma_trisolve_free( &precond_par->cuinfoUT );
     }
     if ( precond_par->LD.val != NULL ) {
         if ( precond_par->LD.memory_location == Magma_DEV )
