@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
        @author Hartwig Anzt
@@ -13,11 +13,6 @@
 #include <cuda.h>  // for CUDA_VERSION
 
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#ifdef MAGMA_HAVE_HIP
-  #define hipblasDoubleComplex hipDoubleComplex
-#endif
-
 
 // todo: check if we need buf later
 #if CUDA_VERSION >= 11000
@@ -27,11 +22,11 @@
         size_t bufsize;                                                                        \
         void *buf;                                                                             \
         cusparseCsr2cscEx2_bufferSize(handle, m, n, nnz, valA, rowA, colA,                     \
-                                      valB, rowB, colB, CUDA_C_64F, action, base,              \
+                                      valB, colB, rowB, CUDA_C_64F, action, base,              \
                                       CUSPARSE_CSR2CSC_ALG1, &bufsize);                        \
         if (bufsize > 0)                                                                       \
-           magma_malloc(&buf, bufsize);                                                        \
-        cusparseCsr2cscEx2(handle, m, n, nnz, valA, rowA, colA, valB, rowB, colB,              \
+           CHECK( magma_malloc(&buf, bufsize) );                                                        \
+        cusparseCsr2cscEx2(handle, m, n, nnz, valA, rowA, colA, valB, colB, rowB,              \
                            CUDA_C_64F, action, base, CUSPARSE_CSR2CSC_ALG1, buf);              \
         if (bufsize > 0)                                                                       \
            magma_free(buf);                                                                    \
@@ -1920,19 +1915,31 @@ magma_zmconvert(
 
             // step 1: allocate buffer
             cusparseXcoosort_bufferSizeExt(cusparseHandle, m, n, nnz, B->drowidx, B->dcol, &pBufferSizeInBytes);
-            //cudaMalloc( &pBuffer, sizeof(char)* pBufferSizeInBytes);
             CHECK( magma_malloc( &pBuffer, sizeof(char)* pBufferSizeInBytes ));
             // step 2: setup permutation vector P to identity
             CHECK( magma_index_malloc( &P, nnz ));
-            //magma_( &P, sizeof(int)*nnz);
             cusparseCreateIdentityPermutation(cusparseHandle, nnz, P);
 
             // step 3: sort COO format by Row
             cusparseXcoosortByRow(cusparseHandle, m, n, nnz, B->drowidx, B->dcol, P, pBuffer);
 
             // step 4: gather sorted cooVals
+#if CUDA_VERSION >= 12000
+            cusparseSpVecDescr_t vec_permutation;
+            cusparseDnVecDescr_t vec_values;
+            CHECK_CUSPARSE( cusparseCreateSpVec(&vec_permutation, A.nnz, A.nnz,
+                                                P, B->dval,
+                                                CUSPARSE_INDEX_32I,
+                                                CUSPARSE_INDEX_BASE_ZERO, CUDA_C_64F) );
+            CHECK_CUSPARSE( cusparseCreateDnVec(&vec_values, A.nnz, A.dval, CUDA_C_64F) );
+            CHECK_CUSPARSE( cusparseGather(cusparseHandle, vec_values, vec_permutation) );
+            
+            // destroy matrix/vector descriptors
+            CHECK_CUSPARSE( cusparseDestroySpVec(vec_permutation) );
+            CHECK_CUSPARSE( cusparseDestroyDnVec(vec_values) );
+#else
             cusparseZgthr(cusparseHandle, nnz, A.dval, B->dval, P, CUSPARSE_INDEX_BASE_ZERO);
-
+#endif
 
             // conversion using CUSPARSE
             cusparseXcoo2csr( cusparseHandle, B->drowidx,
