@@ -1,10 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
-# MAGMA (version 2.6.2) --
+# MAGMA (version 2.10.0) --
 # Univ. of Tennessee, Knoxville
 # Univ. of California, Berkeley
 # Univ. of Colorado, Denver
-# @date March 2022
+# @date February 2026
 
 ## @file
 #  @author Mark Gates
@@ -147,7 +147,7 @@ parser.add_option('-p', '--precisions',  action='store',      dest='precisions',
 parser.add_option(      '--start',       action='store',      dest='start',      help='start with given routine; useful to restart an interupted run')
 parser.add_option(      '--memcheck',    action='store_true', dest='memcheck',   help='run with cuda-memcheck (slow)')
 parser.add_option(      '--tol',         action='store',      dest='tol',        help='set tolerance')
-                                         
+
 parser.add_option('-s', '--small',       action='store_true', dest='small',      help='run small  tests, N < 300')
 parser.add_option('-m', '--medium',      action='store_true', dest='med',        help='run medium tests, N < 1000')
 parser.add_option('-l', '--large',       action='store_true', dest='large',      help='run large  tests, N > 1000')
@@ -184,19 +184,18 @@ parser.add_option(      '--qmr_merge'        , action='store_true', dest='qmr_me
 parser.add_option(      '--pcgs'             , action='store_true', dest='pcgs'          , help='run pcgs'          )
 parser.add_option(      '--pcgs_merge'       , action='store_true', dest='pcgs_merge'    , help='run pcgs_merge'    )
 parser.add_option(      '--pqmr'             , action='store_true', dest='pqmr'          , help='run pqmr'          )
-parser.add_option(      '--pqmr_merge'       , action='store_true', dest='pqmr_merge'    , help='run pqmr_merge'    )   
+parser.add_option(      '--pqmr_merge'       , action='store_true', dest='pqmr_merge'    , help='run pqmr_merge'    )
 parser.add_option(      '--bombard'          , action='store_true', dest='bombard'       , help='run bombard'       )
 parser.add_option(      '--bombard_merge'    , action='store_true', dest='bombard_merge' , help='run bombard_merge' )
 parser.add_option(      '--lsqr'             , action='store_true', dest='lsqr'          , help='run lsqr'          )
 parser.add_option(      '--bicg'             , action='store_true', dest='bicg'          , help='run bicg'          )
 parser.add_option(      '--pbicg'            , action='store_true', dest='pbicg'         , help='run pbicg'         )
 
-                                                                                           
+
 parser.add_option(      '--jacobi-prec'      , action='store_true', dest='jacobi_prec'   , help='run Jacobi preconditioner')
 parser.add_option(      '--ilu-prec'         , action='store_true', dest='ilu_exact_prec', help='run ILU + exact solve preconditioner')
 parser.add_option(      '--ilu-jac'          , action='store_true', dest='ilu_jac_prec',   help='run ILU + Jacobi solve preconditioner')
 parser.add_option(      '--ilu-bjac'         , action='store_true', dest='ilu_bjac_prec',  help='run ILU + Block Jacobi solve preconditioner')
-parser.add_option(      '--ilu-isai-prec'    , action='store_true', dest='ilu_isai_prec' , help='run ILU + ISAI preconditioner')
 parser.add_option(      '--ilut-prec'        , action='store_true', dest='ilut_prec',      help='run threshold ILU + exact solve preconditioner')
 
 (opts, args) = parser.parse_args()
@@ -287,15 +286,13 @@ if (     not opts.cg
 
 # default if no preconditioners given all
 if (     not opts.jacobi_prec
-     and not opts.ilu_exact_prec 
+     and not opts.ilu_exact_prec
      and not opts.ilut_prec
      and not opts.ilu_jac_prec
-     and not opts.ilu_bjac_prec
-     and not opts.ilu_isai_prec ):
+     and not opts.ilu_bjac_prec):
     opts.jacobi_prec      = True
     opts.ilu_prec         = True
     opts.ilu_jac_prec     = True
-    opts.ilu_isai_prec    = True
     opts.ilu_bjac_prec    = True
     opts.ilut_prec        = True
 # end
@@ -308,12 +305,12 @@ if ( not opts.small and not opts.med and not opts.large and not opts.nonsym ):
     opts.nonsym = True
 # end
 
-print 'opts', opts
-print 'args', args
+print('opts', opts)
+print('args', args)
 
 
 # ----------------------------------------------------------------------
-    
+
 # looping over formats
 formats = []
 if ( opts.csr ):
@@ -432,18 +429,12 @@ if ( opts.jacobi_prec ):
 if ( opts.ilu_exact_prec ):
     precs += ['--precond ILU ']
 # end
-if ( opts.ilut_prec ):
-    precs += ['--precond PARILUT --prestart 1 --psweeps 5 --plevels 0 --prtol 0.05 --patol 0.2 ']
-# end
 if ( opts.ilu_jac_prec ):
     precs += ['--precond ILU --trisolver JACOBI --ppattern 1 --piters 5 ']
 # end
 if ( opts.ilu_bjac_prec ):
     precs += ['--precond ILU --trisolver JACOBI --ppattern 4 --piters 3 ']
 # end
-if ( opts.ilu_isai_prec ):
-    precs += ['--precond ILU --trisolver ISAI --ppattern 1 --piters 1 ']
-# end
 
 
 # looping over preconditioners for Iter-Ref
@@ -637,15 +628,6 @@ for solver in IR:
 
 
 
-
-
-
-# ----------------------------------------------------------------------
-#print 'tests'
-#for t in tests:
-#    print t
-
-
 # ----------------------------------------------------------------------
 # runs command in a subprocess.
 # returns list (okay, fail, errors, status)
@@ -655,10 +637,10 @@ for solver in IR:
 # status is exit status of the command.
 def run( cmd ):
     words = re.split( ' +', cmd.strip() )
-    
+
     # stdout & stderr are merged
-    p = subprocess.Popen( words, bufsize=1, stdout=PIPE, stderr=STDOUT )
-    
+    p = subprocess.Popen( words, stdout=PIPE, stderr=STDOUT )
+
     okay  = 0
     fail  = 0
     nospd = 0
@@ -667,17 +649,17 @@ def run( cmd ):
     slowconv = 0
     # read unbuffered ("for line in p.stdout" will buffer)
     while True:
-        line = p.stdout.readline()
+        line = p.stdout.readline().decode()
         if not line:
             break
-        print line.rstrip()
+        print(line.rstrip())
         if re.search( r'\bok *$', line ):
             okay += 1
         if re.search( 'failed', line ):
             fail += 1
         if re.search( 'exit|memory mapping error|CUDA runtime error|illegal value|ERROR SUMMARY: [1-9]', line ):
             error += 1
-        m = re.search( 'solver info: (-?\d+)', line )
+        m = re.search( r'solver info: (-?\d+)', line )
         if ( m ):
             info = int( m.group(1) )
             if ( info == 0 ):
@@ -692,7 +674,7 @@ def run( cmd ):
                 fail += 1
         # end
     # end
-    
+
     status = p.wait()
     return (okay, fail, error, status)
 # end
@@ -716,48 +698,45 @@ last_cmd = None
 
 for test in tests:
     (cmd, options, sizes, comments) = test
-    
+
     make = False
     disabled = (cmd[0] == '#')
     if ( disabled ):
         cmd = cmd[1:]
-    
+
     # command to run
     cmd_args = './' + cmd +' '+ options +' '+ sizes
     cmd_args = re.sub( '  +', ' ', cmd_args )  # compress spaces
-    
+
     # skip tests before start
     if ( start and not start.search( cmd_args )):
         continue
     start = None
-    
+
     # skip tests not in args, or duplicates, or non-existing
-    #if not os.path.exists( cmd ):
-    #    print >>sys.stderr, cmd, cmd, "doesn't exist"
-    if (    (args and not cmd in args)
+    if ((args and not cmd in args)
          or (not os.path.exists( cmd ))
-         or (seen.has_key( cmd_args )) ):
-        #print "skipping", cmd_args
+         or (cmd_args in seen.keys())):
         continue
     # end
     seen[ cmd_args ] = True
-    
+
     if ( opts.memcheck ):
         cmd_args = 'cuda-memcheck ' + cmd_args
-    
+
     go = True
     while( go ):
         if pause > 0:
             time.sleep( pause )
             pause = 0
         # end
-        
+
         print
-        print '*'*100
-        print cmd_args
-        print '*'*100
+        print('*'*100)
+        print(cmd_args)
+        print('*'*100)
         sys.stdout.flush()
-        
+
         if ( batch ):
             if ( last_cmd and cmd != last_cmd ):
                 sys.stderr.write( '\n' )
@@ -765,7 +744,7 @@ for test in tests:
             sys.stderr.write( '%-70s' % cmd_args )
             sys.stderr.flush()
         # end
-        
+
         if ( disabled ):
             if ( comments ):
                 sys.stderr.write( '  (disabled: ' + comments + ')\n' )
@@ -774,23 +753,23 @@ for test in tests:
             go = False
             continue
         # end
-        
+
         if ( make ):
             m = 'make lib ' + cmd
-            print m
+            print(m)
             run( m )
         # end
-        
+
         t = time.time()
         (okay, fail, error, status) = run( cmd_args )
         t = time.time() - t
-        
+
         # count stats
         ntest  += 1
         nokay  += okay
         nfail  += fail
         nerror += error
-        
+
         errmsg = ''
         if ( fail > 0 ):
             errmsg += '  ** %d tests failed' % (fail)
@@ -799,7 +778,7 @@ for test in tests:
         if ( status < 0 ):
             errmsg += '  ** exit with signal %d' % (-status)
             nerror += 1  # count crash as an error
-        
+
         if ( errmsg != '' ):
             if ( batch ):
                 sys.stderr.write( errmsg + '\n' )  # to console
@@ -808,14 +787,14 @@ for test in tests:
         else:
             sys.stderr.write( '  ok\n' )
         # end
-        
+
         if ( batch ):
             # set to sleep a few seconds before next test,
             # to allow processor to cool off some between tests.
             pause = min( t, 5. )
             go = False
         else:
-            x = raw_input( '[enter to continue; M to make and re-run] ' )
+            x = input( '[enter to continue; M to make and re-run] ' )
             if ( x in ('m','M')):
                 make = True
             else:
@@ -837,7 +816,7 @@ else:
     msg += '%5d tests in %d commands passed\n' % (nokay, ntest)
     msg += '%5d tests failed accuracy test\n' % (nfail)
     msg += '%5d errors detected (crashes, CUDA errors, etc.)\n' % (nerror)
-    f = failures.keys()
+    f = list(failures.keys())
     f.sort()
     msg += 'routines with failures:\n    ' + '\n    '.join( f ) + '\n'
 # end
