@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> c d s
        @author Hartwig Anzt
@@ -13,16 +13,12 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
+#if CUDA_VERSION >= 12000
+  #define CUSPARSE_CSRMV_ALG2 CUSPARSE_SPMV_CSR_ALG2
+  #define CUSPARSE_CSRMV_ALG1 CUSPARSE_SPMV_CSR_ALG1
+  #define CUSPARSE_CSRMM_ALG1 CUSPARSE_SPMM_CSR_ALG1
 #endif
 
-
 #if CUDA_VERSION >= 11000 
 // todo: destroy descriptor and see if the original code descriptors have to be changed 
 #define hipsparseZcsrmv(handle, op, rows, cols, nnz, alpha, descr, dval, drow, dcol, x, beta, y) \
@@ -172,8 +168,8 @@ magma_z_spmv(
                 CHECK_CUSPARSE( hipsparseSetMatIndexBase( descr, HIPSPARSE_INDEX_BASE_ZERO ));
                                  
                 hipsparseZcsrmv( hipsparseHandle,HIPSPARSE_OPERATION_NON_TRANSPOSE,
-                                A.num_rows, A.num_cols, A.nnz, (hipblasDoubleComplex*)&alpha, descr,
-                                (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, (hipblasDoubleComplex*)x.dval, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                                A.num_rows, A.num_cols, A.nnz, (hipDoubleComplex*)&alpha, descr,
+                                (hipDoubleComplex*)A.dval, A.drow, A.dcol, (hipDoubleComplex*)x.dval, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else if ( A.storage_type == Magma_CSC )
             {
@@ -184,8 +180,8 @@ magma_z_spmv(
                 CHECK_CUSPARSE( hipsparseSetMatIndexBase( descr, HIPSPARSE_INDEX_BASE_ZERO ));
                 
                 hipsparseZcsrmv( hipsparseHandle,HIPSPARSE_OPERATION_TRANSPOSE,
-                              A.num_rows, A.num_cols, A.nnz, (hipblasDoubleComplex*)&alpha, descr,
-                              (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, (hipblasDoubleComplex*)x.dval, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                              A.num_rows, A.num_cols, A.nnz, (hipDoubleComplex*)&alpha, descr,
+                              (hipDoubleComplex*)A.dval, A.drow, A.dcol, (hipDoubleComplex*)x.dval, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else if ( A.storage_type == Magma_ELL ) {
                 //printf("using ELLPACKT kernel for SpMV: ");
@@ -216,17 +212,6 @@ magma_z_spmv(
 
                 //printf("done.\n");
             }
-            else if ( A.storage_type == Magma_CSR5 ) {
-                //printf("using CSR5 kernel for SpMV: ");
-                CHECK( magma_zgecsr5mv( MagmaNoTrans, A.num_rows, A.num_cols, 
-                   A.csr5_p, alpha, A.csr5_sigma, A.csr5_bit_y_offset, 
-                   A.csr5_bit_scansum_offset, A.csr5_num_packets, 
-                   A.dtile_ptr, A.dtile_desc, A.dtile_desc_offset_ptr, A.dtile_desc_offset, 
-                   A.dcalibrator, A.csr5_tail_tile_start, 
-                   A.dval, A.drow, A.dcol, x.dval, beta, y.dval, queue ));
-
-                //printf("done.\n");
-            }
             else if ( A.storage_type == Magma_DENSE ) {
                 //printf("using DENSE kernel for SpMV: ");
                 magmablas_zgemv( MagmaNoTrans, A.num_rows, A.num_cols, alpha,
@@ -251,8 +236,8 @@ magma_z_spmv(
                CHECK_CUSPARSE( hipsparseCreateMatDescr( &descr ));
                hipsparseZbsrmv( hipsparseHandle, dirA,
                    HIPSPARSE_OPERATION_NON_TRANSPOSE, mb, nb, A.numblocks,
-                   (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, A.blocksize, (hipblasDoubleComplex*)x.dval,
-                   (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval );
+                   (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol, A.blocksize, (hipDoubleComplex*)x.dval,
+                   (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval );
             }
             else {
                 printf("error: format not supported.\n");
@@ -271,8 +256,8 @@ magma_z_spmv(
                     hipsparseZcsrmm(hipsparseHandle,
                                    HIPSPARSE_OPERATION_NON_TRANSPOSE,
                                    A.num_rows,   num_vecs, A.num_cols, A.nnz,
-                                   (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                                   (hipblasDoubleComplex*)x.dval, A.num_cols, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval, A.num_cols);
+                                   (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                                   (hipDoubleComplex*)x.dval, A.num_cols, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval, A.num_cols);
                 } else if ( x.major == MagmaRowMajor) {
                     /*hipsparseZcsrmm2(hipsparseHandle,
                     HIPSPARSE_OPERATION_NON_TRANSPOSE,
@@ -293,8 +278,8 @@ magma_z_spmv(
                         
                         hipsparseZcsrmm( hipsparseHandle,HIPSPARSE_OPERATION_TRANSPOSE,
                                         A.num_rows,   num_vecs, A.num_cols, A.nnz,
-                                        (hipblasDoubleComplex*)&alpha, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                                        (hipblasDoubleComplex*)x.dval, A.num_cols, (hipblasDoubleComplex*)&beta, (hipblasDoubleComplex*)y.dval, A.num_cols);
+                                        (hipDoubleComplex*)&alpha, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                                        (hipDoubleComplex*)x.dval, A.num_cols, (hipDoubleComplex*)&beta, (hipDoubleComplex*)y.dval, A.num_cols);
                     }
             } else if ( A.storage_type == Magma_SELLP ) {
                 if ( x.major == MagmaRowMajor) {
