@@ -1,10 +1,10 @@
 #include "hip/hip_runtime.h"
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> c d s
        @author Hartwig Anzt
@@ -14,18 +14,11 @@
 
 #define PRECISION_z
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#if defined(MAGMA_HAVE_HIP)
-  #ifdef PRECISION_z
-    #define hipblasDoubleComplex hipDoubleComplex
-  #elif defined(PRECISION_c)
-    #define hipblasComplex hipComplex
-  #endif
-#endif
-
-
 #define BLOCK_SIZE 512
 
+#if CUDA_VERSION >= 12000
+  #define CUSPARSE_CSRMV_ALG1 CUSPARSE_SPMV_CSR_ALG1
+#endif
 
 #if CUDA_VERSION >= 11000
 // todo: destroy descriptor and see if the original code descriptors have to be changed
@@ -1105,8 +1098,8 @@ magma_zcgmerge_spmv1(
         hipsparseSetMatType( descr, HIPSPARSE_MATRIX_TYPE_GENERAL );
         hipsparseSetMatIndexBase( descr, HIPSPARSE_INDEX_BASE_ZERO );
         hipsparseZcsrmv( cusparseHandle,HIPSPARSE_OPERATION_NON_TRANSPOSE,
-                        A.num_rows, A.num_cols, A.nnz, (hipblasDoubleComplex*)&c_one, descr,
-                        (hipblasDoubleComplex*)A.dval, A.drow, A.dcol, (hipblasDoubleComplex*)dd, (hipblasDoubleComplex*)&c_zero, (hipblasDoubleComplex*)dz );
+                        A.num_rows, A.num_cols, A.nnz, (hipDoubleComplex*)&c_one, descr,
+                        (hipDoubleComplex*)A.dval, A.drow, A.dcol, (hipDoubleComplex*)dd, (hipDoubleComplex*)&c_zero, (hipDoubleComplex*)dz );
         hipsparseDestroyMatDescr( descr );
         hipsparseDestroy( cusparseHandle );
         cusparseHandle = 0;
