@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
        @author Hartwig Anzt
@@ -13,11 +13,6 @@
 #include <hip/hip_runtime.h>  // for CUDA_VERSION
 
 
-/* For hipSPARSE, they use a separate complex type than for hipBLAS */
-#ifdef MAGMA_HAVE_HIP
-  #define hipblasDoubleComplex hipDoubleComplex
-#endif
-
 
 // todo: check if we need buf later
 #if CUDA_VERSION >= 11000
@@ -27,11 +22,11 @@
         size_t bufsize;                                                                        \
         void *buf;                                                                             \
         cusparseCsr2cscEx2_bufferSize(handle, m, n, nnz, valA, rowA, colA,                     \
-                                      valB, rowB, colB, HIPBLAS_C_64F, action, base,              \
+                                      valB, colB, rowB, HIPBLAS_C_64F, action, base,              \
                                       CUSPARSE_CSR2CSC_ALG1, &bufsize);                        \
         if (bufsize > 0)                                                                       \
-           magma_malloc(&buf, bufsize);                                                        \
-        cusparseCsr2cscEx2(handle, m, n, nnz, valA, rowA, colA, valB, rowB, colB,              \
+           CHECK( magma_malloc(&buf, bufsize) );                                                        \
+        cusparseCsr2cscEx2(handle, m, n, nnz, valA, rowA, colA, valB, colB, rowB,              \
                            HIPBLAS_C_64F, action, base, CUSPARSE_CSR2CSC_ALG1, buf);              \
         if (bufsize > 0)                                                                       \
            magma_free(buf);                                                                    \
@@ -1757,9 +1752,9 @@ magma_zmconvert(
             // conversion using CUSPARSE
             hipsparseZcsr2bsr( cusparseHandle, HIPSPARSE_DIRECTION_ROW,
                               A.num_rows, A.num_cols, descr,
-                              (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
+                              (hipDoubleComplex*)A.dval, A.drow, A.dcol,
                               size_b, descr,
-                              (hipblasDoubleComplex*)B->dval, B->drow, B->dcol);
+                              (hipDoubleComplex*)B->dval, B->drow, B->dcol);
         }
         // BCSR to CSR
         else if ( old_format == Magma_BCSR && new_format == Magma_CSR ) {
@@ -1791,9 +1786,9 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZbsr2csr( cusparseHandle, HIPSPARSE_DIRECTION_ROW,
-                              mb, nb, descr, (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
+                              mb, nb, descr, (hipDoubleComplex*)A.dval, A.drow, A.dcol,
                               size_b, descr,
-                              (hipblasDoubleComplex*)B->dval, B->drow, B->dcol );
+                              (hipDoubleComplex*)B->dval, B->drow, B->dcol );
         }
         // CSR to CSC
         else if ( old_format == Magma_CSR && new_format == Magma_CSC ) {
@@ -1819,8 +1814,8 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZcsr2csc(cusparseHandle, A.num_rows, A.num_cols, A.nnz,
-                             (hipblasDoubleComplex*)A.dval, A.drow, A.dcol,
-                             (hipblasDoubleComplex*)B->dval, B->drow, B->dcol,
+                             (hipDoubleComplex*)A.dval, A.drow, A.dcol,
+                             (hipDoubleComplex*)B->dval, B->drow, B->dcol,
                              HIPSPARSE_ACTION_NUMERIC,
                              HIPSPARSE_INDEX_BASE_ZERO);
         }
@@ -1848,8 +1843,8 @@ magma_zmconvert(
 
             // conversion using CUSPARSE
             hipsparseZcsr2csc(cusparseHandle, A.num_cols, A.num_rows, A.nnz,
-                             (hipblasDoubleComplex*)A.dval, A.dcol, A.drow,
-                             (hipblasDoubleComplex*)B->dval, B->dcol, B->drow,
+                             (hipDoubleComplex*)A.dval, A.dcol, A.drow,
+                             (hipDoubleComplex*)B->dval, B->dcol, B->drow,
                              HIPSPARSE_ACTION_NUMERIC,
                              HIPSPARSE_INDEX_BASE_ZERO);
         }
@@ -1920,19 +1915,31 @@ magma_zmconvert(
 
             // step 1: allocate buffer
             hipsparseXcoosort_bufferSizeExt(cusparseHandle, m, n, nnz, B->drowidx, B->dcol, &pBufferSizeInBytes);
-            //hipMalloc( &pBuffer, sizeof(char)* pBufferSizeInBytes);
             CHECK( magma_malloc( &pBuffer, sizeof(char)* pBufferSizeInBytes ));
             // step 2: setup permutation vector P to identity
             CHECK( magma_index_malloc( &P, nnz ));
-            //magma_( &P, sizeof(int)*nnz);
             hipsparseCreateIdentityPermutation(cusparseHandle, nnz, P);
 
             // step 3: sort COO format by Row
             hipsparseXcoosortByRow(cusparseHandle, m, n, nnz, B->drowidx, B->dcol, P, pBuffer);
 
             // step 4: gather sorted cooVals
+#if CUDA_VERSION >= 12000
+            cusparseSpVecDescr_t vec_permutation;
+            cusparseDnVecDescr_t vec_values;
+            CHECK_CUSPARSE( cusparseCreateSpVec(&vec_permutation, A.nnz, A.nnz,
+                                                P, B->dval,
+                                                CUSPARSE_INDEX_32I,
+                                                HIPSPARSE_INDEX_BASE_ZERO, HIPBLAS_C_64F) );
+            CHECK_CUSPARSE( cusparseCreateDnVec(&vec_values, A.nnz, A.dval, HIPBLAS_C_64F) );
+            CHECK_CUSPARSE( cusparseGather(cusparseHandle, vec_values, vec_permutation) );
+            
+            // destroy matrix/vector descriptors
+            CHECK_CUSPARSE( cusparseDestroySpVec(vec_permutation) );
+            CHECK_CUSPARSE( cusparseDestroyDnVec(vec_values) );
+#else
             hipsparseZgthr(cusparseHandle, nnz, A.dval, B->dval, P, HIPSPARSE_INDEX_BASE_ZERO);
-
+#endif
 
             // conversion using CUSPARSE
             hipsparseXcoo2csr( cusparseHandle, B->drowidx,
