@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
        @author Hartwig Anzt
@@ -226,21 +226,10 @@ magma_zsolverinfo(
                 printf("%%   Preconditioner used: ILU(%lld).\n",
                         (long long) precond_par->levels );
                 break;
-            case Magma_PARILU:
-                printf("%%   Preconditioner used: ParILU(%lld).\n",
-                        (long long) precond_par->levels );
-                break;
             case Magma_ICC:
                 printf("%%   Preconditioner used: IC(%lld).\n",
                         (long long) precond_par->levels );
                 break;
-            case Magma_PARIC:
-                printf("%%   Preconditioner used: ParIC(%lld).\n",
-                        (long long) precond_par->levels );
-                break;
-            case Magma_ISAI:
-                printf("%%   Preconditioner used: ParILU-SPAI.\n" );
-                break;
             default:
                 break;
         }
@@ -595,11 +584,14 @@ magma_zsolverinfo_init(
     precond_par->UDT.row = NULL;
     precond_par->UDT.blockinfo = NULL;
     
-    // todo: error: invalid conversion from 'long int' to 'hipsparseSolvePolicy_t'
-    //precond_par->cuinfoL = NULL;
-    //precond_par->cuinfoU = NULL;
-    //precond_par->cuinfoLT = NULL;
-    //precond_par->cuinfoUT = NULL;
+    precond_par->cuinfoL.descr = NULL;
+    precond_par->cuinfoU.descr = NULL;
+    precond_par->cuinfoLT.descr = NULL;
+    precond_par->cuinfoUT.descr = NULL;
+    precond_par->cuinfoL.buffer = NULL;
+    precond_par->cuinfoU.buffer = NULL;
+    precond_par->cuinfoLT.buffer = NULL;
+    precond_par->cuinfoUT.buffer = NULL;
     
     precond_par->L_dgraphindegree = NULL;
     precond_par->U_dgraphindegree = NULL;
