@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 */
 
 #ifndef MAGMASPARSE_H
@@ -22,10 +22,6 @@
 #include "magmasparse_d.h"
 #include "magmasparse_s.h"
 
-// mixed precision
-#include "magmasparse_zc.h"
-#include "magmasparse_ds.h"
-
 /* ------------------------------------------------------------
  * MAGMASPARSE types
  * --------------------------------------------------------- */
