@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal d -> s
        @author Stan Tomov
@@ -88,7 +88,11 @@
             after another in the columns of VL, in the same order
             as their eigenvalues.
             If JOBVL = MagmaNoVec, VL is not referenced.
-            u(j) = VL(:,j), the j-th column of VL.
+            If the j-th eigenvalue is real, then u(j) = VL(:,j),
+            the j-th column of VL.
+            If the j-th and (j+1)-st eigenvalues form a complex
+            conjugate pair, then u(j)   = VL(:,j) + i*VL(:,j+1)
+            and                  u(j+1) = VL(:,j) - i*VL(:,j+1).
 
     @param[in]
     ldvl    INTEGER
@@ -101,7 +105,11 @@
             after another in the columns of VR, in the same order
             as their eigenvalues.
             If JOBVR = MagmaNoVec, VR is not referenced.
-            v(j) = VR(:,j), the j-th column of VR.
+            If the j-th eigenvalue is real, then v(j) = VR(:,j),
+            the j-th column of VR.
+            If the j-th and (j+1)-st eigenvalues form a complex
+            conjugate pair, then v(j)   = VR(:,j) + i*VR(:,j+1)
+            and                  v(j+1) = VR(:,j) - i*VR(:,j+1).
 
     @param[in]
     ldvr    INTEGER
@@ -128,7 +136,7 @@
       -     < 0:  if INFO = -i, the i-th argument had an illegal value.
       -     > 0:  if INFO = i, the QR algorithm failed to compute all the
                   eigenvalues, and no eigenvectors have been computed;
-                  elements and i+1:N of W contain eigenvalues which have
+                  elements and i+1:N of w contain eigenvalues which have
                   converged.
 
     @ingroup magma_geev
@@ -152,10 +160,10 @@ magma_dgeev_m(
 {
     #define VL(i,j)  (VL + (i) + (j)*ldvl)
     #define VR(i,j)  (VR + (i) + (j)*ldvr)
-    
+
     const magma_int_t ione  = 1;
     const magma_int_t izero = 0;
-    
+
     double d__1, d__2;
     double r, cs, sn, scl;
     double dum[1], eps;
@@ -163,15 +171,15 @@ magma_dgeev_m(
     magma_int_t i, k, ilo, ihi;
     magma_int_t ibal, ierr, itau, iwrk, nout, liwrk, nb;
     magma_int_t scalea, minwrk, optwrk, lquery, wantvl, wantvr, select[1];
-    
+
     magma_side_t side = MagmaRight;
     magma_int_t ngpu = magma_num_gpus();
-    
+
     magma_timer_t time_total=0, time_gehrd=0, time_unghr=0, time_hseqr=0, time_trevc=0, time_sum=0;
     magma_flops_t flop_total=0, flop_gehrd=0, flop_unghr=0, flop_hseqr=0, flop_trevc=0, flop_sum=0;
     timer_start( time_total );
     flops_start( flop_total );
-    
+
     *info = 0;
     lquery = (lwork == -1);
     wantvl = (jobvl == MagmaVec);
@@ -196,7 +204,7 @@ magma_dgeev_m(
         minwrk = (2 +   nb + nb*ngpu)*n;
         optwrk = (2 + 2*nb + nb*ngpu)*n;
         work[0] = magma_dmake_lwork( optwrk );
-        
+
         if (lwork < minwrk && ! lquery) {
             *info = -13;
         }
@@ -214,7 +222,7 @@ magma_dgeev_m(
     if (n == 0) {
         return *info;
     }
-   
+
     #if defined(Version3)
     double *dT;
     if (MAGMA_SUCCESS != magma_dmalloc( &dT, nb*n )) {
@@ -504,15 +512,15 @@ CLEANUP:
     #if defined(Version5)
     magma_free_cpu( T );
     #endif
-    
+
     timer_stop( time_total );
     flops_stop( flop_total );
     timer_printf( "dgeev times n %5lld, gehrd %7.3f, unghr %7.3f, hseqr %7.3f, trevc %7.3f, total %7.3f, sum %7.3f\n",
                   (long long) n, time_gehrd, time_unghr, time_hseqr, time_trevc, time_total, time_sum );
     timer_printf( "dgeev flops n %5lld, gehrd %7lld, unghr %7lld, hseqr %7lld, trevc %7lld, total %7lld, sum %7lld\n",
                   (long long) n, flop_gehrd, flop_unghr, flop_hseqr, flop_trevc, flop_total, flop_sum );
-    
+
     work[0] = magma_dmake_lwork( optwrk );
-    
+
     return *info;
 } /* magma_dgeev */
