@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions mixed zc -> ds
 
@@ -390,6 +390,7 @@ fallback:
     }
 
 cleanup:
+    magma_queue_sync( queue );
     magma_free( dworks );
     magma_free( dworkd );
     magma_free_cpu( hworks );
