@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions mixed zc -> ds
 
@@ -224,7 +224,8 @@ magma_zcgesv_gpu(
     }
     
     // factor dSA in single precision
-    magma_cgetrf_gpu( n, n, dSA, lddsa, ipiv, info );
+    // magma_cgetrf_gpu( n, n, dSA, lddsa, ipiv, info );
+    magma_cgetrf_native( n, n, dSA, lddsa, ipiv, info );
     if (*info != 0) {
         *iter = -3;
         goto fallback;
