@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
        @author Adrien REMY
@@ -44,13 +44,13 @@ init_butterfly(
 
     Arguments
     ---------
-    
+
     @param[in]
     gen     magma_bool_t
      -         = MagmaTrue:     new matrices are generated for U and V
      -         = MagmaFalse:    matrices U and V given as parameter are used
 
-    
+
     @param[in]
     n       INTEGER
             The order of the matrix A.  n >= 0.
@@ -108,7 +108,7 @@ magma_zgerbt_gpu(
     magma_int_t *info)
 {
     #define dB(i_, j_) (dB + (i_) + (j_)*lddb)
-    
+
     /* Function Body */
     *info = 0;
     if ( ! (gen == MagmaTrue) &&
@@ -133,10 +133,8 @@ magma_zgerbt_gpu(
     if (nrhs == 0 || n == 0)
         return *info;
 
-    magmaDoubleComplex_ptr dU=NULL, dV=NULL;
-    magma_int_t j;
-
     /* Allocate memory for the buterfly matrices */
+    magmaDoubleComplex_ptr dU=NULL, dV=NULL;
     if (MAGMA_SUCCESS != magma_zmalloc( &dU, 2*n ) ||
         MAGMA_SUCCESS != magma_zmalloc( &dV, 2*n )) {
         magma_free( dU );
@@ -149,7 +147,7 @@ magma_zgerbt_gpu(
     magma_device_t cdev;
     magma_getdevice( &cdev );
     magma_queue_create( cdev, &queue );
-    
+
     /* Initialize Butterfly matrix on the CPU */
     if (gen == MagmaTrue)
         init_butterfly( 2*n, U, V );
@@ -162,10 +160,9 @@ magma_zgerbt_gpu(
     magmablas_zprbt( n, dA, ldda, dU, dV, queue );
 
     /* Compute U^T * b on the GPU*/
-    for (j= 0; j < nrhs; j++) {
-        magmablas_zprbt_mtv( n, dU, dB(0,j), queue );
-    }
+    magmablas_zprbt_mtv(n, nrhs, dU, dB, lddb, queue);
 
+    magma_queue_sync( queue );
     magma_queue_destroy( queue );
     magma_free( dU );
     magma_free( dV );
