@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> s d c
 
@@ -56,7 +56,7 @@
     B       COMPLEX_16 array, dimension (LDB,NRHS)
             On entry, the right hand side matrix B.
             On exit, the solution matrix X.
-    
+
     @param[in]
     ldb     INTEGER
             The leading dimension of the array B.  LDB >= max(1,N).
@@ -78,14 +78,14 @@ magma_zgesv_rbt(
     /* Constants */
     const magmaDoubleComplex c_zero = MAGMA_Z_ZERO;
     const magmaDoubleComplex c_one  = MAGMA_Z_ONE;
-    
+
     /* Local variables */
-    magma_int_t nn = magma_roundup( n, 4 );  // n + ((4-(n % 4))%4);
+    magma_int_t nn = n;//magma_roundup( n, 4 );
     magmaDoubleComplex *hu=NULL, *hv=NULL;
     magmaDoubleComplex_ptr dA=NULL, dB=NULL, dAo=NULL, dBo=NULL, dwork=NULL, dv=NULL;
-    magma_int_t i, iter;
+    magma_int_t iter;
     magma_queue_t queue=NULL;
-    
+
     /* Function Body */
     *info = 0;
     if ( ! (refine == MagmaTrue) &&
@@ -110,6 +110,13 @@ magma_zgesv_rbt(
     if (nrhs == 0 || n == 0)
         return *info;
 
+    // TODO: investigate failures on AMD GPUs
+    // For now ignore refine and always set it to False
+    // there is probably a bug in the refinement code for the HIP backend
+    #ifdef MAGMA_HAVE_HIP
+    refine = MagmaFalse;
+    #endif
+
     if (MAGMA_SUCCESS != magma_zmalloc( &dA, nn*nn ) ||
         MAGMA_SUCCESS != magma_zmalloc( &dB, nn*nrhs ))
     {
@@ -137,7 +144,7 @@ magma_zgesv_rbt(
     magma_device_t cdev;
     magma_getdevice( &cdev );
     magma_queue_create( cdev, &queue );
-    
+
     magmablas_zlaset( MagmaFull, nn, nn, c_zero, c_one, dA, nn, queue );
 
     /* Send matrix to the GPU */
@@ -159,10 +166,10 @@ magma_zgesv_rbt(
     magma_zgesv_nopiv_gpu( nn, nrhs, dA, nn, dB, nn, info );
 
     /* Iterative refinement */
+
     if (refine == MagmaTrue) {
         magma_zgerfs_nopiv_gpu( MagmaNoTrans, nn, nrhs, dAo, nn, dBo, nn, dB, nn, dwork, dA, &iter, info );
     }
-    //printf("iter = %lld\n", (long long) iter );
 
     /* The solution of A.x = b is Vy computed on the GPU */
     if (MAGMA_SUCCESS != magma_zmalloc( &dv, 2*nn )) {
@@ -171,28 +178,26 @@ magma_zgesv_rbt(
     }
 
     magma_zsetvector( 2*nn, hv, 1, dv, 1, queue );
-    
-    for (i = 0; i < nrhs; i++) {
-        magmablas_zprbt_mv( nn, dv, dB+(i*nn), queue );
-    }
+
+    magmablas_zprbt_mv(nn, nrhs, dv, dB, nn, queue);
 
     magma_zgetmatrix( n, nrhs, dB, nn, B, ldb, queue );
 
 cleanup:
     magma_queue_destroy( queue );
-    
+
     magma_free_cpu( hu );
     magma_free_cpu( hv );
 
     magma_free( dA );
     magma_free( dv );
     magma_free( dB );
-    
+
     if (refine == MagmaTrue) {
         magma_free( dAo );
         magma_free( dBo );
         magma_free( dwork );
     }
-    
+
     return *info;
 }
