@@ -1,9 +1,9 @@
 /*
-   -- MAGMA (version 2.6.2) --
+   -- MAGMA (version 2.10.0) --
    Univ. of Tennessee, Knoxville
    Univ. of California, Berkeley
    Univ. of Colorado, Denver
-   @date March 2022
+   @date February 2026
 
    @author Azzam Haidar
    @author Adrien Remy
@@ -161,6 +161,7 @@ magma_zgetrf_recpanel_nopiv_batched(
         if (arginfo != 0) return arginfo;
     }
 
+    magma_queue_sync( queue );
     magma_free(dA_displ);
     return 0;
 }
