@@ -1,15 +1,15 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
-    
+       @date February 2026
+
        @author Raffaele Solca
        @author Stan Tomov
        @author Mark Gates
        @author Azzam Haidar
-    
+
        @precisions normal z -> c
 
 */
@@ -17,7 +17,7 @@
 #include "magma_timer.h"
 
 #define COMPLEX
-#define FAST_HEMV
+//#define USE_MAGMABLAS_HEMV
 
 /***************************************************************************//**
     Purpose
@@ -283,7 +283,7 @@ magma_zheevdx_gpu(
         lrwmin = n;
         liwmin = 1;
     }
-    
+
     work[0]  = magma_zmake_lwork( lwmin );
     rwork[0] = magma_dmake_lwork( lrwmin );
     iwork[0] = liwmin;
@@ -407,7 +407,7 @@ magma_zheevdx_gpu(
     magma_timer_t time=0;
     timer_start( time );
 
-#ifdef FAST_HEMV
+#ifdef USE_MAGMABLAS_HEMV
     magma_zhetrd2_gpu( uplo, n, dA, ldda, w, &rwork[inde],
                        &work[indtau], wA, ldwa, &work[indwrk], llwork,
                        dC, ldwork, &iinfo );
