@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Stan Tomov
        @author Mark Gates
@@ -14,10 +14,11 @@
 */
 #include "magma_internal.h"
 
-// === Define what BLAS to use ============================================
-//    #undef  magma_ztrsm
-//    #define magma_ztrsm magmablas_ztrsm
-// === End defining what BLAS to use =======================================
+// rocBLAS has a very slow syrk/herk
+// switch to magmablas syrk/herk (which internally calls rocBLAS GEMM)
+#if defined(MAGMA_HAVE_HIP)
+#define magma_zherk    magmablas_zherk
+#endif
 
 /***************************************************************************//**
     Purpose
@@ -37,8 +38,8 @@
     ---------
     @param[in]
     uplo    magma_uplo_t
-      -     = MagmaUpper:  Upper triangle of dA is stored;
-      -     = MagmaLower:  Lower triangle of dA is stored.
+      -     = MagmaUpper:  Upper triangle of dA is stored (hybrid mode only);
+      -     = MagmaLower:  Lower triangle of dA is stored (hybrid & native modes).
 
     @param[in]
     n       INTEGER
@@ -58,7 +59,7 @@
             factorization dA = U**H * U or dA = L * L**H.
 
     @param[in]
-    ldda     INTEGER
+    ldda    INTEGER
             The leading dimension of the array dA.  LDDA >= max(1,N).
             To benefit from coalescent memory accesses LDDA must be
             divisible by 16.
@@ -73,17 +74,70 @@
 
     @param[in]
     mode    magma_mode_t
-      -     = MagmaNative:  Factorize dA using GPU only mode (only uplo=MagmaLower is available);
+      -     = MagmaNative:  Factorize dA using GPU only mode.
       -     = MagmaHybrid:  Factorize dA using Hybrid (CPU/GPU) mode.
 
+    @param[in]
+    nb      INTEGER
+            The blocking size used during the factorization. nb > 0;
+            Users with no specific preference of nb can call magma_get_zpotrf_nb()
+            to get the value of nb as determined by MAGMA's internal tuning.
+
+    @param[in]
+    recnb   INTEGER
+            The blocking size used during the recursive panel factorization (0 < recnb <= nb);
+            Users with no specific preference of recnb can set it to a fixed value of
+            64 or 128.
+
+    @param[in,out]
+    host_work  Workspace, allocated on host (CPU) memory. For faster CPU-GPU communication,
+               user can allocate it as pinned memory using magma_malloc_pinned()
+
+    @param[in,out]
+    lwork_host   INTEGER pointer
+                 The size of the workspace (host_work) in bytes
+                 - lwork_host[0] < 0: a workspace query is assumed, the routine
+                   calculates the required amount of workspace and returns
+                   it in lwork_host. The workspace itself is not referenced, and no
+                   factorization is performed.
+                -  lwork[0] >= 0: the routine assumes that the user has provided
+                   a workspace with the size in lwork_host.
+
+    @param[in,out]
+    device_work  Workspace, allocated on device (GPU) memory.
+
+    @param[in,out]
+    lwork_device   INTEGER pointer
+                   The size of the workspace (device_work) in bytes
+                   - lwork_device[0] < 0: a workspace query is assumed, the routine
+                     calculates the required amount of workspace and returns
+                     it in lwork_device. The workspace itself is not referenced, and no
+                     factorization is performed.
+                   - lwork_device[0] >= 0: the routine assumes that the user has provided
+                     a workspace with the size in lwork_device.
+
+    @param[in]
+    events        magma_event_t array of size two
+                  - created/destroyed by the user outside the routine
+                  - Used to manage inter-stream dependencies
+
+    @param[in]
+    queues        magma_queue_t array of size two
+                  - created/destroyed by the user outside the routine
+                  - Used for concurrent kernel execution, if possible
+
     @ingroup magma_potrf
 *******************************************************************************/
 extern "C" magma_int_t
-magma_zpotrf_expert_gpu(
+magma_zpotrf_expert_gpu_work(
     magma_uplo_t uplo, magma_int_t n,
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t *info,
-    magma_int_t nb, magma_mode_t mode )
+    magma_mode_t mode,
+    magma_int_t nb, magma_int_t recnb,
+    void* host_work,   magma_int_t *lwork_host,
+    void* device_work, magma_int_t *lwork_device,
+    magma_event_t events[2], magma_queue_t queues[2] )
 {
     #ifdef MAGMA_HAVE_OPENCL
     #define dA(i_, j_)  dA, ((i_) + (j_)*ldda + dA_offset)
@@ -98,11 +152,38 @@ magma_zpotrf_expert_gpu(
     const double d_neg_one = -1.0;
 
     /* Local variables */
-    magma_int_t j, jb, recnb;
-    magmaDoubleComplex *work;
-    magma_int_t *dinfo;
+    magma_int_t j, jb;
+    magmaDoubleComplex *work = NULL;
+    magma_int_t *dinfo = NULL;
 
+    /* Quick return if possible */
     *info = 0;
+    if (n == 0) return *info;
+
+    // calculate the required workspace in bytes
+    magma_int_t h_workspace_bytes = 0;
+    magma_int_t d_workspace_bytes = 0;
+    if (mode == MagmaHybrid) {
+        if ( nb <= 1 || 4*nb >= n ) {
+            h_workspace_bytes += n * n * sizeof(magmaDoubleComplex);
+        }
+        else {
+            h_workspace_bytes += nb * nb * sizeof(magmaDoubleComplex);
+        }
+    }
+    else {
+        d_workspace_bytes += 1 * sizeof(magma_int_t);
+    }
+
+    // check for workspace query
+    if( *lwork_host < 0 || *lwork_device < 0 ) {
+        *lwork_host   = h_workspace_bytes;
+        *lwork_device = d_workspace_bytes;
+        *info  = 0;
+        return 0;
+    }
+
+    // check input arguments
     if (uplo != MagmaUpper && uplo != MagmaLower) {
         *info = -1;
     } else if (n < 0) {
@@ -110,52 +191,43 @@ magma_zpotrf_expert_gpu(
     } else if (ldda < max(1,n)) {
         *info = -4;
     }
+    else if( mode != MagmaHybrid && mode != MagmaNative) {
+        *info = -6;
+    }
+    else if(nb <= 0) {
+        *info = -7;
+    }
+    else if(recnb <= 0) {
+        *info = -8;
+    }
+    else if( *lwork_host   < h_workspace_bytes ) {
+        *info = -10;
+    }
+    else if( *lwork_device < d_workspace_bytes ) {
+        *info = -12;
+    }
+
     if (*info != 0) {
         magma_xerbla( __func__, -(*info) );
         return *info;
     }
 
-    /* Quick return if possible */
-    if (n == 0)
-        return *info;
-
-    recnb = 128;
-
+    // assign pointers
     if (mode == MagmaHybrid) {
-        if (nb <= 1 || 4*nb >= n ) {
-            /* Use CPU code. */
-            if ( MAGMA_SUCCESS != magma_zmalloc_cpu( &work, n*n )) {
-                *info = MAGMA_ERR_HOST_ALLOC;
-                return *info;
-            }
-            magma_zgetmatrix( n, n, dA(0,0), ldda, work, n, NULL);
-            lapackf77_zpotrf(lapack_uplo_const(uplo), &n, work, &n, info );
-            magma_zsetmatrix( n, n, work, n, dA(0,0), ldda, NULL);
-            magma_free_cpu( work );  work=NULL;
-
-            return *info;
-        }
-        else if (MAGMA_SUCCESS != magma_zmalloc_pinned( &work, nb*nb )) {
-            *info = MAGMA_ERR_HOST_ALLOC;
-            goto cleanup;
-        }
+        work = (magmaDoubleComplex*) host_work;
     }
     else {
-        if (MAGMA_SUCCESS != magma_imalloc( &dinfo, 1 ) ) {
-            /* alloc failed for workspace */
-            *info = MAGMA_ERR_DEVICE_ALLOC;
-            goto cleanup;
-        }
+        dinfo = (magma_int_t*) device_work;
+    }
+
+    if ( mode == MagmaHybrid && (nb <= 1 || 4*nb >= n) ) {
+        /* Use CPU only */
+        magma_zgetmatrix( n, n, dA(0,0), ldda, work, n, queues[0]);
+        lapackf77_zpotrf(lapack_uplo_const(uplo), &n, work, &n, info );
+        magma_zsetmatrix( n, n, work, n, dA(0,0), ldda, queues[0]);
+        return *info;
     }
 
-    magma_queue_t queues[2];
-    magma_event_t events[2];
-    magma_device_t cdev;
-    magma_getdevice( &cdev );
-    magma_queue_create( cdev, &queues[0] );
-    magma_queue_create( cdev, &queues[1] );
-    magma_event_create(&events[0]);
-    magma_event_create(&events[1]);
     if (mode == MagmaNative)
         magma_setvector( 1, sizeof(magma_int_t), info, 1, dinfo, 1, queues[0]);
 
@@ -236,6 +308,7 @@ magma_zpotrf_expert_gpu(
                 magma_zpotrf_rectile_native(MagmaLower, jb, recnb,
                                             dA(j, j), ldda, j,
                                             dinfo, info, queues[0] );
+                magma_event_record(events[0], queues[0]);
             }
 
             // apply all previous updates to block column below diagonal block
@@ -276,9 +349,85 @@ magma_zpotrf_expert_gpu(
         }
     }
     if (mode == MagmaNative)
-        magma_getvector( 1, sizeof(magma_int_t), dinfo, 1, info, 1, queues[0]);
+        magma_getvector_async( 1, sizeof(magma_int_t), dinfo, 1, info, 1, queues[0]);
+
+    return *info;
+} /* magma_zpotrf_expert_gpu_work */
+
+/***************************************************************************//**
+    wrapper around magma_zpotrf_expert_gpu_work to hide workspace, event,
+    and queue management
+    @see magma_zpotrf_expert_gpu_work
+    @ingroup magma_potrf
+*******************************************************************************/
+extern "C" magma_int_t
+magma_zpotrf_expert_gpu(
+    magma_uplo_t uplo, magma_int_t n,
+    magmaDoubleComplex_ptr dA, magma_int_t ldda,
+    magma_int_t *info,
+    magma_int_t nb, magma_mode_t mode )
+{
+
+    *info = 0;
+    if (uplo != MagmaUpper && uplo != MagmaLower) {
+        *info = -1;
+    } else if (n < 0) {
+        *info = -2;
+    } else if (ldda < max(1,n)) {
+        *info = -4;
+    }
+    else if( nb <= 0 ) {
+        *info = -6;
+    }
+    else if( mode != MagmaHybrid && mode != MagmaNative ) {
+        *info = -7;
+    }
+
+    if (*info != 0) {
+        magma_xerbla( __func__, -(*info) );
+        return *info;
+    }
+
+    /* Quick return if possible */
+    if (n == 0)
+        return *info;
+
+    magma_int_t recnb = 128;
+
+    magma_queue_t queues[2];
+    magma_event_t events[2];
+    magma_device_t cdev;
+    magma_getdevice( &cdev );
+    magma_queue_create( cdev, &queues[0] );
+    magma_queue_create( cdev, &queues[1] );
+    magma_event_create(&events[0]);
+    magma_event_create(&events[1]);
+
+    // query workspace
+    magma_int_t lhwork[1] = {-1}, ldwork[1] = {-1};
+    magma_zpotrf_expert_gpu_work(
+        uplo, n, NULL, ldda, info,
+        mode, nb, recnb,
+        NULL, lhwork, NULL, ldwork,
+        events, queues );
+
+    // alloc workspace
+    void *hwork = NULL, *dwork=NULL;
+    if( lhwork[0] > 0 ) {
+        magma_malloc_pinned( (void**)&hwork, lhwork[0] );
+    }
+
+    if( ldwork[0] > 0 ) {
+        magma_malloc( (void**)&dwork, ldwork[0] );
+    }
+
+    // main call
+    magma_zpotrf_expert_gpu_work(
+        uplo, n, dA, ldda, info,
+        mode, nb, recnb,
+        hwork, lhwork, dwork, ldwork,
+        events, queues );
 
-cleanup:
     magma_queue_sync( queues[0] );
     magma_queue_sync( queues[1] );
     magma_event_destroy( events[0] );
@@ -286,11 +435,13 @@ cleanup:
     magma_queue_destroy( queues[0] );
     magma_queue_destroy( queues[1] );
 
-    if (mode == MagmaHybrid) {
-        magma_free_pinned( work );
+    // free workspace
+    if( hwork != NULL) {
+        magma_free_pinned( hwork );
     }
-    else {
-        magma_free( dinfo );
+
+    if( dwork != NULL ) {
+        magma_free( dwork );
     }
 
     return *info;
@@ -308,6 +459,20 @@ magma_zpotrf_gpu(
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t *info )
 {
+    *info = 0;
+    if (uplo != MagmaUpper && uplo != MagmaLower) {
+        *info = -1;
+    } else if (n < 0) {
+        *info = -2;
+    } else if (ldda < max(1,n)) {
+        *info = -4;
+    }
+
+    if (*info != 0) {
+        magma_xerbla( __func__, -(*info) );
+        return *info;
+    }
+
     magma_mode_t mode = MagmaHybrid;
     magma_int_t nb = magma_get_zpotrf_nb( n );
     magma_zpotrf_expert_gpu(uplo, n, dA, ldda, info, nb, mode);
@@ -326,6 +491,20 @@ magma_zpotrf_native(
     magmaDoubleComplex_ptr dA, magma_int_t ldda,
     magma_int_t *info )
 {
+    *info = 0;
+    if (uplo != MagmaUpper && uplo != MagmaLower) {
+        *info = -1;
+    } else if (n < 0) {
+        *info = -2;
+    } else if (ldda < max(1,n)) {
+        *info = -4;
+    }
+
+    if (*info != 0) {
+        magma_xerbla( __func__, -(*info) );
+        return *info;
+    }
+
     magma_mode_t mode = MagmaNative;
     magma_int_t nb = magma_get_zpotrf_nb( n );
     magma_zpotrf_expert_gpu(uplo, n, dA, ldda, info, nb, mode);
