@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
        
        @author Azzam Haidar
        @author Ichi Yamazaki
@@ -11,8 +11,6 @@
        @precisions normal z -> s d c
 
 */
-#ifndef MAGMA_NO_V1
-
 #include "magma_internal.h"
 #include "trace.h"
 
@@ -512,4 +510,3 @@ magma_zpotrf_mgpu_right(
 #undef STREAM_ID
 
 #endif // needs updating to MAGMA v2 interfaces
-#endif // MAGMA_NO_V1
