@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Azzam Haidar
        @author Tingxing Dong
@@ -55,6 +55,7 @@ magma_zpotrf_panel_vbatched(
                                            0, batchCount,
                                            max_n-nb, nb, queue );
     }
+    magma_queue_sync( queue );
     magma_free( n_minus_ib );
     return arginfo;
 }
