@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @author Ichitaro Yamazaki
        @author Stan Tomov
@@ -252,6 +252,8 @@ magma_zsytrf_nopiv_gpu(
     }
     
     trace_finalize( "zhetrf.svg","trace.css" );
+    magma_queue_sync( queues[0] );
+    magma_queue_sync( queues[1] );
     magma_queue_destroy( queues[0] );
     magma_queue_destroy( queues[1] );
     magma_event_destroy( event );
