@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> c d s
 
@@ -30,19 +30,19 @@ int main( int argc, char** argv)
 {
     TESTING_CHECK( magma_init() );
     magma_print_environment();
-    
+
     real_Double_t    gflops, gpu_perf, gpu_time, cpu_perf=0, cpu_time=0;
     magmaDoubleComplex *h_A, *h_R, *tau, *h_work;
     magmaDoubleComplex_ptr d_A, dtau, d_work;
     magma_int_t *jpvt;
-    magma_int_t M, N, K, n2, lda, lwork, j, info, min_mn, nb;
+    magma_int_t M, N, K, n2, lda, lwork, j, info, min_mn;
     int status = 0;
-    
+
     magma_opts opts;
     opts.parse_opts( argc, argv );
 
     double tol = opts.tolerance * lapackf77_dlamch("E");
-    
+
     printf("%% M     N     CPU Gflop/s (sec)   GPU Gflop/s (sec)   ||A*P - Q*R||_F\n");
     printf("%%====================================================================\n");
     for( int itest = 0; itest < opts.ntest; ++itest ) {
@@ -55,37 +55,40 @@ int main( int argc, char** argv)
                         (long long) M, (long long) N, (long long) K );
                 continue;
             }
- 
+
             min_mn = min(M, N);
             lda    = M;
             n2     = lda*N;
-            nb     = magma_get_zgeqp3_nb( M, N );
             gflops = FLOPS_ZGEQRF( M, N ) / 1e9;
-            
-            lwork = ( N+1 )*nb;
-            #ifdef REAL
-            lwork += 2*N;
-            #endif
+
+            // get lwork from expert interface
+            magma_int_t geqp3_lhwork_bytes[1] = {-1};
+            magma_int_t geqp3_ldwork_bytes[1] = {-1};
+            magma_zgeqp3_expert_gpu_work(
+                M, N, NULL, lda, NULL, NULL,
+                NULL, geqp3_lhwork_bytes, NULL, geqp3_ldwork_bytes,
+                &info, opts.queue );
+
+            lwork = magma_ceildiv( geqp3_ldwork_bytes[0], sizeof(magmaDoubleComplex) );
+
             if ( opts.check )
                 lwork = max( lwork, M*N + N );
-            
+
             #ifdef COMPLEX
             double *rwork;
-            magmaDouble_ptr drwork;
-            TESTING_CHECK( magma_dmalloc( &drwork, 2*N + (N+1)*nb ));
             TESTING_CHECK( magma_dmalloc_cpu( &rwork,  2*N ));
             #endif
             TESTING_CHECK( magma_imalloc_cpu( &jpvt,   N      ));
             TESTING_CHECK( magma_zmalloc_cpu( &tau,    min_mn ));
             TESTING_CHECK( magma_zmalloc_cpu( &h_A,    n2     ));
-            
+
             TESTING_CHECK( magma_zmalloc_pinned( &h_R,    n2     ));
             TESTING_CHECK( magma_zmalloc_pinned( &h_work, lwork  ));
-            
+
             TESTING_CHECK( magma_zmalloc( &dtau,   min_mn ));
             TESTING_CHECK( magma_zmalloc( &d_A,    lda*N  ));
             TESTING_CHECK( magma_zmalloc( &d_work, lwork  ));
-            
+
             /* Initialize the matrix */
             magma_generate_matrix( opts, M, N, h_R, lda );
 
@@ -96,14 +99,14 @@ int main( int argc, char** argv)
                           &beta, h_A, &lda);
 
             lapackf77_zlacpy( MagmaFullStr, &M, &N, h_A, &lda, h_R, &lda );
-            
+
             /* =====================================================================
                Performs operation using LAPACK
                =================================================================== */
             if ( opts.lapack ) {
                 for( j = 0; j < N; j++)
                     jpvt[j] = 0;
-                
+
                 cpu_time = magma_wtime();
                 lapackf77_zgeqp3( &M, &N, h_R, &lda, jpvt, tau, h_work, &lwork,
                                   #ifdef COMPLEX
@@ -117,14 +120,14 @@ int main( int argc, char** argv)
                            (long long) info, magma_strerror( info ));
                 }
             }
-            
+
             /* ====================================================================
                Performs operation using MAGMA
                =================================================================== */
             lapackf77_zlacpy( MagmaFullStr, &M, &N, h_A, &lda, h_R, &lda );
             for( j = 0; j < N; j++)
                 jpvt[j] = 0;
-            
+
             /* copy A to gpu */
             magma_zsetmatrix( M, N, h_R, lda, d_A, lda, opts.queue );
 
@@ -132,21 +135,21 @@ int main( int argc, char** argv)
             gpu_time = magma_wtime();
             magma_zgeqp3_gpu( M, N, d_A, lda, jpvt, dtau, d_work, lwork,
                               #ifdef COMPLEX
-                              drwork,
+                              NULL,
                               #endif
                               &info );
             gpu_time = magma_wtime() - gpu_time;
-            
+
             /* copy outputs to cpu */
             magma_zgetmatrix( M, N, d_A, lda, h_R, lda, opts.queue );
             magma_zgetvector( min_mn, dtau, 1, tau, 1, opts.queue );
-            
+
             gpu_perf = gflops / gpu_time;
             if (info != 0) {
                 printf("magma_zgeqp3 returned error %lld: %s.\n",
                        (long long) info, magma_strerror( info ));
             }
-            
+
             /* =====================================================================
                Check the result
                =================================================================== */
@@ -161,7 +164,7 @@ int main( int argc, char** argv)
             if ( opts.check ) {
                 double error, ulp;
                 ulp = lapackf77_dlamch( "P" );
-                
+
                 // Compute norm( A*P - Q*R )
                 error = lapackf77_zqpt01( &M, &N, &min_mn, h_A, h_R, &lda,
                                           tau, jpvt, h_work, &lwork );
@@ -172,18 +175,17 @@ int main( int argc, char** argv)
             else {
                 printf("     ---  \n");
             }
-            
+
             #ifdef COMPLEX
             magma_free_cpu( rwork  );
-            magma_free( drwork );
             #endif
             magma_free_cpu( jpvt   );
             magma_free_cpu( tau    );
             magma_free_cpu( h_A    );
-            
+
             magma_free_pinned( h_R    );
             magma_free_pinned( h_work );
-            
+
             magma_free( dtau   );
             magma_free( d_A    );
             magma_free( d_work );
@@ -193,7 +195,7 @@ int main( int argc, char** argv)
             printf( "\n" );
         }
     }
-    
+
     opts.cleanup();
     TESTING_CHECK( magma_finalize() );
     return status;
