@@ -1,9 +1,9 @@
 /*
-   -- MAGMA (version 2.6.2) --
+   -- MAGMA (version 2.10.0) --
    Univ. of Tennessee, Knoxville
    Univ. of California, Berkeley
    Univ. of Colorado, Denver
-   @date March 2022
+   @date February 2026
 
    @author Ahmad Abdelfattah
 
@@ -26,6 +26,23 @@
 #include "../control/magma_threadsetting.h"  // internal header
 #endif
 
+#define PRECISION_z
+
+// uncomment to use mkl's group batch interface
+//#define USE_MKL_GETRF_BATCH
+
+// uncomment to introduce singularity in one matrix
+// by setting two different columns to zeros
+// (edit MTX_ID, COL1, and COL2 accordingly)
+//#define SINGULARITY_CHECK
+#ifdef SINGULARITY_CHECK
+#define MTX_ID (10)    // checked against batchCount
+#define COL1   (1)     // checked against #columns
+#define COL2   (10)    // checked against #columns
+#endif
+
+
+////////////////////////////////////////////////////////////////////////////////
 double get_LU_error(magma_int_t M, magma_int_t N,
                     magmaDoubleComplex *A,  magma_int_t lda,
                     magmaDoubleComplex *LU, magma_int_t *IPIV)
@@ -68,6 +85,38 @@ double get_LU_error(magma_int_t M, magma_int_t N,
     return residual / (matnorm * N);
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// compares the GPU output to the CPU's
+void
+get_LU_forward_error(
+    magma_int_t M, magma_int_t N,
+    magmaDoubleComplex *refLU, magma_int_t ref_lda, magma_int_t *refIPIV,
+    magmaDoubleComplex *resLU, magma_int_t res_lda, magma_int_t *resIPIV,
+    double* error, magma_int_t* pivots_match)
+{
+    magma_int_t i, j;
+    double work[1], matnorm, residual;
+    *error = MAGMA_D_ZERO;
+    matnorm = lapackf77_zlange("f", &M, &N, refLU, &ref_lda, work);
+
+    for( j = 0; j < N; j++ ) {
+        for( i = 0; i < M; i++ ) {
+            resLU[i+j*res_lda] = MAGMA_Z_SUB( resLU[i+j*res_lda], refLU[i+j*ref_lda] );
+        }
+    }
+    residual = lapackf77_zlange("f", &M, &N, resLU, &res_lda, work);
+    *error = residual / (matnorm * N);
+
+    // compare pivots
+    *pivots_match = 1;
+    for( i = 0; i < min(M,N); i++ ) {
+        if( !( refIPIV[i] == resIPIV[i]) ) {
+            *pivots_match = 0;
+            break;
+        }
+    }
+}
+
 /* ////////////////////////////////////////////////////////////////////////////
    -- Testing zgetrf_batched
 */
@@ -85,13 +134,13 @@ int main( int argc, char** argv)
     magmaDoubleComplex *dA;
     magmaDoubleComplex **dA_array = NULL, **hA_array = NULL, **hR_array = NULL, **hdA_array = NULL;
 
-    magma_int_t     **hipiv_array = NULL, **hdipiv_array = NULL, **dipiv_array = NULL;
+    magma_int_t     **hipiv_array = NULL, **hdipiv_array = NULL, **dipiv_array = NULL, **dpivinfo_array;
     magma_int_t     *ipiv, *hinfo;
-    magma_int_t     *dipiv, *dinfo;
+    magma_int_t     *dipiv, *dpivinfo, *dinfo;
 
     magma_int_t *h_M = NULL, *h_N = NULL, *h_lda  = NULL, *h_ldda = NULL, *h_min_mn = NULL;
-    magma_int_t *d_M = NULL, *d_N = NULL, *d_ldda = NULL;
-    magma_int_t iM, iN, max_M=0, max_N=0, max_minmn, info;
+    magma_int_t *d_M = NULL, *d_N = NULL, *d_ldda = NULL, *d_min_mn;
+    magma_int_t iM, iN, max_M=0, max_N=0, max_minMN=0, max_MxN=0, info=0;
     magma_int_t ione     = 1;
     magma_int_t ISEED[4] = {0,0,0,1};
     magma_int_t batchCount;
@@ -99,6 +148,7 @@ int main( int argc, char** argv)
 
     magma_opts opts( MagmaOptsBatched );
     opts.parse_opts( argc, argv );
+    opts.lapack |= (opts.check == 2);
     double tol = opts.tolerance * lapackf77_dlamch("E");
 
     batchCount = opts.batchcount;
@@ -110,22 +160,29 @@ int main( int argc, char** argv)
     TESTING_CHECK( magma_imalloc_cpu(&h_min_mn, batchCount) );
     TESTING_CHECK( magma_imalloc_cpu(&hinfo,    batchCount ));
 
-    TESTING_CHECK( magma_imalloc(&d_M,    batchCount) );
-    TESTING_CHECK( magma_imalloc(&d_N,    batchCount) );
-    TESTING_CHECK( magma_imalloc(&d_ldda, batchCount) );
-    TESTING_CHECK( magma_imalloc(&dinfo,  batchCount ));
+    TESTING_CHECK( magma_imalloc(&d_M,      batchCount) );
+    TESTING_CHECK( magma_imalloc(&d_N,      batchCount) );
+    TESTING_CHECK( magma_imalloc(&d_ldda,   batchCount) );
+    TESTING_CHECK( magma_imalloc(&d_min_mn, batchCount) );
+    TESTING_CHECK( magma_imalloc(&dinfo,    batchCount ));
 
     TESTING_CHECK( magma_malloc_cpu((void**)&hA_array,  batchCount * sizeof(magmaDoubleComplex*)) );
     TESTING_CHECK( magma_malloc_cpu((void**)&hR_array,  batchCount * sizeof(magmaDoubleComplex*)) );
     TESTING_CHECK( magma_malloc_cpu((void**)&hdA_array, batchCount * sizeof(magmaDoubleComplex*)) );
     TESTING_CHECK( magma_malloc(    (void**)&dA_array,  batchCount * sizeof(magmaDoubleComplex*)) );
 
-    TESTING_CHECK( magma_malloc_cpu((void**)&hipiv_array,  batchCount * sizeof(magma_int_t*) ));
-    TESTING_CHECK( magma_malloc_cpu((void**)&hdipiv_array, batchCount * sizeof(magma_int_t*) ));
-    TESTING_CHECK( magma_malloc(    (void**)&dipiv_array,  batchCount * sizeof(magma_int_t*) ));
+    TESTING_CHECK( magma_malloc_cpu((void**)&hipiv_array,    batchCount * sizeof(magma_int_t*) ));
+    TESTING_CHECK( magma_malloc_cpu((void**)&hdipiv_array,   batchCount * sizeof(magma_int_t*) ));
+    TESTING_CHECK( magma_malloc(    (void**)&dipiv_array,    batchCount * sizeof(magma_int_t*) ));
+    TESTING_CHECK( magma_malloc(    (void**)&dpivinfo_array, batchCount * sizeof(magma_int_t*) ));
 
     printf("%%             max   max\n");
-    printf("%% BatchCount   M     N    CPU Gflop/s (ms)   MAGMA Gflop/s (ms)   ||PA-LU||/(||A||*N)\n");
+    if(opts.check == 2) {
+        printf("%% BatchCount   M     N    CPU Gflop/s (ms)   MAGMA Gflop/s (ms)   ||Aref-A||/(||Aref||*N)\n");
+    }
+    else {
+        printf("%% BatchCount   M     N    CPU Gflop/s (ms)   MAGMA Gflop/s (ms)   ||PA-LU||/(||A||*N)\n");
+    }
     printf("%%==========================================================================================================\n");
     for( int itest = 0; itest < opts.ntest; ++itest ) {
         seed = rand();
@@ -140,6 +197,7 @@ int main( int argc, char** argv)
             dA_size  = 0;
             piv_size = 0;
             gflops   = 0;
+
             for(int s = 0; s < batchCount; s++) {
                 h_M[s]      = 1 + (rand() % iM);
                 h_N[s]      = max(1, (magma_int_t) round(NbyM * real_Double_t(h_M[s])) ); // try to keep the M/N ratio
@@ -148,7 +206,8 @@ int main( int argc, char** argv)
                 h_lda[s]    = h_M[s];
                 h_ldda[s]   = h_lda[s]; //magma_roundup( h_M[s], opts.align );  // multiple of 32 by default
                 h_min_mn[s] = min( h_M[s], h_N[s] );
-                max_minmn   = (s == 0) ? h_min_mn[s] : max(h_min_mn[s], max_minmn);
+                max_minMN   = (s == 0) ? h_min_mn[s] : max(h_min_mn[s], max_minMN);
+                max_MxN     = (s == 0) ? h_M[s] * h_N[s] : max(h_M[s] * h_N[s], max_MxN);
                 hA_size    += h_lda[s]  * h_N[s];
                 dA_size    += h_ldda[s] * h_N[s];
                 piv_size   += h_min_mn[s];
@@ -160,8 +219,9 @@ int main( int argc, char** argv)
             TESTING_CHECK( magma_zmalloc_cpu( &hA_magma, hA_size  ));
             TESTING_CHECK( magma_zmalloc_pinned( &hR,    hA_size  ));
 
-            TESTING_CHECK( magma_zmalloc( &dA,    dA_size ));
-            TESTING_CHECK( magma_imalloc( &dipiv, piv_size ));
+            TESTING_CHECK( magma_zmalloc( &dA,       dA_size ));
+            TESTING_CHECK( magma_imalloc( &dipiv,    piv_size ));
+            TESTING_CHECK( magma_imalloc( &dpivinfo, batchCount * max_M ));
 
             /* Initialize ptr arrays */
             hA_array [0]    = hA;
@@ -176,9 +236,23 @@ int main( int argc, char** argv)
                 hipiv_array[s]  = hipiv_array[s-1]  + h_min_mn[s-1];
                 hdipiv_array[s] = hdipiv_array[s-1] + h_min_mn[s-1];
             }
+            magma_iset_pointer(dpivinfo_array, dpivinfo, 1, 0, 0, max_M, batchCount, opts.queue );
 
             /* Initialize hA and copy to hR */
             lapackf77_zlarnv( &ione, ISEED, &hA_size, hA );
+
+            #ifdef SINGULARITY_CHECK
+            // introduce singularity -- for debugging purpose only
+            magma_int_t id   = min(MTX_ID, batchCount-1);
+            magma_int_t col1 = min(COL1, h_N[id]-1);
+            magma_int_t col2 = min(COL2, h_N[id]-1);
+            printf("singularity in matrix %lld of size (%lld, %lld) : col. %lld & %lld set to zeros\n",
+                   (long long)id, (long long)h_M[id], (long long)h_N[id],
+                   (long long)col1, (long long)col2);
+            memset(hA_array[id] + col1 * h_lda[id], 0, h_M[id] * sizeof(magmaDoubleComplex));
+            memset(hA_array[id] + col2 * h_lda[id], 0, h_M[id] * sizeof(magmaDoubleComplex));
+            #endif
+
             memcpy(hR, hA, hA_size * sizeof(magmaDoubleComplex));
 
             /* ====================================================================
@@ -189,6 +263,7 @@ int main( int argc, char** argv)
             magma_isetvector(batchCount, h_M,    1, d_M,    1, opts.queue);
             magma_isetvector(batchCount, h_N,    1, d_N,    1, opts.queue);
             magma_isetvector(batchCount, h_ldda, 1, d_ldda, 1, opts.queue);
+            magma_isetvector(batchCount, h_min_mn, 1, d_min_mn, 1, opts.queue);
 
             for(int s = 0; s < batchCount; s++) {
                 magma_zsetmatrix( h_M[s], h_N[s],
@@ -196,13 +271,32 @@ int main( int argc, char** argv)
                                   hdA_array[s], h_ldda[s], opts.queue );
             }
 
-            magma_time = magma_sync_wtime( opts.queue );
-            info = magma_zgetrf_vbatched(
-                    d_M, d_N,
-                    dA_array, d_ldda,
-                    dipiv_array, dinfo,
-                    batchCount, opts.queue);
-            magma_time = magma_sync_wtime( opts.queue ) - magma_time;
+
+            if(opts.version == 1) {
+                // main API, with error checking and
+                // workspace allocation
+                magma_time = magma_sync_wtime( opts.queue );
+                info = magma_zgetrf_vbatched(
+                        d_M, d_N,
+                        dA_array, d_ldda,
+                        dipiv_array, dinfo,
+                        batchCount, opts.queue);
+                magma_time = magma_sync_wtime( opts.queue ) - magma_time;
+            }
+            else {
+                // advanced API, totally asynchronous,
+                // but requires some setup
+                magma_time = magma_sync_wtime( opts.queue );
+                magma_int_t nb, recnb;
+                magma_get_zgetrf_vbatched_nbparam(max_M, max_N, &nb, &recnb);
+                info = magma_zgetrf_vbatched_max_nocheck(
+                        d_M, d_N, d_min_mn,
+                        max_M, max_N, max_minMN, max_MxN, nb, 32,
+                        dA_array, d_ldda,
+                        dipiv_array, dpivinfo_array, dinfo,
+                        batchCount, opts.queue);
+                magma_time = magma_sync_wtime( opts.queue ) - magma_time;
+            }
             magma_perf = gflops / magma_time;
 
             hTmp = hA_magma;
@@ -229,6 +323,21 @@ int main( int argc, char** argv)
                Performs operation using LAPACK
                =================================================================== */
             if ( opts.lapack ) {
+
+                #if defined(MAGMA_WITH_MKL) && defined(USE_MKL_GETRF_BATCH)
+                magma_int_t *group_size = new magma_int_t[batchCount];
+                for(magma_int_t ig = 0; ig < batchCount; ig++) group_size[ig] = 1;
+
+                cpu_time = magma_wtime();
+                lapackf77_zgetrf_batch(
+                         h_M, h_N,
+                         hA_array, h_lda,
+                         hipiv_array, &batchCount, group_size, hinfo );
+                cpu_time = magma_wtime() - cpu_time;
+
+                delete[] group_size;
+
+                #else
                 cpu_time = magma_wtime();
                 #if !defined (BATCHED_DISABLE_PARCPU) && defined(_OPENMP)
                 magma_int_t nthreads = magma_get_lapack_numthreads();
@@ -247,8 +356,10 @@ int main( int argc, char** argv)
                 #if !defined (BATCHED_DISABLE_PARCPU) && defined(_OPENMP)
                     magma_set_lapack_numthreads(nthreads);
                 #endif
-
                 cpu_time = magma_wtime() - cpu_time;
+
+                #endif
+
                 cpu_perf = gflops / cpu_time;
             }
 
@@ -267,7 +378,7 @@ int main( int argc, char** argv)
                        magma_perf, magma_time*1000. );
             }
 
-            if ( opts.check ) {
+            if ( opts.check == 1 ) {
                 magma_getvector( piv_size, sizeof(magma_int_t), dipiv, 1, ipiv, 1, opts.queue );
                 hA_array[0] = hA_magma;
                 for(int s = 1; s < batchCount; s++) {
@@ -301,6 +412,41 @@ int main( int argc, char** argv)
                 status += ! okay;
                 printf("   %8.2e   %s\n", error, (okay ? "ok" : "failed") );
             }
+            else if( opts.check == 2 ) {
+                magma_int_t* ipiv_magma = NULL;
+                TESTING_CHECK( magma_imalloc_cpu( &ipiv_magma,     piv_size ));
+                magma_getvector( piv_size, sizeof(magma_int_t), dipiv, 1, ipiv_magma, 1, opts.queue );
+
+                magmaDoubleComplex *htmp_gpu = hA_magma;
+                magmaDoubleComplex *htmp_cpu = hA;
+                magma_int_t *hpiv_cpu = ipiv;
+                magma_int_t *hpiv_gpu = ipiv_magma;
+                double err = 0; error = 0;
+                magma_int_t pivots_match = 1, piv_match = 1;
+                for(magma_int_t s = 0; s < batchCount; s++) {
+                    get_LU_forward_error(
+                        h_M[s], h_N[s],
+                        htmp_cpu, h_lda[s], hpiv_cpu,
+                        htmp_gpu, h_lda[s], hpiv_gpu,
+                        &err, &piv_match);
+
+                    error = max(error, err);
+                    pivots_match &= piv_match;
+
+                    htmp_cpu += h_lda[s] * h_N[s];
+                    htmp_gpu += h_lda[s] * h_N[s];
+                    hpiv_cpu += h_min_mn[s];
+                    hpiv_gpu += h_min_mn[s];
+                }
+
+                bool okay = (error < tol);
+                status += ! okay;
+                printf("   %8.2e   %15s   %s\n", error,
+                       (pivots_match == 1)  ? "pivots match" : "pivots mismatch",
+                       (okay ? "ok" : "failed") );
+
+                magma_free_cpu( ipiv_magma );
+            }
             else {
                 printf("     ---\n");
             }
@@ -312,6 +458,7 @@ int main( int argc, char** argv)
 
             magma_free( dA );
             magma_free( dipiv );
+            magma_free( dpivinfo );
             fflush( stdout );
         }
         if ( opts.niter > 1 ) {
@@ -322,8 +469,10 @@ int main( int argc, char** argv)
     magma_free( d_M );
     magma_free( d_N );
     magma_free( d_ldda );
+    magma_free( d_min_mn );
     magma_free( dA_array );
     magma_free( dipiv_array );
+    magma_free( dpivinfo_array );
     magma_free( dinfo );
 
     magma_free_cpu( h_M );
