@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.6.2) --
+    -- MAGMA (version 2.10.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date March 2022
+       @date February 2026
 
        @precisions normal z -> c d s
        @author Ichitaro Yamazaki
@@ -13,6 +13,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
+#include <algorithm>
 
 // includes, project
 #include "flops.h"
@@ -58,22 +59,22 @@ double get_residual(
     const magmaDoubleComplex c_one     = MAGMA_Z_ONE;
     const magmaDoubleComplex c_neg_one = MAGMA_Z_NEG_ONE;
     const magma_int_t ione = 1;
-    
+
     magma_int_t upper = (uplo == MagmaUpper);
-    
+
     // this seed should be DIFFERENT than used in init_matrix
     // (else x is column of A, so residual can be exactly zero)
     magma_int_t ISEED[4] = {0,0,0,1};
     magma_int_t info = 0;
     magma_int_t i;
     magmaDoubleComplex *x, *b;
-    
+
     // initialize RHS
     TESTING_CHECK( magma_zmalloc_cpu( &x, n ));
     TESTING_CHECK( magma_zmalloc_cpu( &b, n ));
     lapackf77_zlarnv( &ione, ISEED, &n, b );
     blasf77_zcopy( &n, b, &ione, x, &ione );
-    
+
     // solve Ax = b
     if (nopiv) {
         if (upper) {
@@ -112,21 +113,21 @@ double get_residual(
     }
     // reset to original A
     init_matrix( opts, n, n, A, lda );
-    
+
     // compute r = Ax - b, saved in b
     blasf77_zhemv( lapack_uplo_const(uplo), &n, &c_one, A, &lda, x, &ione, &c_neg_one, b, &ione );
-    
+
     // compute residual |Ax - b| / (n*|A|*|x|)
     double norm_x, norm_A, norm_r, work[1];
     norm_A = lapackf77_zlanhe( "Fro", lapack_uplo_const(uplo), &n, A, &lda, work );
     norm_r = lapackf77_zlange( "Fro", &n, &ione, b, &n, work );
     norm_x = lapackf77_zlange( "Fro", &n, &ione, x, &n, work );
-    
+
     //printf( "r=\n" ); magma_zprint( 1, n, b, 1 );
-    
+
     magma_free_cpu( x );
     magma_free_cpu( b );
-    
+
     //printf( "r=%.2e, A=%.2e, x=%.2e, n=%lld\n", norm_r, norm_A, norm_x, (long long) n );
     return norm_r / (n * norm_A * norm_x);
 }
@@ -140,7 +141,7 @@ double get_residual_gpu(
     bool nopiv, magma_uplo_t uplo, magma_int_t n,
     magmaDoubleComplex *A, magma_int_t lda,
     magmaDoubleComplex *dA, magma_int_t ldda,
-    magma_int_t *ipiv, 
+    magma_int_t *ipiv,
     real_Double_t *time)
 {
     const magmaDoubleComplex c_one     = MAGMA_Z_ONE;
@@ -211,7 +212,7 @@ double get_residual_aasen(
     const magma_int_t ione = 1;
     const magmaDoubleComplex c_one     = MAGMA_Z_ONE;
     const magmaDoubleComplex c_neg_one = MAGMA_Z_NEG_ONE;
-    
+
     magmaDoubleComplex *L, *T;
     #define  A(i,j) ( A[(i) + (j)*lda])
     #define  L(i,j) ( L[(i) + (j)*n])
@@ -235,7 +236,7 @@ double get_residual_aasen(
     magma_int_t ISEED[4] = {0,0,0,1};
     magma_int_t info = 0;
     magmaDoubleComplex *x, *b;
-    
+
     // initialize RHS
     TESTING_CHECK( magma_zmalloc_cpu( &x, n ));
     TESTING_CHECK( magma_zmalloc_cpu( &b, n ));
@@ -307,20 +308,20 @@ double get_residual_aasen(
 
     // compute r = Ax - b, saved in b
     blasf77_zhemv( lapack_uplo_const(uplo), &n, &c_one, A, &lda, x, &ione, &c_neg_one, b, &ione );
-    
+
     // compute residual |Ax - b| / (n*|A|*|x|)
     double norm_x, norm_A, norm_r, work[1];
     norm_A = lapackf77_zlanhe( "Fro", lapack_uplo_const(uplo), &n, A, &lda, work );
     norm_r = lapackf77_zlange( "Fro", &n, &ione, b, &n, work );
     norm_x = lapackf77_zlange( "Fro", &n, &ione, x, &n, work );
-    
+
     //printf( "r=\n" ); magma_zprint( 1, n, b, 1 );
     magma_free_cpu( L );
     magma_free_cpu( T );
-    
+
     magma_free_cpu( x );
     magma_free_cpu( b );
-    
+
     #undef T
     #undef L
     #undef A
@@ -329,11 +330,11 @@ double get_residual_aasen(
 }
 
 /******************************************************************************/
-// On input, LU and ipiv is LU factorization of A. On output, LU is overwritten.
-// Works for any m, n.
+// On input, LD and ipiv is LDL^T factorization of A. On output, LD is overwritten.
+// Works for any n.
 // Uses init_matrix() to re-generate original A as needed.
 // Returns error in factorization, |PA - LU| / (n |A|)
-// This allocates 3 more matrices to store A, L, and U.
+// This allocates 3 more matrices to store A, L, and D.
 double get_LDLt_error(
     magma_opts &opts,
     bool nopiv, magma_uplo_t uplo, magma_int_t N,
@@ -342,11 +343,11 @@ double get_LDLt_error(
 {
     const magmaDoubleComplex c_one  = MAGMA_Z_ONE;
     const magmaDoubleComplex c_zero = MAGMA_Z_ZERO;
-    
+
     magma_int_t i, j, piv;
     magmaDoubleComplex *A, *L, *D;
     double work[1], matnorm, residual;
-    
+
     #define LD(i,j) (LD[(i) + (j)*lda])
     #define  A(i,j) ( A[(i) + (j)*N])
     #define  L(i,j) ( L[(i) + (j)*N])
@@ -363,21 +364,27 @@ double get_LDLt_error(
 
     // symmetrize; the pivoting code below assumes a full matrix
     if (opts.uplo == MagmaLower) {
-        // copy L to U
+        // Copy conj(L) to U, and make diagonal real.
         for (j = 0; j < N; ++j) {
             for (i = 0; i < j; ++i) {
-                A(i,j) = A(j,i);
+                A(i, j) = MAGMA_Z_CONJ( A(j, i) );
             }
+            A(j, j) = MAGMA_Z_MAKE( MAGMA_Z_REAL( A(j, j) ), 0 );
         }
     }
     else {
-        // copy U to L
+        // Copy conj(U) to L, and make diagonal real.
         for (j = 0; j < N; ++j) {
             for (i = 0; i < j; ++i) {
-                A(j,i) = A(i,j);
+                A(j, i) = MAGMA_Z_CONJ( A(i, j) );
             }
+            A(j, j) = MAGMA_Z_MAKE( MAGMA_Z_REAL( A(j, j) ), 0 );
         }
     }
+    if (opts.verbose) {
+        printf( "Aerr = " );
+        magma_zprint( N, N, A, lda );
+    }
 
     if (uplo == MagmaUpper) {
         for (j=N-1; j >= 0; j--) {
@@ -402,21 +409,15 @@ double get_LDLt_error(
                 if (piv != j) {
                     // apply row-pivoting to previous L
                     for (i=j+2; i < N; i++) {
-                        magmaDoubleComplex val = L(j,i);
-                        L(j,i) = L(piv,i);
-                        L(piv,i) = val;
+                        std::swap( L(j, i), L(piv, i) );
                     }
                     // apply row-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(j,i);
-                        A(j,i) = A(piv,i);
-                        A(piv,i) = val;
+                        std::swap( A(j, i), A(piv, i) );
                     }
                     // apply col-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(i,j);
-                        A(i,j) = A(i,piv);
-                        A(i,piv) = val;
+                        std::swap( A(i, j), A(i, piv) );
                     }
                 }
             }
@@ -432,21 +433,15 @@ double get_LDLt_error(
                 if (piv != j) {
                     // apply row-pivoting to previous L
                     for (i=j+1; i < N; i++) {
-                        magmaDoubleComplex val = L(j,i);
-                        L(j,i) = L(piv,i);
-                        L(piv,i) = val;
+                        std::swap( L(j, i), L(piv, i) );
                     }
                     // apply row-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(j,i);
-                        A(j,i) = A(piv,i);
-                        A(piv,i) = val;
+                        std::swap( A(j, i), A(piv, i) );
                     }
                     // apply col-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(i,j);
-                        A(i,j) = A(i,piv);
-                        A(i,piv) = val;
+                        std::swap( A(i, j), A(i,piv) );
                     }
                 }
             }
@@ -491,21 +486,15 @@ double get_LDLt_error(
                 if (piv != j) {
                     // apply row-pivoting to previous L
                     for (i=0; i < j-1; i++) {
-                        magmaDoubleComplex val = L(j,i);
-                        L(j,i) = L(piv,i);
-                        L(piv,i) = val;
+                        std::swap( L(j, i), L(piv, i) );
                     }
                     // apply row-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(j,i);
-                        A(j,i) = A(piv,i);
-                        A(piv,i) = val;
+                        std::swap( A(j, i), A(piv, i) );
                     }
                     // apply col-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(i,j);
-                        A(i,j) = A(i,piv);
-                        A(i,piv) = val;
+                        std::swap( A(i, j), A(i, piv) );
                     }
                 }
             }
@@ -521,21 +510,15 @@ double get_LDLt_error(
                 if (piv != j) {
                     // apply row-pivoting to previous L
                     for (i=0; i < j; i++) {
-                        magmaDoubleComplex val = L(j,i);
-                        L(j,i) = L(piv,i);
-                        L(piv,i) = val;
+                        std::swap( L(j, i), L(piv, i) );
                     }
                     // apply row-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(j,i);
-                        A(j,i) = A(piv,i);
-                        A(piv,i) = val;
+                        std::swap( A(j, i), A(piv, i) );
                     }
                     // apply col-pivoting to A
                     for (i=0; i < N; i++) {
-                        magmaDoubleComplex val = A(i,j);
-                        A(i,j) = A(i,piv);
-                        A(i,piv) = val;
+                        std::swap( A(i, j), A(i, piv) );
                     }
                 }
             }
@@ -557,6 +540,11 @@ double get_LDLt_error(
     }
     residual = lapackf77_zlange( "Fro", &N, &N, D, &N, work);
 
+    if (opts.verbose) {
+        printf( "Residual = " );
+        magma_zprint( N, N, D, N );
+    }
+
     magma_free_cpu( A );
     magma_free_cpu( L );
     magma_free_cpu( D );
@@ -575,10 +563,10 @@ double get_LTLt_error(
     magmaDoubleComplex c_one  = MAGMA_Z_ONE;
     magmaDoubleComplex c_zero = MAGMA_Z_ZERO;
     magmaDoubleComplex *A, *L, *T;
-    
+
     #define LT(i,j) (LT[(i) + (j)*lda])
     #define  T(i,j) ( T[(i) + (j)*N])
-    
+
     TESTING_CHECK( magma_zmalloc_cpu( &A, N*N ));
     TESTING_CHECK( magma_zmalloc_cpu( &L, N*N ));
     TESTING_CHECK( magma_zmalloc_cpu( &T, N*N ));
@@ -587,7 +575,7 @@ double get_LTLt_error(
 
     magma_int_t i, j, istart, piv;
     magma_int_t nb = magma_get_zhetrf_aasen_nb(N);
-    
+
     // for debuging
     /*
     magma_int_t *p;
@@ -608,7 +596,7 @@ double get_LTLt_error(
     printf( "];\n" );
     magma_free_cpu( p );
     */
-    
+
     // extract T
     for (i=0; i < N; i++) {
         istart = max(0, i-nb);
@@ -622,7 +610,7 @@ double get_LTLt_error(
     //printf( "T=" );
     //magma_zprint(N,N, &T(0,0),N);
     // extract L
-    for (i=0; i < min(N,nb); i++) 
+    for (i=0; i < min(N,nb); i++)
     {
         L(i,i) = c_one;
     }
@@ -651,21 +639,27 @@ double get_LTLt_error(
 
     // symmetrize; the pivoting code below assumes a full matrix
     if (opts.uplo == MagmaLower) {
-        // copy L to U
+        // Copy conj(L) to U, and make diagonal real.
         for (j = 0; j < N; ++j) {
             for (i = 0; i < j; ++i) {
-                A(i,j) = A(j,i);
+                A(i, j) = MAGMA_Z_CONJ( A(j, i) );
             }
+            A(j, j) = MAGMA_Z_MAKE( MAGMA_Z_REAL( A(j, j) ), 0 );
         }
     }
     else {
-        // copy U to L
+        // Copy conj(U) to L, and make diagonal real.
         for (j = 0; j < N; ++j) {
             for (i = 0; i < j; ++i) {
-                A(j,i) = A(i,j);
+                A(j, i) = MAGMA_Z_CONJ( A(i, j) );
             }
+            A(j, j) = MAGMA_Z_MAKE( MAGMA_Z_REAL( A(j, j) ), 0 );
         }
     }
+    if (opts.verbose) {
+        printf( "Aerr = " );
+        magma_zprint( N, N, A, lda );
+    }
 
     // apply symmetric pivoting
     for (j=0; j < N; j++) {
@@ -673,15 +667,11 @@ double get_LTLt_error(
         if (piv != j) {
             // apply row-pivoting to A
             for (i=0; i < N; i++) {
-                magmaDoubleComplex val = A(j,i);
-                A(j,i) = A(piv,i);
-                A(piv,i) = val;
+                std::swap( A(j, i), A(piv, i) );
             }
             // apply col-pivoting to A
             for (i=0; i < N; i++) {
-                magmaDoubleComplex val = A(i,j);
-                A(i,j) = A(i,piv);
-                A(i,piv) = val;
+                std::swap( A(i, j), A(i, piv) );
             }
         }
     }
@@ -694,6 +684,11 @@ double get_LTLt_error(
     }
     residual = lapackf77_zlange( "Fro", &N, &N, T, &N, work);
 
+    if (opts.verbose) {
+        printf( "Residual = " );
+        magma_zprint( N, N, T, N );
+    }
+
     magma_free_cpu( A );
     magma_free_cpu( L );
     magma_free_cpu( T );
@@ -706,19 +701,19 @@ double get_LTLt_error(
 /* ////////////////////////////////////////////////////////////////////////////
    -- Testing zhetrf
 */
-int main( int argc, char** argv)
+int main( int argc, char** argv )
 {
     TESTING_CHECK( magma_init() );
     magma_print_environment();
 
     magmaDoubleComplex *h_A, *work, temp;
     real_Double_t   gflops, gpu_perf, gpu_time = 0.0, cpu_perf=0, cpu_time=0, solve_time[2];
-    double          error, error_lapack = 0.0;
+    double          error = 0.0, error_lapack = 0.0;
     magma_int_t     *ipiv;
     magma_int_t     cpu_panel = 1, N, n2, lda, lwork, info;
     magma_int_t     cpu = 0, gpu = 0, nopiv = 0, nopiv_gpu = 0, row = 0, aasen = 0;
     int status = 0;
-    
+
     magma_opts opts;
     opts.parse_opts( argc, argv );
     if (opts.version == 3 || opts.version == 4) {
@@ -730,8 +725,8 @@ int main( int argc, char** argv)
 
     // TODO: this doesn't work. Options need to be added to parse_opts()
     //for (int i = 1; i < argc; ++i) {
-    //    if ( strcmp("--cpu-panel", argv[i]) == 0) cpu_panel = 1;
-    //    if ( strcmp("--gpu-panel", argv[i]) == 0) cpu_panel = 0;
+    //    if (strcmp("--cpu-panel", argv[i]) == 0) cpu_panel = 1;
+    //    if (strcmp("--gpu-panel", argv[i]) == 0) cpu_panel = 0;
     //}
 
     printf( "%% --version 1 = Bunch-Kauffman (CPU)\n"
@@ -774,7 +769,7 @@ int main( int argc, char** argv)
 
     double tol = opts.tolerance * lapackf77_dlamch("E");
 
-    if ( opts.check == 2 ) {
+    if (opts.check == 2) {
         printf("%%   M     N   CPU Gflop/s (sec)   GPU Gflop/s (sec)   |Ax-b|/(N*|A|*|x|)\n");
     }
     else {
@@ -787,14 +782,14 @@ int main( int argc, char** argv)
             lda    = N;
             n2     = lda*N;
             gflops = FLOPS_ZPOTRF( N ) / 1e9;
-            
+
             TESTING_CHECK( magma_imalloc_pinned( &ipiv, N ));
             TESTING_CHECK( magma_zmalloc_pinned( &h_A,  n2 ));
-            
+
             /* =====================================================================
                Performs operation using LAPACK
                =================================================================== */
-            if ( opts.lapack ) {
+            if (opts.lapack) {
                 lwork = -1;
                 lapackf77_zhetrf( lapack_uplo_const(opts.uplo), &N, h_A, &lda, ipiv, &temp, &lwork, &info );
                 lwork = (magma_int_t)MAGMA_Z_REAL( temp );
@@ -824,11 +819,15 @@ int main( int argc, char** argv)
 
                 magma_free_cpu( work );
             }
-           
+
             /* ====================================================================
                Performs operation using MAGMA
                =================================================================== */
             init_matrix( opts, N, N, h_A, lda );
+            if (opts.verbose) {
+                printf( "A = " );
+                magma_zprint( N, N, h_A, lda );
+            }
 
             //printf( "A0=" );
             //magma_zprlong( N, N, h_A, lda );
@@ -844,7 +843,7 @@ int main( int argc, char** argv)
                 magma_zhetrf( opts.uplo, N, h_A, lda, ipiv, &info);
                 gpu_time = magma_wtime() - gpu_time;
 
-                // To do: extend to test inertia for real case; 
+                // To do: extend to test inertia for real case;
                 #ifdef REAL
                 double det[2];
                 magma_int_t inert[3];
@@ -865,6 +864,7 @@ int main( int argc, char** argv)
                 magmaDoubleComplex_ptr d_A;
                 TESTING_CHECK( magma_zmalloc( &d_A, N*ldda ));
                 magma_zsetmatrix(N, N, h_A, lda, d_A, ldda, opts.queue );
+
                 gpu_time = magma_wtime();
                 magma_zhetrf_nopiv_gpu( opts.uplo, N, d_A, ldda, &info);
                 gpu_time = magma_wtime() - gpu_time;
@@ -902,6 +902,7 @@ int main( int argc, char** argv)
                 }
                 printf("inertia: positive / negative / zero = %d / %d / %d\n",
                        inert[0], inert[1], inert[2]);
+
                 magma_free( d_A );
             }
             else if (gpu) {
@@ -910,21 +911,22 @@ int main( int argc, char** argv)
                 magmaDoubleComplex_ptr d_A;
                 TESTING_CHECK( magma_zmalloc( &d_A, N*ldda ));
                 magma_zsetmatrix(N, N, h_A, lda, d_A, ldda, opts.queue );
+
                 gpu_time = magma_wtime();
                 magma_zhetrf_gpu( opts.uplo, N, d_A, ldda, ipiv, &info);
                 gpu_time = magma_wtime() - gpu_time;
 
                 magma_zgetmatrix(N, N, d_A, ldda, h_A, lda, opts.queue );
-                if ( opts.check == 2 && info == 0) {
-                    error = get_residual_gpu( opts, (nopiv | nopiv_gpu), opts.uplo, N, 
+                if (opts.check == 2 && info == 0) {
+                    error = get_residual_gpu( opts, (nopiv | nopiv_gpu), opts.uplo, N,
                                               h_A, lda, d_A, ldda, ipiv, solve_time );
                     magma_zgetmatrix(N, N, d_A, ldda, h_A, lda, opts.queue );
                 }
-                
+
                 int *dinert, inert[3];
                 //for(int kk=0; kk<N; kk++)
                 //    h_A[kk+(N-1)*lda] = h_A[N-1+kk*lda] = 0.;
-                TESTING_CHECK( magma_malloc( (void**)&dinert, 3*sizeof(int)) ); 
+                TESTING_CHECK( magma_malloc( (void**)&dinert, 3*sizeof(int)) );
                 magmablas_zheinertia(opts.uplo, N, d_A, ldda, ipiv, dinert, opts.queue);
                 magma_getvector( 3, sizeof(int), dinert, 1, inert, 1, opts.queue );
                 printf("inertia: positive / negative / zero = %d / %d / %d\n",
@@ -950,11 +952,11 @@ int main( int argc, char** argv)
                 printf("magma_zhetrf returned error %lld: %s.\n",
                        (long long) info, magma_strerror( info ));
             }
-            
+
             /* =====================================================================
                Check the factorization
                =================================================================== */
-            if ( opts.lapack ) {
+            if (opts.lapack) {
                 printf("%5lld %5lld   %7.2f (%7.2f)   %7.2f (%7.2f)",
                        (long long) N, (long long) N, cpu_perf, cpu_time, gpu_perf, gpu_time );
             }
@@ -962,16 +964,16 @@ int main( int argc, char** argv)
                 printf("%5lld %5lld     ---   (  ---  )   %7.2f (%7.2f)",
                        (long long) N, (long long) N, gpu_perf, gpu_time );
             }
-            if ( opts.check == 2 && info == 0) {
+            if (opts.check == 2 && info == 0) {
                 if (aasen) {
                     error = get_residual_aasen( opts, (nopiv | nopiv_gpu), opts.uplo, N, h_A, lda, ipiv );
                 }
-                else if (!gpu) {
+                else if (! gpu) {
                     error = get_residual( opts, (nopiv | nopiv_gpu), opts.uplo, N, h_A, lda, ipiv );
                 }
                 // gpu case calls get_residual_gpu before to initialize error and timing.
                 // This is done above in a block where GPU memory is allocated, computatio is done,
-                // and the GPU memory is freed. 
+                // and the GPU memory is freed.
                 if (gpu) {
                     printf("   %8.2e (%.2f s) %s", error, solve_time[0], (error < tol ? "ok" : "failed"));
                     if (opts.lapack)
@@ -985,7 +987,7 @@ int main( int argc, char** argv)
                 printf("\n");
                 status += ! (error < tol);
             }
-            else if ( opts.check && info == 0 ) {
+            else if (opts.check && info == 0) {
                 if (aasen) {
                     error = get_LTLt_error( opts, (nopiv | nopiv_gpu), opts.uplo, N, h_A, lda, ipiv );
                 }
@@ -998,12 +1000,12 @@ int main( int argc, char** argv)
             else {
                 printf("     ---   \n");
             }
- 
+
             magma_free_pinned( ipiv );
             magma_free_pinned( h_A  );
             fflush( stdout );
         }
-        if ( opts.niter > 1 ) {
+        if (opts.niter > 1) {
             printf( "\n" );
         }
     }
